@@ -40,8 +40,12 @@
 #include <wx/utils.h>
 #include <wx/wfstream.h>
 #include <wx/xml/xml.h>
+#include <algorithm>
 
 AutoComplete::AutoComplete(Configuration *configuration) {
+  std::vector<wxString> emptyList;
+  for(unsigned i = 0; i < autoCompletionType::numberOfTypes; i++)
+    m_wordList.push_back(emptyList);
   m_configuration = configuration;
 }
 
@@ -55,7 +59,7 @@ void AutoComplete::ClearDemofileList() {
     WaitForBackgroundThread_Files();
     m_addFiles_backgroundThread.reset();
   }
-  m_wordList[demofile] = m_builtInDemoFiles;
+  m_wordList.at(demofile) = m_builtInDemoFiles;
 }
 
 void AutoComplete::AddSymbols(wxString xml) {
@@ -66,9 +70,9 @@ void AutoComplete::AddSymbols(wxString xml) {
   wxString sharedir = m_configuration->MaximaShareDir();
   sharedir.Replace("\n", "");
   sharedir.Replace("\r", "");
-  
+
   m_addSymbols_backgroundThread = std::unique_ptr<std::thread>(
-							       new std::thread(&AutoComplete::AddSymbols_Backgroundtask, this, xml));
+                                                               new std::thread(&AutoComplete::AddSymbols_Backgroundtask, this, xml));
 }
 
 void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
@@ -159,27 +163,23 @@ void AutoComplete::LoadSymbols() {
   sharedir.Replace("\n", "");
   sharedir.Replace("\r", "");
   m_addSymbols_backgroundThread = std::unique_ptr<std::thread>(
-							       new std::thread(&AutoComplete::BuiltinSymbols_BackgroundTask, this));
+                                                               new std::thread(&AutoComplete::BuiltinSymbols_BackgroundTask, this));
   m_addFiles_backgroundThread = std::unique_ptr<std::thread>(
-							     new std::thread(&AutoComplete::LoadableFiles_BackgroundTask, this, sharedir));
+                                                             new std::thread(&AutoComplete::LoadableFiles_BackgroundTask, this, sharedir));
 }
 
 void AutoComplete::BuiltinSymbols_BackgroundTask() {
-  m_wordList[command].Clear();
-  m_wordList[tmplte].Clear();
-  m_wordList[esccommand].Clear();
-  m_wordList[unit].Clear();
+  for(auto &wordlist:m_wordList)
+    wordlist.clear();
 
   LoadBuiltinSymbols();
 
   for (auto it = Configuration::EscCodesBegin();
        it != Configuration::EscCodesEnd(); ++it)
-    m_wordList[esccommand].Add(it->first);
+    m_wordList.at(esccommand).push_back(it->first);
 
-  m_wordList[command].Sort();
-  m_wordList[tmplte].Sort();
-  m_wordList[unit].Sort();
-  m_wordList[esccommand].Sort();
+  for(auto &wordlist:m_wordList)
+    std::sort(wordlist.begin(), wordlist.end());
 
   wxString line;
 
@@ -187,7 +187,7 @@ void AutoComplete::BuiltinSymbols_BackgroundTask() {
   wxString privateList;
   privateList = Dirstructure::Get()->UserAutocompleteFile();
   wxLogMessage(_("Trying to load a list of autocompletable symbols from file %s"),
-	       privateList.utf8_str());
+               privateList.utf8_str());
   if (wxFileExists(privateList)) {
     wxTextFile priv(privateList);
 
@@ -202,17 +202,17 @@ void AutoComplete::BuiltinSymbols_BackgroundTask() {
       line.Trim(false);
       if (!line.StartsWith("#")) {
         if (function.Replace(&line, ""))
-          m_wordList[command].Add(line);
+          m_wordList.at(command).push_back(line);
         else if (option.Replace(&line, ""))
-          m_wordList[command].Add(line);
+          m_wordList.at(command).push_back(line);
         else if (templte.Replace(&line, ""))
-          m_wordList[tmplte].Add(FixTemplate(line));
+          m_wordList.at(tmplte).push_back(FixTemplate(line));
         else if (unt.Replace(&line, ""))
-          m_wordList[unit].Add(line);
+          m_wordList.at(unit).push_back(line);
         else
           wxLogMessage(_("%s: Can't interpret line: %s"),
-	    privateList.mb_str(),
-	    line.mb_str());
+                       privateList.mb_str(),
+                       line.mb_str());
       }
     }
     priv.Close();
@@ -251,7 +251,7 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
       wxFileName shareDir(sharedir + "/");
       shareDir.MakeAbsolute();
       wxLogMessage(_("Autocompletion: Scanning %s recursively for loadable lisp files."),
-				    shareDir.GetFullPath().utf8_str());
+                   shareDir.GetFullPath().utf8_str());
       wxDir maximadir(shareDir.GetFullPath());
       if (maximadir.IsOpened())
         maximadir.Traverse(maximaLispIterator); // todo
@@ -261,11 +261,11 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
     userDir.MakeAbsolute();
     wxDir maximauserfilesdir(userDir.GetFullPath());
     wxLogMessage(_("Autocompletion: Scanning %s for loadable lisp files."),
-		 userDir.GetFullPath().utf8_str());
+                 userDir.GetFullPath().utf8_str());
     if (maximauserfilesdir.IsOpened())
       maximauserfilesdir.Traverse(userLispIterator);
-    int num = m_builtInLoadFiles.GetCount();
-    wxLogMessage(_("Found %i loadable files."), num);
+    int num = m_builtInLoadFiles.size();
+    wxLogMessage(_("Found %li loadable files."), static_cast<long>(num));
   }
 
   // Prepare a list of all built-in demos of maxima.
@@ -277,22 +277,22 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
     demoDir.RemoveLastDir();
     GetDemoFiles_includingSubdirs maximaLispIterator(m_builtInDemoFiles);
     wxLogMessage(_("Autocompletion: Scanning %s for loadable demo files."),
-		 demoDir.GetFullPath().utf8_str());
+                 demoDir.GetFullPath().utf8_str());
 
     wxDir maximadir(demoDir.GetFullPath());
     if (maximadir.IsOpened())
       maximadir.Traverse(maximaLispIterator);
-    int num = m_builtInDemoFiles.GetCount();
-    wxLogMessage(_("Found %i demo files."), num);
+    int num = m_builtInDemoFiles.size();
+    wxLogMessage(_("Found %li demo files."), static_cast<long>(num));
   }
-  m_builtInLoadFiles.Sort();
-  m_builtInDemoFiles.Sort();
+  std::sort(m_builtInLoadFiles.begin(), m_builtInLoadFiles.end());
+  std::sort(m_builtInDemoFiles.begin(), m_builtInDemoFiles.end());
 }
 
 void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
   WaitForBackgroundThread_Files();
   // Remove the opening quote from the partial.
-  if (partial[0] == wxS('\"'))
+  if (partial.at(0) == wxS('\"'))
     partial = partial.Right(partial.Length() - 1);
 
   partial.Replace(wxFileName::GetPathSeparator(), "/");
@@ -319,7 +319,7 @@ void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
 
   // Add all files from the maxima directory to the demo file list
   if (partial != wxS("//")) {
-    GetDemoFiles userLispIterator(m_wordList[demofile], prefix);
+    GetDemoFiles userLispIterator(m_wordList.at(demofile), prefix);
     wxDir demofilesdir(partial);
     if (demofilesdir.IsOpened())
       demofilesdir.Traverse(userLispIterator);
@@ -329,7 +329,7 @@ void AutoComplete::UpdateDemoFiles(wxString partial, wxString maximaDir) {
 void AutoComplete::UpdateGeneralFiles(wxString partial, wxString maximaDir) {
   WaitForBackgroundThread_Files();
   // Remove the opening quote from the partial.
-  if (partial[0] == wxS('\"'))
+  if (partial.at(0) == wxS('\"'))
     partial = partial.Right(partial.Length() - 1);
 
   partial.Replace(wxFileName::GetPathSeparator(), "/");
@@ -365,7 +365,7 @@ void AutoComplete::UpdateLoadFiles(wxString partial, wxString maximaDir) {
                  "file names."));
   WaitForBackgroundThread_Files();
   // Remove the opening quote from the partial.
-  if (partial[0] == wxS('\"'))
+  if (partial.at(0) == wxS('\"'))
     partial = partial.Right(partial.Length() - 1);
 
   partial.Replace(wxFileName::GetPathSeparator(), "/");
@@ -392,7 +392,7 @@ void AutoComplete::UpdateLoadFiles(wxString partial, wxString maximaDir) {
 
   // Add all files from the maxima directory to the load file list
   if (partial != wxS("//")) {
-    GetMacFiles userLispIterator(m_wordList[loadfile], prefix);
+    GetMacFiles userLispIterator(m_wordList.at(loadfile), prefix);
     wxDir loadfilesdir(partial);
     if (loadfilesdir.IsOpened())
       loadfilesdir.Traverse(userLispIterator);
@@ -400,10 +400,10 @@ void AutoComplete::UpdateLoadFiles(wxString partial, wxString maximaDir) {
 }
 
 /// Returns a string array with functions which start with partial.
-wxArrayString AutoComplete::CompleteSymbol(wxString partial,
-                                           autoCompletionType type) {
-  wxArrayString completions;
-  wxArrayString perfectCompletions;
+std::vector<wxString> AutoComplete::CompleteSymbol(wxString partial,
+                                                   autoCompletionType type) {
+  std::vector<wxString> completions;
+  std::vector<wxString> perfectCompletions;
 
   WaitForBackgroundThreads();
   if (((type == AutoComplete::demofile) || (type == AutoComplete::loadfile)) &&
@@ -413,20 +413,21 @@ wxArrayString AutoComplete::CompleteSymbol(wxString partial,
   wxASSERT_MSG((type >= command) && (type <= unit),
                _("Bug: Autocompletion requested for unknown type of item."));
 
-  if (type != tmplte) {
-    for (const auto &i : m_wordList[type]) {
+  if ((type != tmplte) && (type >=0 ) && (type < numberOfTypes )) {
+    for (const auto &i : m_wordList.at(type)) {
       if (i.StartsWith(partial) &&
-          completions.Index(i) == wxNOT_FOUND)
-        completions.Add(i);
+          (std::find(completions.begin(), completions.end(), i) == completions.end()))
+        completions.push_back(i);
     }
-  } else {
-    for (const auto &i: m_wordList[type]) {
+  } else if (type == tmplte) {
+    for (const auto &i: m_wordList.at(type)) {
       if (i.StartsWith(partial)) {
-        if (completions.Index(i) == wxNOT_FOUND)
-          completions.Add(i);
-        if (i.SubString(0, i.Find(wxS("(")) - 1) == partial &&
-            perfectCompletions.Index(i) == wxNOT_FOUND)
-          perfectCompletions.Add(i);
+        if (std::find(completions.begin(), completions.end(), i) == completions.end())
+          completions.push_back(i);
+        if (i.SubString(0, static_cast<std::size_t>(i.Find(wxS("("))) - 1) == partial &&
+            (std::find(perfectCompletions.begin(), perfectCompletions.end(), i) ==
+             perfectCompletions.end()))
+          perfectCompletions.push_back(i);
       }
     }
   }
@@ -436,15 +437,15 @@ wxArrayString AutoComplete::CompleteSymbol(wxString partial,
   if (type == command) {
     for (const auto &it : m_worksheetWords) {
       if (it.first.StartsWith(partial)) {
-        if (completions.Index(it.first) == wxNOT_FOUND) {
-          completions.Add(it.first);
+        if (std::find(completions.begin(), completions.end(), it.first) == completions.end()) {
+          completions.push_back(it.first);
         }
       }
     }
   }
 
-  completions.Sort();
-  if (perfectCompletions.Count() > 0)
+  std::sort(completions.begin(), completions.end());
+  if (perfectCompletions.size() > 0)
     return perfectCompletions;
   return completions;
 }
@@ -469,28 +470,29 @@ void AutoComplete::AddSymbol_nowait(wxString fun, autoCompletionType type) {
 
   /// Add symbols
   if ((type != tmplte) &&
-      m_wordList[type].Index(fun, true, true) == wxNOT_FOUND)
-    m_wordList[type].Add(fun);
+      (std::find(m_wordList.at(type).begin(), m_wordList.at(type).end(), fun) ==
+       m_wordList.at(type).end()))
+    m_wordList.at(type).push_back(fun);
 
   /// Add templates - for given function and given argument count we
   /// only add one template. We count the arguments by counting '<'
   if (type == tmplte) {
     fun = FixTemplate(fun);
-    long openpos = fun.Find(wxS("("));
+    auto openpos = fun.Find(wxS("("));
     if(openpos < 0)
       wxLogMessage(_("Cannot interpret template %s"), fun.mb_str());
     else
       {
-	wxString funName = fun.SubString(0, openpos);
-	long count = fun.Freq('<');
-	size_t i = 0;
-	for (const auto &o: m_wordList[type]) {
-	  if (o.StartsWith(funName) && (o.Freq('<') == count))
-	    break;
-	  i++;
-	}
-	if (i == m_wordList[type].GetCount())
-	  m_wordList[type].Add(fun);
+        wxString funName = fun.SubString(0, openpos);
+        auto count = fun.Freq('<');
+        std::size_t i = 0;
+        for (const auto &o: m_wordList.at(type)) {
+          if (o.StartsWith(funName) && (o.Freq('<') == count))
+            break;
+          i++;
+        }
+        if (i == m_wordList.at(type).size())
+          m_wordList.at(type).push_back(fun);
       }
   }
 }
