@@ -35,8 +35,8 @@
 
 ChangeLogDialog::ChangeLogDialog(wxWindow *parent)
   : wxDialog(parent, -1, _("ChangeLog"), wxDefaultPosition, wxDefaultSize,
-	     wxRESIZE_BORDER | wxCLOSE_BOX | wxMAXIMIZE_BOX |
-	     wxMINIMIZE_BOX) {
+             wxRESIZE_BORDER | wxCLOSE_BOX | wxMAXIMIZE_BOX |
+             wxMINIMIZE_BOX) {
   wxBoxSizer *vbox = new wxBoxSizer(wxVERTICAL);
   wxMemoryInputStream istream(NEWS_MD, NEWS_MD_SIZE);
   wxTextInputStream textIn(istream);
@@ -44,16 +44,16 @@ ChangeLogDialog::ChangeLogDialog(wxWindow *parent)
   wxString line;
   wxString licenseText;
   Connect(wxEVT_TEXT_URL, wxTextUrlEventHandler(ChangeLogDialog::OnTextURLEvent),
-	  NULL, this);
+          NULL, this);
 
   m_license = new wxTextCtrl(
-			     this, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize,
-			     wxTE_MULTILINE | wxTE_BESTWRAP | wxTE_READONLY | wxTE_AUTO_URL);
+                             this, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize,
+                             wxTE_MULTILINE | wxTE_BESTWRAP | wxTE_READONLY | wxTE_AUTO_URL);
 
   wxFont fnt = m_license->GetFont();
   wxClientDC dc(this);
   dc.SetFont(fnt);
-  long textWidth = 0;
+  wxCoord textWidth = 0;
   wxRegEx issueLink("#([0-9][0-9]*)");
   wxRegEx bullet("^ \\*");
 
@@ -64,8 +64,8 @@ ChangeLogDialog::ChangeLogDialog(wxWindow *parent)
       textWidth = linesize.x;
       m_longestLine = line;
     }
-    issueLink.Replace(&line,wxS("https://github.com/wxMaxima-developers/wxmaxima/issues/\\1"));
-    bullet.Replace(&line,wxS("\u00a0\u2022"));
+    issueLink.Replace(&line, wxS("https://github.com/wxMaxima-developers/wxmaxima/issues/\\1"));
+    bullet.Replace(&line, wxS("\u00a0\u2022"));
     licenseText += line + wxS("\n");
   }
 
@@ -121,7 +121,7 @@ void ChangeLogDialog::OnTextURLEvent(wxTextUrlEvent &event) {
   if (event.GetMouseEvent().LeftUp()) {
     wxTextCtrl *pTextCtrl = static_cast<wxTextCtrl *>(event.GetEventObject());
     wxLaunchDefaultBrowser(
-			   pTextCtrl->GetRange(event.GetURLStart(), event.GetURLEnd()));
+                           pTextCtrl->GetRange(event.GetURLStart(), event.GetURLEnd()));
   }
 }
 
