@@ -135,7 +135,7 @@ private:
     HOME,
     VAR_DELETE
   };
-  std::unique_ptr<struct NSVGrasterizer, decltype(std::free)*> m_svgRast{nullptr, std::free};
+  std::unique_ptr<struct wxm_NSVGrasterizer, decltype(std::free)*> m_svgRast{nullptr, std::free};
   //! The configuration storage
   std::unique_ptr<Configuration> m_configuration;
   Worksheet *m_sampleWorksheet = NULL;
@@ -219,7 +219,7 @@ private:
 
   //! The panel that allows to specify startup commands
   wxWindow *CreateStartupPanel();
-  
+
 protected:
   wxGrid *m_maximaEnvVariables;
   void OnImport(wxCommandEvent& event);
