@@ -56,7 +56,6 @@ Configuration::Configuration(wxDC *dc, InitOpt options) :
   m_eng{m_rd()},
   m_dc(dc)
 {
-
   wxConfigBase *config = wxConfig::Get();
   std::uniform_int_distribution<long> urd(std::numeric_limits<long>::min(), std::numeric_limits<long>::max());
   m_configId = urd(m_eng);
@@ -183,6 +182,7 @@ Configuration::Configuration(wxDC *dc, InitOpt options) :
   m_maximaOperators[wxS(">=")] = 1;
   m_maximaOperators[wxS("$BFLOAT")] = 1;
   m_maximaOperators[wxS("do")] = 1;
+  m_maximaHelpFormat = frontend;
   m_printing = false;
   m_clipToDrawRegion = true;
   m_inLispMode = false;
@@ -191,7 +191,7 @@ Configuration::Configuration(wxDC *dc, InitOpt options) :
   m_lineWidth_em = 88;
   m_workSheet = NULL;
   SetBackgroundBrush(*wxWHITE_BRUSH);
-  ResetAllToDefaults(options);
+  ResetAllToDefaults();
   ReadConfig();
   wxString operators(wxS("\u221A\u22C0\u22C1\u22BB\u22BC\u22BD\u00AC\u222b"
                          "\u2264\u2265\u2211\u2260+-*/^:=#'!()[]{}"));
@@ -211,7 +211,7 @@ void Configuration::SetWorkSheet(wxWindow *workSheet)
   else
     {
       if(m_dc == m_worksheetDC.get())
-	m_dc = NULL;
+        m_dc = NULL;
       m_worksheetDC.reset();
     }
 }
@@ -221,15 +221,15 @@ wxSize Configuration::GetPPI() const {
   if(GetRecalcDC())
     {
       if(GetRecalcDC()->IsOk())
-	ppi = GetRecalcDC()->GetPPI();
+        ppi = GetRecalcDC()->GetPPI();
     }
 #if wxCHECK_VERSION(3, 1, 1)
   if((ppi.x < 10 ) || (ppi.y < 10 ))
     {
       if (GetWorkSheet()) {
-	int display_idx = wxDisplay::GetFromWindow(GetWorkSheet());
-	if (display_idx >= 0)
-	  ppi = wxDisplay(display_idx).GetPPI();
+        int display_idx = wxDisplay::GetFromWindow(GetWorkSheet());
+        if (display_idx >= 0)
+          ppi = wxDisplay(display_idx).GetPPI();
       }
     }
 #endif
@@ -238,7 +238,7 @@ wxSize Configuration::GetPPI() const {
   return ppi;
 }
 
-void Configuration::ResetAllToDefaults(InitOpt options) {
+void Configuration::ResetAllToDefaults() {
   m_printMargin_Top = 10;
   m_printMargin_Bot = 10;
   m_printMargin_Left = 10;
@@ -333,7 +333,7 @@ void Configuration::ResetAllToDefaults(InitOpt options) {
   m_greekSidebar_ShowLatinLookalikes = false;
   m_greekSidebar_Show_mu = false;
   m_copyBitmap = false; // Otherwise MS Office, OpenOffice and LibreOffice
-                        // prefer the bitmap
+  // prefer the bitmap
   // to Mathml and RTF. Also mail programs prefer bitmaps to text - which is
   // counter-productive for maxima-discuss.
   m_copyMathML = true;
@@ -599,7 +599,7 @@ bool Configuration::MaximaFound(wxString location) {
 
 void Configuration::ReadConfig() {
   wxConfigBase *config = wxConfig::Get();
-  
+
   config->Read(wxS("configID"), &m_configId);
 
   wxString str;
@@ -649,8 +649,8 @@ void Configuration::ReadConfig() {
       wxTextOutputStream txtstrm(ostream);
       txtstrm.WriteString(hideMessagesConfigString);
       wxMemoryInputStream istream(
-				  ostream.GetOutputStreamBuffer()->GetBufferStart(),
-				  ostream.GetOutputStreamBuffer()->GetBufferSize());
+                                  ostream.GetOutputStreamBuffer()->GetBufferStart(),
+                                  ostream.GetOutputStreamBuffer()->GetBufferSize());
       wxXmlDocument xmlDocument;
       if ((!hideMessagesConfigString.IsEmpty()) &&
           (xmlDocument.Load(istream))) {
@@ -659,19 +659,19 @@ void Configuration::ReadConfig() {
           headNode = headNode->GetChildren();
           while ((headNode) && (headNode->GetName() != wxS("markers")))
             headNode = headNode->GetNext();
-	  if(headNode)
-	    {
-	      wxXmlNode *entry = headNode->GetChildren();
-	      while (entry) {
-		if (entry->GetName() == wxS("hide")) {
-		  wxXmlNode *node = entry->GetChildren();
-		  if (node) {
-		    HideMarkerForThisMessage(node->GetContent(), true);
-		  }
-		}
-		entry = entry->GetNext();
-	      }
-	    }
+          if(headNode)
+            {
+              wxXmlNode *entry = headNode->GetChildren();
+              while (entry) {
+                if (entry->GetName() == wxS("hide")) {
+                  wxXmlNode *node = entry->GetChildren();
+                  if (node) {
+                    HideMarkerForThisMessage(node->GetContent(), true);
+                  }
+                }
+                entry = entry->GetNext();
+              }
+            }
         }
       }
     }
@@ -683,8 +683,8 @@ void Configuration::ReadConfig() {
       wxTextOutputStream txtstrm(ostream);
       txtstrm.WriteString(maximaEnvironmentString);
       wxMemoryInputStream istream(
-				  ostream.GetOutputStreamBuffer()->GetBufferStart(),
-				  ostream.GetOutputStreamBuffer()->GetBufferSize());
+                                  ostream.GetOutputStreamBuffer()->GetBufferStart(),
+                                  ostream.GetOutputStreamBuffer()->GetBufferSize());
       wxXmlDocument xmlDocument;
       if ((!maximaEnvironmentString.IsEmpty()) && (xmlDocument.Load(istream))) {
         wxXmlNode *headNode = xmlDocument.GetDocumentNode();
@@ -754,7 +754,11 @@ void Configuration::ReadConfig() {
   config->Read("incrementalSearch", &m_incrementalSearch);
   if (m_language == wxLANGUAGE_UNKNOWN)
     m_language = wxLANGUAGE_DEFAULT;
-
+  {
+    long format;
+    if(config->Read("maximaHelpFormat", &format))
+      MaximaHelpFormat(static_cast<maximaHelpFormat>(format));
+  }
   config->Read("invertBackground", &m_invertBackground);
   config->Read("undoLimit", &m_undoLimit);
   config->Read("recentItems", &m_recentItems);
@@ -862,6 +866,17 @@ void Configuration::ReadConfig() {
   ReadStyles();
 }
 
+Configuration::maximaHelpFormat Configuration::MaximaHelpFormat() const
+{
+  if(
+     (m_maximaHelpFormat == frontend) ||
+     (m_maximaHelpFormat == browser) ||
+     (m_maximaHelpFormat == maxima))
+    return m_maximaHelpFormat;
+  else
+    return frontend;
+}
+
 void Configuration::LastActiveTextCtrl(wxTextCtrl *last) {
   m_lastActiveTextCtrl = last;
 }
@@ -895,13 +910,13 @@ void Configuration::MakeStylesConsistent()
   for(const auto &style : GetMathStylesList())
     {
       if((style != TS_ASCIIMATHS) && (style != TS_TEXT))
-	{
-	  m_styles[style].SetFontSize(GetStyle(TS_MATH)->GetFontSize());
-	  m_styles[style].SetFamily(GetStyle(TS_MATH)->GetFamily());
-	  m_styles[style].SetEncoding(GetStyle(TS_MATH)->GetEncoding());
-	  m_styles[style].SetFontName(GetStyle(TS_MATH)->GetFontName());
-	  m_styles[style].CantChangeFontName(true);
-	}
+        {
+          m_styles[style].SetFontSize(GetStyle(TS_MATH)->GetFontSize());
+          m_styles[style].SetFamily(GetStyle(TS_MATH)->GetFamily());
+          m_styles[style].SetEncoding(GetStyle(TS_MATH)->GetEncoding());
+          m_styles[style].SetFontName(GetStyle(TS_MATH)->GetFontName());
+          m_styles[style].CantChangeFontName(true);
+        }
     }
 
   for(const auto &style : GetColorOnlyStylesList())
@@ -990,15 +1005,15 @@ void Configuration::ReportMultipleRedraws() {
   // This sort is over two orders of magnitude faster,
   // per-cell, than having counters in a map or hash.
   std::sort(m_cellRedrawTrace->begin(), m_cellRedrawTrace->end());
-  int counter = 0;
+  size_t counter = 0;
   const Cell *prev = {};
   for (auto *cell : *m_cellRedrawTrace) {
     if (prev != cell) {
       wxASSERT(counter <= 1);
       if (counter > 1)
         wxLogMessage(
-		     "Bug: %i redraws in one screen refresh for a cell reading \"%s\"",
-		     counter, prev->ToString().mb_str());
+                     "Bug: %li redraws in one screen refresh for a cell reading \"%s\"",
+                     static_cast<long>(counter), prev->ToString().mb_str());
       prev = cell;
       counter = 1;
     } else
@@ -1024,14 +1039,15 @@ wxColour Configuration::InvertColour(wxColour col) {
 long Configuration::GetLineWidth() const {
   // The default line width is the width of the viewport minus the indentation
   // minus roughly one char
-  long lineWidth =
+  wxCoord lineWidth =
     GetCanvasSize().x -
-    Scale_Px(GetLabelWidth() + GetCellBracketWidth() + GetDefaultFontSize());
+    Scale_Px(GetLabelWidth()) + Scale_Px(GetCellBracketWidth()) +
+    Scale_Px(GetDefaultFontSize().Get());
 
   // If that was suspiciously wide we reduce the default line width again.
-  if ((lineWidth >= Scale_Px(GetDefaultFontSize()) * LineWidth_em()) &&
+  if ((lineWidth >= Scale_Px(GetDefaultFontSize().Get()) * LineWidth_em()) &&
       (!m_printing))
-    lineWidth = Scale_Px(GetDefaultFontSize()) * LineWidth_em();
+    lineWidth = Scale_Px(GetDefaultFontSize().Get()) * LineWidth_em();
   return lineWidth;
 }
 
@@ -1212,7 +1228,7 @@ void Configuration::ReadStyles(const wxString &file) {
   m_styles[TS_EQUALSSELECTION].Read(config, wxS("Style/EqualsSelection/"));
   m_styles[TS_OUTDATED].Read(config, wxS("Style/Outdated/"));
   m_BackgroundBrush = *wxTheBrushList->FindOrCreateBrush(
-							 m_styles[TS_DOCUMENT_BACKGROUND].GetColor(), wxBRUSHSTYLE_SOLID);
+                                                         m_styles[TS_DOCUMENT_BACKGROUND].GetColor(), wxBRUSHSTYLE_SOLID);
   MakeStylesConsistent();
 }
 
@@ -1233,11 +1249,11 @@ void Configuration::WriteSettings(const wxString &file) {
     for (it = m_maximaEnvVars.begin(); it != m_maximaEnvVars.end(); ++it) {
       if (!it->first.IsEmpty()) {
         wxXmlNode *entryNode =
-	  new wxXmlNode(entriesNode, wxXML_ELEMENT_NODE, "entry");
+          new wxXmlNode(entriesNode, wxXML_ELEMENT_NODE, "entry");
         wxXmlNode *varNode =
-	  new wxXmlNode(entryNode, wxXML_ELEMENT_NODE, "var");
+          new wxXmlNode(entryNode, wxXML_ELEMENT_NODE, "var");
         wxXmlNode *valueNode =
-	  new wxXmlNode(entryNode, wxXML_ELEMENT_NODE, "value");
+          new wxXmlNode(entryNode, wxXML_ELEMENT_NODE, "value");
         new wxXmlNode(varNode, wxXML_TEXT_NODE, wxEmptyString, it->first);
         new wxXmlNode(valueNode, wxXML_TEXT_NODE, wxEmptyString, it->second);
       }
@@ -1248,8 +1264,8 @@ void Configuration::WriteSettings(const wxString &file) {
     wxMemoryOutputStream ostream;
     xmlDoc.Save(ostream);
     wxMemoryInputStream istream(
-				ostream.GetOutputStreamBuffer()->GetBufferStart(),
-				ostream.GetOutputStreamBuffer()->GetBufferSize());
+                                ostream.GetOutputStreamBuffer()->GetBufferStart(),
+                                ostream.GetOutputStreamBuffer()->GetBufferSize());
     wxTextInputStream text(istream);
     wxString maximaEnvConfigString;
     while (!istream.Eof())
@@ -1266,7 +1282,7 @@ void Configuration::WriteSettings(const wxString &file) {
          it != m_hideMarkerForThisMessage.end(); ++it) {
       if (it->second) {
         wxXmlNode *hideNode =
-	  new wxXmlNode(headNode, wxXML_ELEMENT_NODE, "hide");
+          new wxXmlNode(headNode, wxXML_ELEMENT_NODE, "hide");
         new wxXmlNode(hideNode, wxXML_TEXT_NODE, wxEmptyString, it->first);
       }
     }
@@ -1276,8 +1292,8 @@ void Configuration::WriteSettings(const wxString &file) {
     wxMemoryOutputStream ostream;
     xmlDoc.Save(ostream);
     wxMemoryInputStream istream(
-				ostream.GetOutputStreamBuffer()->GetBufferStart(),
-				ostream.GetOutputStreamBuffer()->GetBufferSize());
+                                ostream.GetOutputStreamBuffer()->GetBufferStart(),
+                                ostream.GetOutputStreamBuffer()->GetBufferSize());
     wxTextInputStream text(istream);
     wxString hideMessagesConfigString;
     while (!istream.Eof())
@@ -1286,6 +1302,7 @@ void Configuration::WriteSettings(const wxString &file) {
                   hideMessagesConfigString);
   }
 
+  config->Write("maximaHelpFormat", static_cast<long>(m_maximaHelpFormat));
   config->Write(wxS("Print/Margin/Top"), m_printMargin_Top);
   config->Write(wxS("Print/Margin/Bot"), m_printMargin_Bot);
   config->Write(wxS("Print/Margin/Left"), m_printMargin_Left);
@@ -1339,9 +1356,11 @@ wxColour Configuration::GetColor(TextStyle style) {
   return col;
 }
 
-long Configuration::Scale_Px(double px) const {
-  long retval = lround(px * GetZoomFactor());
-  return std::max(retval, 1l);
+wxCoord Configuration::Scale_Px(double px) const {
+  wxCoord retval = lround(px * GetZoomFactor());
+  if(retval < 1)
+    retval = 1;
+  return retval;
 }
 
 AFontSize Configuration::Scale_Px(AFontSize size) const {
@@ -1354,7 +1373,7 @@ wxColor Configuration::MakeColorDifferFromBackground(wxColor color) {
   if (color == DefaultBackgroundColor()) {
     return InvertColour(color);
   } else {
-    int maxOldCol = wxMax(wxMax(color.Red(), color.Green()), color.Blue());
+    int maxOldCol = std::max(std::max(color.Red(), color.Green()), color.Blue());
     return wxColour(newBrightness * color.Red() / maxOldCol,
                     newBrightness * color.Green() / maxOldCol,
                     newBrightness * color.Blue() / maxOldCol);
@@ -1477,8 +1496,8 @@ bool Configuration::CharVisiblyDifferent(wxChar ch, wxChar otherChar,
         return true;
     }
   wxLogMessage(wxS("Char '%s' looks identical to '%s'."),
-	       wxString(ch).mb_str(),
-	       wxString(otherChar).mb_str());
+               wxString(ch).mb_str(),
+               wxString(otherChar).mb_str());
   return false;
 }
 
@@ -1505,7 +1524,7 @@ bool Configuration::UpdateNeeded() const
 
   return m_configId != configId;
 }
-  
+
 void Configuration::WriteStyles(wxConfigBase *config) {
   std::uniform_int_distribution<long> urd(std::numeric_limits<long>::min(), std::numeric_limits<long>::max());
   m_configId = urd(m_eng);
@@ -1643,7 +1662,7 @@ void Configuration::WriteStyles(const wxString &file) {
     config = wxConfig::Get();
   else
     config = new wxFileConfig(wxS("wxMaxima"), wxEmptyString, file);
-  
+
   WriteStyles(config);
   if (file != wxEmptyString) {
     config->Flush();
