@@ -36,6 +36,7 @@
 #include <random>
 #include <list>
 #include <vector>
+#include <algorithm>
 #include <wx/wupdlock.h>
 #include <wx/webview.h>
 #ifdef __WXMSW__
@@ -54,12 +55,13 @@
 #define PAREN_CLOSE_BOTTOM_UNICODE "\u23a0"
 #define SUM_SIGN "\u2211"
 #define PROD_SIGN "\u220F"
+//! How much to make the font smaller for the sum index and limit?
 #define SUM_DEC 2
 
 //! The width of the horizontally-drawn cursor
 #define MC_HCARET_WIDTH 25
 
-#define MC_EXP_INDENT 2
+#define MC_EXP_INDENT static_cast<wxCoord>(Scale_Px(2))
 static constexpr AFontSize MC_MIN_SIZE{ 6.0f };
 static constexpr AFontSize MC_MAX_SIZE{ 48.0f };
 
@@ -79,19 +81,24 @@ class Cell;
 
   Caching the information here means we don't need to search for the configuration
   value's name every time we need the information: Reading configuration values from
-  the system's configuration storage can be quite time consuming, especially on a 
+  the system's configuration storage can be quite time consuming, especially on a
   MSW with a long registry.
 
-  In order to make all cells temporary listen to a different set of configuration 
-  than the default one all that has to be done is to create a new configuration 
-  object that contains hold the right settings for printing/export as bitmap or 
-  similar: Configuration::Get() will always return the last Configuration that was 
+  In order to make all cells temporary listen to a different set of configuration
+  than the default one all that has to be done is to create a new configuration
+  object that contains hold the right settings for printing/export as bitmap or
+  similar: Configuration::Get() will always return the last Configuration that was
   created and therefore as long as the new configuration object exist will return
   a pointer to this object if configuration is needed.
 */
 class Configuration
 {
 public:
+  enum maximaHelpFormat{
+    maxima = 0,
+    frontend = 1,
+    browser = 2
+  };
   //! The export formats we support for HTML equations
   enum htmlExportFormat
   {
@@ -160,12 +167,12 @@ public:
   void ReadConfig();
 
   /*! The constructor
-    
+
     \param dc The drawing context that is to be used for drawing objects
   */
   explicit Configuration(wxDC *dc = {}, InitOpt options = {});
 
-  void ResetAllToDefaults(InitOpt options = {});
+  void ResetAllToDefaults();
 
   //! Set the drawing context that is currently active
   void SetRecalcContext(wxDC &dc)
@@ -206,7 +213,7 @@ public:
     which line begins a new equation and which line merely continues a multi-line
     equation.
   */
-  double GetInterEquationSkip() const 
+  double GetInterEquationSkip() const
     {
       if (ShowAutomaticLabels())
         return 0;
@@ -214,9 +221,9 @@ public:
         return GetZoomFactor() * m_styles[TS_MATH].GetFontSize() / 2;
     }
 
-  long GetCellBracketWidth() const
+  wxCoord GetCellBracketWidth() const
     {
-      return static_cast<int>(GetZoomFactor() * 16);
+      return static_cast<wxCoord>(GetZoomFactor() * 16);
     }
 
   //! Hide brackets that are not under the pointer?
@@ -254,7 +261,7 @@ public:
 
     Is used for displaying/printing/exporting of text/maths.
   */
-  long Scale_Px(double px) const;
+  wxCoord Scale_Px(double px) const;
   AFontSize Scale_Px(AFontSize size) const;
 
   //! Determines the zoom factor the worksheet is displayed at
@@ -267,7 +274,7 @@ public:
 
   void SetRecalcDC(wxDC *dc)
     { m_dc = dc; }
-  
+
   wxString GetFontName(TextStyle ts = TS_CODE_DEFAULT) const;
 
   // cppcheck-suppress functionStatic
@@ -280,14 +287,14 @@ public:
 
   bool IsUnderlined(long st) const {return m_styles[st].IsUnderlined();}
 
-  long GetLabelWidth() const
+  wxCoord GetLabelWidth() const
     { return m_labelWidth * 14; }
 
   long LabelWidth() const
     { return m_labelWidth; }
   void LabelWidth(long labelWidth)
     { m_labelWidth = labelWidth; }
-  
+
   //! Get the indentation of GroupCells.
   long GetIndent() const
     {
@@ -297,7 +304,7 @@ public:
         return m_indent;
     }
 
-  /*! Get the resolution 
+  /*! Get the resolution
 
     During recalculation the drawing context doesn't know the display's resolution
     so we need to do some additional tricks here.
@@ -321,7 +328,7 @@ public:
       else
         return ppi / 45;
     }
-  
+
   //! The y position the worksheet starts at
   long GetBaseIndent() const
     {
@@ -366,7 +373,7 @@ public:
     {
       m_charsInFont.clear();
     }
-  
+
   //! Calculates the default line width for the worksheet
   double GetDefaultLineWidth() const
     {
@@ -377,7 +384,7 @@ public:
     }
 
   //! The minimum sensible line width in widths of a letter.
-  long LineWidth_em() const 
+  long LineWidth_em() const
     {
       if(!m_printing)
         return m_lineWidth_em;
@@ -419,7 +426,7 @@ public:
     { return false; }
 
   /*! Sets the auto wrap mode
-    \param autoWrap 
+    \param autoWrap
     - 0: No automatic line breaks
     - 1: Automatic line breaks only for text cells
     - 2: Automatic line breaks for text and code cells.
@@ -439,14 +446,14 @@ public:
 
   static const wxString &GetStyleName(TextStyle textStyle);
 
-  /*! Reads the style settings 
+  /*! Reads the style settings
 
     If a file name is given the settings are read from a file.
   */
-  
+
   void ReadStyles(const wxString &file = {});
-  
-  /*! Saves the style settings 
+
+  /*! Saves the style settings
 
     If a file name is given the settings are written to a file.
   */
@@ -490,7 +497,7 @@ public:
     redrawn.
   */
   void SetPrinting(bool printing);
-  
+
   /*! Are we currently printing?
 
     This affects the bitmap scale as well as the fact if we want
@@ -502,12 +509,12 @@ public:
 
   //! Gets the color for a text style
   wxColour GetColor(TextStyle style);
-  
+
   //! Inverts a color: In 2020 wxColor still lacks this functionality
   static wxColour InvertColour(wxColour col);
-  
+
   /*! Make this color differ from the background by a noticeable amount
-    
+
     Useful for black/white background theme changes
   */
   wxColor MakeColorDifferFromBackground(wxColor color);
@@ -519,30 +526,30 @@ public:
   void SetMatchParens(bool matchParens) { m_matchParens = matchParens; }
   bool ShowMatchingParens() const { return m_showMatchingParens; }
   void ShowMatchingParens(bool show) { m_showMatchingParens = show; }
-  
+
   bool GetChangeAsterisk() const{ return m_changeAsterisk; }
-  
+
   void SetChangeAsterisk(bool changeAsterisk) {m_changeAsterisk = changeAsterisk;}
-  
+
   bool HidemultiplicationSign() const {return m_hidemultiplicationsign;}
-  
+
   void HidemultiplicationSign(bool show) {m_hidemultiplicationsign = show;}
-  
+
   bool Latin2Greek() const
     {return m_latin2greek;}
-  
+
   void Latin2Greek(bool latin2greek) {m_latin2greek = latin2greek;}
-  
+
   bool GreekSidebar_ShowLatinLookalikes() const {return m_greekSidebar_ShowLatinLookalikes;}
   void GreekSidebar_ShowLatinLookalikes(bool show){m_greekSidebar_ShowLatinLookalikes = show;}
-  
+
   bool GreekSidebar_Show_mu() const {return m_greekSidebar_Show_mu;}
   void GreekSidebar_Show_mu(bool show) {m_greekSidebar_Show_mu = show;}
-  
+
   wxString SymbolPaneAdditionalChars() const
     {return m_symbolPaneAdditionalChars;}
   void SymbolPaneAdditionalChars(wxString symbols) {m_symbolPaneAdditionalChars = std::move(symbols);}
-  
+
   //! Notify the user if maxima is idle?
   bool NotifyIfIdle() const
     { return m_notifyIfIdle; }
@@ -569,7 +576,7 @@ public:
     FileToSave(const wxString &filename, const wxMemoryBuffer &data):
       m_data(data),
       m_filename(filename)
-      {        
+      {
       }
     const wxString FileName() const{return m_filename;}
     const wxMemoryBuffer Data() const{return m_data;}
@@ -586,7 +593,7 @@ public:
       m_pos(pos),
       m_text(text),
       m_color(color)
-      {        
+      {
       }
     const wxPoint  Pos() const{return m_pos;}
     const wxString Text() const{return m_text;}
@@ -603,6 +610,7 @@ public:
 
   wxRect GetUpdateRegion() const {return m_updateRegion;}
   const std::list<FileToSave> &GetFilesToSave() const {return m_filesToSave;}
+  void ClearFilesToSave () { m_filesToSave.clear();}
   void SetUpdateRegion(wxRect rect){m_updateRegion = rect;}
 
   //! Whether any part of the given rectangle is within the current update region,
@@ -610,7 +618,7 @@ public:
   bool InUpdateRegion(wxRect rect) const;
 
   bool GetInsertAns() const
-    { return m_insertAns; } 
+    { return m_insertAns; }
 
   void SetInsertAns(bool insertAns){ m_insertAns = insertAns; }
 
@@ -648,14 +656,14 @@ public:
 
   bool ShowInputLabels() const {return m_showInputLabels;}
   void ShowInputLabels(bool show) {m_showInputLabels = show;}
-  
+
   bool InvertBackground() const {return m_invertBackground;}
   void InvertBackground(bool invert){ m_invertBackground = invert; }
 
-  long UndoLimit(){return wxMax(m_undoLimit, 0);}
+  long UndoLimit(){return std::max(m_undoLimit, static_cast<long>(0));}
   void UndoLimit(long limit){ m_undoLimit = limit; }
 
-  long RecentItems(){return wxMax(m_recentItems, 0);}
+  long RecentItems(){return std::max(m_recentItems, static_cast<long>(0));}
   void RecentItems(long items){ m_recentItems = items; }
 
   //! Do we want to show maxima's automatic labels (%o1, %t1, %i1,...)?
@@ -665,7 +673,7 @@ public:
   //! Do we want at all to show labels?
   bool UseUserLabels() const
     { return m_showLabelChoice > labels_automatic; }
-  
+
   //! Do we want at all to show labels?
   bool ShowLabels() const
     { return m_showLabelChoice < labels_none; }
@@ -699,7 +707,7 @@ public:
   wxString MaximaUserLocation() const {return m_maximaUserLocation;}
 
   void OnMpBrowse(wxCommandEvent& event);
-  
+
   //! Sets the location of the maxima binary.
   void MaximaUserLocation(wxString maxima) { m_maximaUserLocation = std::move(maxima); }
 
@@ -728,8 +736,8 @@ public:
 
   /*! Could a maxima binary be found in the path we expect it to be in?
 
-    \param location The location to search for maxima in. 
-    If location == wxEmptyString the default location from the configuration 
+    \param location The location to search for maxima in.
+    If location == wxEmptyString the default location from the configuration
     is taken.
   */
   static bool MaximaFound(wxString location = wxEmptyString);
@@ -758,7 +766,7 @@ public:
 
   bool CopyBitmap() const {return m_copyBitmap;}
   void CopyBitmap(bool copyBitmap){ m_copyBitmap = copyBitmap; }
-  
+
   bool CopyMathML() const {return m_copyMathML;}
   void CopyMathML(bool copyMathML){ m_copyMathML = copyMathML;}
   bool CopyMathMLHTML() const {return m_copyMathMLHTML;}
@@ -778,10 +786,10 @@ public:
   long ShowLength() const {return m_showLength;}
   void LispType(wxString type) { m_lispType = std::move(type); }
   wxString LispType() const {return m_lispType;}
-  
+
   //! Which way do we want to draw parenthesis?
   void SetParenthesisDrawMode(drawMode mode) { m_parenthesisDrawMode = mode; }
-  
+
   void TocShowsSectionNumbers(bool showSectionNumbers) { m_TOCshowsSectionNumbers = showSectionNumbers; }
 
   bool TocShowsSectionNumbers() const {return m_TOCshowsSectionNumbers;}
@@ -789,7 +797,7 @@ public:
   void UseUnicodeMaths(bool useunicodemaths)
     { m_useUnicodeMaths = useunicodemaths; }
   bool UseUnicodeMaths() const {return m_useUnicodeMaths;}
-  
+
   StringBoolHash m_hideMarkerForThisMessage;
 
   /*! Get the text Style for a given text style identifier.
@@ -815,10 +823,10 @@ public:
   void DefaultPort(long port){m_defaultPort = port;}
   bool GetAbortOnError() const {return m_abortOnError;}
   void SetAbortOnError(bool abortOnError) {m_abortOnError = abortOnError;}
-  
+
   long GetLanguage() const {return m_language;}
   void SetLanguage(long language) {m_language = language;}
-  
+
   //! The maximum number of Megabytes of gnuplot sources we should store
   long MaxGnuplotMegabytes() const {return m_maxGnuplotMegabytes;}
   void MaxGnuplotMegabytes(long megaBytes)
@@ -827,13 +835,13 @@ public:
   bool OfferKnownAnswers() const {return m_offerKnownAnswers;}
   void OfferKnownAnswers(bool offerKnownAnswers)
     {m_offerKnownAnswers = offerKnownAnswers;}
-  
+
   wxString Documentclass() const {return m_documentclass;}
   void Documentclass(wxString clss){m_documentclass = std::move(clss);}
   wxString DocumentclassOptions() const {return m_documentclassOptions;}
   void DocumentclassOptions(wxString classOptions){m_documentclassOptions = std::move(classOptions);}
 
-  
+
   htmlExportFormat HTMLequationFormat() const {return m_htmlEquationFormat;}
   void HTMLequationFormat(htmlExportFormat HTMLequationFormat)
     {m_htmlEquationFormat = HTMLequationFormat;}
@@ -882,7 +890,7 @@ public:
   //! Clear the memory of ReportMultipleRedraws()
   void ClearAndEnableRedrawTracing();
   /*! Report if a cell has been redrawn 2 or more times during a simple Draw() command
-    
+
     Only used in debug mode; If a cell is drawn and then re-drawn in the same draw
     command this most likely means that a 2D-displayed cell draws its sub-cells,
     but didn't remove them from the Cell::NextToDraw()-list of cells to draw
@@ -902,7 +910,7 @@ public:
   int  MaxClipbrdBitmapMegabytes() const {return m_maxClipbrd_BitmapMegabytes;}
   void MaxClipbrdBitmapMegabytes(int maxClipbrd_BitmapMegabytes)
     {m_maxClipbrd_BitmapMegabytes = maxClipbrd_BitmapMegabytes;}
-  
+
   void MaximaUsesHtmlBrowser(bool maximaUsesHhtmlBrowser){m_maximaUsesHhtmlBrowser = maximaUsesHhtmlBrowser;}
   bool MaximaUsesHtmlBrowser() const {return m_maximaUsesHhtmlBrowser;}
   void MaximaUsesWxmaximaBrowser(bool maximaUsesWxmaximaBrowser){m_maximaUsesWxmaximaBrowser = maximaUsesWxmaximaBrowser;}
@@ -938,6 +946,8 @@ public:
   static void SetDebugmode(){m_debugMode = true;}
   //! Enable costly checks?
   static bool GetDebugmode(){return m_debugMode;}
+  maximaHelpFormat MaximaHelpFormat() const;
+  void MaximaHelpFormat(maximaHelpFormat format) {m_maximaHelpFormat = format;}
 
 private:
   /*! The id of the current configuration
@@ -947,7 +957,7 @@ private:
   */
   long m_configId;
 public:
- //! Our random device
+  //! Our random device
   std::random_device m_rd;
   //! Our random engine
   std::default_random_engine m_eng;
@@ -993,14 +1003,14 @@ private:
   long m_autoSubscript;
   //! The worksheet this configuration storage is valid for
   wxWindow *m_workSheet = NULL;
-  //! A drawing context that knows the text sizes for the worksheet 
+  //! A drawing context that knows the text sizes for the worksheet
   std::unique_ptr<wxClientDC> m_worksheetDC;
   /*! Do these chars exist in the given font?
 
     wxWidgets currently doesn't define such a function. But we can do the following:
     - Test if any of these characters has the width or height 0 (or even less)
     which clearly indicates that this char doesn't exist.
-    - Test if any two of the characters are equal when rendered as bitmaps: 
+    - Test if any two of the characters are equal when rendered as bitmaps:
     If they are we most probably didn't get render real characters but rather
     render placeholders for characters.
 
@@ -1034,7 +1044,7 @@ private:
   //! Prlong the cell brackets [displayed left to each group cell showing its extend]?
   bool m_printBrackets;
   /*! Replace a "*" by a centered dot?
-    
+
     Normally we ask the parser for this piece of information. But during recalculation
     of widths while selecting text we don't know our parser.
   */
@@ -1050,7 +1060,7 @@ private:
   //! Always show all digits of all numbers?
   bool m_showAllDigits;
   //! Allow linebreaks in numbers that are longer than a line?
-  bool m_lineBreaksInLongNums;  
+  bool m_lineBreaksInLongNums;
   //! Do we want to automatically close parenthesis?
   bool m_matchParens;
   //! Do we want to automatically insert new cells containing a "%" at the end of every command?
@@ -1139,7 +1149,7 @@ private:
   int m_maxClipbrd_BitmapMegabytes;
   int m_autoSaveMinutes;
   wxString m_wxMathML_Filename;
-
+  maximaHelpFormat m_maximaHelpFormat;
   wxTextCtrl *m_lastActiveTextCtrl = NULL;
 };
 
