@@ -21,10 +21,10 @@
 //
 //  SPDX-License-Identifier: GPL-2.0+
 
-/*! \file 
+/*! \file
   The evaluation queue
 
-  The class EvaluationQueue that is declared here handles the queue of commands 
+  The class EvaluationQueue that is declared here handles the queue of commands
   that still have to be sent to maxima.
 */
 
@@ -45,9 +45,9 @@ private:
   class Command{
   public:
     Command(const wxString &strng, int index) : m_indexStart(index), m_command(strng) {}
-    Command(Command &&o) : m_indexStart(o.m_indexStart), m_command(std::move(o.m_command)) {}
+    Command(Command &&o) noexcept : m_indexStart(o.m_indexStart), m_command(std::move(o.m_command)) {}
     Command(const Command &o) : m_indexStart(o.m_indexStart), m_command(o.m_command) {}
-    Command &operator=(Command &&o)
+    Command &operator=(Command &&o) noexcept
       {
         m_indexStart = o.m_indexStart;
         m_command = std::move(o.m_command);
@@ -67,9 +67,9 @@ private:
     int m_indexStart;
     wxString m_command;
   };
-    
+
   /*! A list of all the commands in the current cell
-    
+
     We need to track each single command:
     - If we send more than one command at once maxima will interpret the command
     as an answer to an eventual question and
@@ -86,7 +86,7 @@ private:
   void AddTokens(const GroupCell *cell);
 
 public:
-  /*! Query for the label the user has assigned to the current command.  
+  /*! Query for the label the user has assigned to the current command.
 
     If there is no such label or the label as hidden deep down inside the command
     (in which case we assume the user wanted to hide it and for example didn't use
@@ -112,7 +112,7 @@ public:
       if (!m_commands.empty())
         m_commands.back().AddEnding();
     }
-  
+
   ~EvaluationQueue()
     {};
 
@@ -130,7 +130,7 @@ public:
 
   //! Remove a GroupCell from the evaluation queue.
   void Remove(GroupCell *gr);
-  
+
   //! Adds all hidden cells attached to the GroupCell gr to the evaluation queue.
   void AddHiddenTreeToQueue(const GroupCell *gr);
 
