@@ -1,3 +1,29 @@
+// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
+//
+//  Copyright (C) 2014-2018 Gunter Königsmann <wxMaxima@physikbuch.de>
+//
+//  This program is free software; you can redistribute it and/or modify
+//  it under the terms of the GNU General Public License as published by
+//  the Free Software Foundation; either version 2 of the License, or
+//  (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU General Public License for more details.
+//
+//
+//  You should have received a copy of the GNU General Public License
+//  along with this program; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
+//  SPDX-License-Identifier: GPL-2.0+
+
+/*!\file
+
+  This file defines the class EventIDs that contains unique IDs for many events
+  wxMaxima needs.
+*/
 #include "EventIDs.h"
 #include <wx/utils.h>
 #include <wx/window.h>
@@ -233,6 +259,8 @@ const wxWindowIDRef EventIDs::menu_structs(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_dependencies(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_gradefs(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_let_rule_packages(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_wxmaxima_uses_help_sidebar(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_wxmaxima_uses_help_browser(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_maxima_uses_internal_help(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_maxima_uses_html_help(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_maxima_uses_wxmaxima_help(wxWindow::NewControlId());
@@ -283,6 +311,8 @@ const wxWindowIDRef EventIDs::menu_jumptoerror(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_math_as_1D_ASCII(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_math_as_2D_ASCII(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_math_as_graphics(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::internalRepresentation(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::wxMathML(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_logexpand_false(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_logexpand_true(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_logexpand_all(wxWindow::NewControlId());
@@ -350,6 +380,8 @@ const wxWindowIDRef EventIDs::menu_add_path(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_evaluate_all_visible(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_evaluate_all(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_show_tip(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_show_cellbrackets(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_print_cellbrackets(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_copy_matlab_from_worksheet(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_copy_tex_from_worksheet(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_copy_text_from_worksheet(wxWindow::NewControlId());
