@@ -20,17 +20,17 @@
 //  SPDX-License-Identifier: GPL-2.0+
 
 /*!\file
-  
-  This file defines the class EventIDs that contains unique IDs for many events
+
+  This file declares the class EventIDs that contains unique IDs for many events
   wxMaxima needs.
 
   EventIDs have proven to be a weird thing since
-   - everything has an ID (-1 or wxID_ANY tells wxWidgets to pick a new ID,
-     automatically)
-   - Windows allows only for 16-bit-IDs
-   - and since dynamic contents can consist of thousands of items and
-     sub-items at a time it is highly probable that IDs need to be re-used
-     frequently.
+  - everything has an ID (-1 or wxID_ANY tells wxWidgets to pick a new ID,
+  automatically)
+  - Windows allows only for 16-bit-IDs
+  - and since dynamic contents can consist of thousands of items and
+  sub-items at a time it is highly probable that IDs need to be re-used
+  frequently.
 
   We therefore need to be careful that wxWidgets knows what IDs are currently
   in use and that wxWidgets doesn't believe we have finished using one ID we will
@@ -71,14 +71,14 @@ public:
 
 
   /*! Hide all panes
-    
-    This event is assigned an ID higher than the highest ID wxWidgets assigns to 
+
+    This event is assigned an ID higher than the highest ID wxWidgets assigns to
     its internal events in order to avoid ID clashes.
   */
   static const wxWindowIDRef menu_pane_hideall;
   /*! Both used as the "toggle the math pane" command and as the ID of the math pane
 
-    Since this enum is also used for iterating over the panes it is vital 
+    Since this enum is also used for iterating over the panes it is vital
     that this entry stays that of the first pane in this enum.
   */
   static const wxWindowIDRef wizard_parametric_plot;
@@ -104,7 +104,7 @@ public:
   static const wxWindowIDRef menu_pane_console ;   //!< The id for the worksheet
   /*! Both used as the "toggle the stats pane" command and as the ID of the stats pane
 
-    Since this enum is also used for iterating over the panes it is vital 
+    Since this enum is also used for iterating over the panes it is vital
     that this entry stays that of the last pane in this enum.
   */
   static const wxWindowIDRef menu_pane_stats;
@@ -323,6 +323,8 @@ public:
   static const wxWindowIDRef menu_dependencies;
   static const wxWindowIDRef menu_gradefs;
   static const wxWindowIDRef menu_let_rule_packages;
+  static const wxWindowIDRef menu_wxmaxima_uses_help_sidebar;
+  static const wxWindowIDRef menu_wxmaxima_uses_help_browser;
   static const wxWindowIDRef menu_maxima_uses_internal_help;
   static const wxWindowIDRef menu_maxima_uses_html_help;
   static const wxWindowIDRef menu_maxima_uses_wxmaxima_help;
@@ -373,6 +375,8 @@ public:
   static const wxWindowIDRef menu_math_as_1D_ASCII;
   static const wxWindowIDRef menu_math_as_2D_ASCII;
   static const wxWindowIDRef menu_math_as_graphics;
+  static const wxWindowIDRef internalRepresentation;
+  static const wxWindowIDRef wxMathML;
   static const wxWindowIDRef menu_logexpand_false;
   static const wxWindowIDRef menu_logexpand_true;
   static const wxWindowIDRef menu_logexpand_all;
@@ -440,6 +444,8 @@ public:
   static const wxWindowIDRef menu_evaluate_all_visible;
   static const wxWindowIDRef menu_evaluate_all;
   static const wxWindowIDRef menu_show_tip;
+  static const wxWindowIDRef menu_show_cellbrackets;
+  static const wxWindowIDRef menu_print_cellbrackets;
   static const wxWindowIDRef menu_copy_matlab_from_worksheet;
   static const wxWindowIDRef menu_copy_tex_from_worksheet;
   static const wxWindowIDRef menu_copy_text_from_worksheet;
@@ -477,7 +483,7 @@ public:
   static const wxWindowIDRef menu_loadLisp;
   static const wxWindowIDRef menu_maximatostring;
   static const wxWindowIDRef menu_stringtomaxima;
-    
+
   static const wxWindowIDRef button_enter;
   static const wxWindowIDRef menu_zoom_80;
   /* Instead of menu_zoom_100 we use the standard static const int _ZOOM_100; which displays an icon in the menu (currently Unix only) */
@@ -746,10 +752,10 @@ public:
   static const wxWindowIDRef popid_var_newVar;
   static const wxWindowIDRef popid_var_addAll;
   static const wxWindowIDRef popid_addToSymbols;
-  
+
 private:
 /*! @}
-   */
+ */
 };
 
 #endif // EVENTIDS_H
