@@ -46,11 +46,11 @@ FindReplacePane::FindReplacePane(wxWindow *parent, FindReplaceData *data)
 
   grid_sizer->Add(new wxStaticText(this, -1, _("Find:")),
                   wxSizerFlags().Right().Center().Border(wxALL, 5));
-  
+
   m_searchText = new wxTextCtrl(this, -1, data->GetFindString());
   m_searchText->Connect(
-			wxEVT_TEXT, wxCommandEventHandler(FindReplacePane::OnFindStringChange),
-			NULL, this);
+                        wxEVT_TEXT, wxCommandEventHandler(FindReplacePane::OnFindStringChange),
+                        NULL, this);
   grid_sizer->Add(m_searchText, wxSizerFlags(1).Expand().Border(wxALL, 5));
 
   m_searchButton = new wxButton(this, wxID_FIND);
@@ -64,8 +64,8 @@ FindReplacePane::FindReplacePane(wxWindow *parent, FindReplaceData *data)
 
   m_replaceText = new wxTextCtrl(this, -1, data->GetReplaceString());
   m_replaceText->Connect(
-			 wxEVT_TEXT, wxCommandEventHandler(FindReplacePane::OnReplaceStringChange),
-			 NULL, this);
+                         wxEVT_TEXT, wxCommandEventHandler(FindReplacePane::OnReplaceStringChange),
+                         NULL, this);
   grid_sizer->Add(m_replaceText, wxSizerFlags(1).Expand().Border(wxALL, 5));
   m_matchCase = new wxCheckBox(this, -1, _("Match Case"));
   lefttop_sizer->Add(grid_sizer, wxSizerFlags(1).Expand());
@@ -84,19 +84,19 @@ FindReplacePane::FindReplacePane(wxWindow *parent, FindReplaceData *data)
   m_backwards = new wxRadioButton(this, -1, _("Down"));
   fbbox->Add(m_backwards, wxSizerFlags().Expand().Border(wxALL, 5));
   m_regexSearch = new wxRadioButton(this, -1, _("Regex"), wxDefaultPosition,
-                                wxDefaultSize, wxRB_GROUP);
+                                    wxDefaultSize, wxRB_GROUP);
   fbbox->Add(m_regexSearch, wxSizerFlags().Expand().Border(wxALL, 5));
   m_simpleSearch = new wxRadioButton(this, -1, _("Simple"));
   fbbox->Add(m_simpleSearch, wxSizerFlags().Expand().Border(wxALL, 5));
 
   m_regexSearch->SetValue((data->GetRegexSearch()));
   m_regexSearch->Connect(wxEVT_RADIOBUTTON,
-			 wxCommandEventHandler(FindReplacePane::OnRegexSimpleChange),
-			 NULL, this);
+                         wxCommandEventHandler(FindReplacePane::OnRegexSimpleChange),
+                         NULL, this);
   m_simpleSearch->SetValue(!(data->GetRegexSearch()));
   m_simpleSearch->Connect(wxEVT_RADIOBUTTON,
-			  wxCommandEventHandler(FindReplacePane::OnRegexSimpleChange),
-			  NULL, this);
+                          wxCommandEventHandler(FindReplacePane::OnRegexSimpleChange),
+                          NULL, this);
   m_matchCase->Enable(!m_regexSearch->GetValue());
   if(m_regexSearch->GetValue())
     m_matchCase->SetValue(true);
@@ -109,14 +109,14 @@ FindReplacePane::FindReplacePane(wxWindow *parent, FindReplaceData *data)
                      wxCommandEventHandler(FindReplacePane::OnDirectionChange),
                      NULL, this);
   m_backwards->Connect(
-		       wxEVT_RADIOBUTTON,
-		       wxCommandEventHandler(FindReplacePane::OnDirectionChange), NULL, this);
+                       wxEVT_RADIOBUTTON,
+                       wxCommandEventHandler(FindReplacePane::OnDirectionChange), NULL, this);
 
   m_replaceAllButton = new wxButton(this, 1, _("Replace All"));
   button_sizer->Add(m_replaceAllButton, wxSizerFlags().Expand().Border(wxALL, 5));
   m_replaceAllButton->Connect(
-			      wxEVT_BUTTON, wxCommandEventHandler(FindReplacePane::OnReplaceAll), NULL,
-			      this);
+                              wxEVT_BUTTON, wxCommandEventHandler(FindReplacePane::OnReplaceAll), NULL,
+                              this);
   top_sizer->Add(lefttop_sizer, wxSizerFlags(1).Expand());
   top_sizer->Add(button_sizer, wxSizerFlags());
 
@@ -130,7 +130,7 @@ FindReplacePane::FindReplacePane(wxWindow *parent, FindReplaceData *data)
   // replacement text box immediately.
   m_replaceText->MoveAfterInTabOrder(m_searchText);
   Connect(wxEVT_ACTIVATE, wxActivateEventHandler(FindReplacePane::OnActivate),
-	  NULL, this);
+          NULL, this);
   m_activateDuringConstruction = true;
   Connect(wxEVT_CHAR_HOOK, wxKeyEventHandler(FindReplacePane::OnKeyDown), NULL,
           this);
@@ -203,8 +203,8 @@ void FindReplacePane::OnRegexSimpleChange(wxCommandEvent &event){
 
 void FindReplacePane::OnMatchCase(wxCommandEvent &event) {
   m_findReplaceData->SetFlags(
-			      (m_findReplaceData->GetFlags() & (~wxFR_MATCHCASE)) |
-			      (event.IsChecked() * wxFR_MATCHCASE));
+                              (m_findReplaceData->GetFlags() & (~wxFR_MATCHCASE)) |
+                              (event.IsChecked() * wxFR_MATCHCASE));
   wxConfig::Get()->Write(wxS("findFlags"), m_findReplaceData->GetFlags());
 }
 
@@ -216,10 +216,18 @@ void FindReplacePane::OnActivate(wxActivateEvent &event) {
       return;
     }
   if (event.GetActive())
-    SetTransparent(255);
+    {
+      SetTransparent(255);
+      // Call m_searchText->SetFocus(), once this event is over: During the
+      // activation event it seems to be unreliable
+      CallAfter([this]{m_searchText->SetFocus();});
+      m_active = true;
+    }
   else
-    SetTransparent(180);
-  m_active = true;
+    {
+      SetTransparent(180);
+      m_active = false;
+    }
 }
 
 void FindReplacePane::OnFindStringChange(wxCommandEvent &event) {
@@ -230,13 +238,12 @@ void FindReplacePane::OnFindStringChange(wxCommandEvent &event) {
       wxLogNull suppressor;
       wxRegEx test(m_searchText->GetValue());
       if(test.IsValid())
-	m_searchText->SetForegroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
+        m_searchText->SetForegroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
       else
-	m_searchText->SetForegroundColour(wxColor(255, 165, 0));
+        m_searchText->SetForegroundColour(wxColor(255, 165, 0));
     }
   else
     m_searchText->SetForegroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
-  
 }
 
 void FindReplacePane::OnReplaceStringChange(wxCommandEvent &WXUNUSED(event)) {
