@@ -48,7 +48,7 @@ History::History(wxWindow *parent, int id, Configuration *cfg)
   // Windows
   m_history =
     new wxListBox(this, history_ctrl_id, wxDefaultPosition, wxDefaultSize, 0,
-		  NULL, wxLB_EXTENDED | wxLB_HSCROLL | wxLB_NEEDED_SB);
+                  NULL, wxLB_EXTENDED | wxLB_HSCROLL | wxLB_NEEDED_SB);
   m_regex = new RegexCtrl(this, wxID_ANY, cfg);
   wxBoxSizer *box = new wxBoxSizer(wxVERTICAL);
 
@@ -76,8 +76,8 @@ void History::OnMouseRightDown(wxMouseEvent &WXUNUSED(event)) {
   if (m_commands.size() > 0) {
     popupMenu.Append(export_all, _("Export all history to a .mac file"));
     popupMenu.Append(
-		     export_session,
-		     _("Export commands from the current maxima session to a .mac file"));
+                     export_session,
+                     _("Export commands from the current maxima session to a .mac file"));
     if (hasSelections)
       popupMenu.Append(export_selected,
                        _("Export selected commands to a .mac file"));
@@ -251,19 +251,17 @@ wxString History::GetCommand(bool next) {
   return m_history->GetString(m_current);
 }
 
-void History::SetCurrent(long current) {
-  auto const count = long(m_history->GetCount());
-  if (current < 0)
-    current = count - 1;
-  else if (current >= count)
+void History::SetCurrent(std::size_t current) {
+  auto const count = m_history->GetCount();
+  if (current >= count)
     current = 0;
   if (count < 1)
-    current = -1;
+    current = 0;
 
   if (current == m_current)
     return;
 
-  if (current >= 0) {
+  if (current > 0) {
     m_current = current;
     m_history->EnsureVisible(m_current);
     UnselectAll();
