@@ -28,38 +28,19 @@
 #include "precomp.h"
 #include "Cell.h"
 #include "Version.h"
+#include "ErrorRedirector.h"
 #include <wx/image.h>
 #include <wx/rawbmp.h>
 
-#include <wx/filesys.h>
 #include <wx/fs_arc.h>
 #include <wx/buffer.h>
 #define NANOSVG_ALL_COLOR_KEYWORDS
-#include "nanoSVG/nanosvg.h"
-#include "nanoSVG/nanosvgrast.h"
+#include "nanosvg_private.h"
+#include "nanosvgrast_private.h"
 #include <Image.h>
-
-/* The nanosvg .h files contain both the header and the implementation.
-   In exactly one file of the project need to be defined in order to
-   make the implementation visible to the compiler.
-
-   In wxWidgets >3.1.6 this is done in wxWidgets itself so we need to
-   skip that step there.
-
-   So that should work. But for Linux builds with 3.1.6 I get linking errors,
-   e.g.: undefined reference to `nsvgRasterize' Therefore do not define
-   NANOSVG_IMPLEMENTATION/NANOSVGRAST_IMPLEMENTATION only for Windows. That is
-   probably not correct (a FIXME), but I have no idea, why Linux still requires
-   that NANOSVG_IMPLEMENTATION/NANOSVGRAST_IMPLEMENTATION is defined.
-
-*/
-#if (wxCHECK_VERSION(3, 1, 6)) && defined(__WINDOWS__)
-#else
-#define NANOSVG_IMPLEMENTATION
-#define NANOSVGRAST_IMPLEMENTATION
-#endif
-
-#include "ErrorRedirector.h"
+#include <vector>
+#include <utility>
+#include "wx/log.h"
 #include "StringUtils.h"
 #include "SvgBitmap.h"
 #include <wx/mstream.h>
@@ -71,14 +52,7 @@
 
 Image::Image(Configuration *config) {
   m_configuration = config;
-  m_width = 1;
-  m_height = 1;
-  m_originalWidth = 640;
-  m_originalHeight = 480;
-  m_scaledBitmap.Create(1, 1);
-  m_isOk = false;
-  m_maxWidth = -1;
-  m_maxHeight = -1;
+  InvalidBitmap();
 }
 
 Image::Image(Configuration *config, wxMemoryBuffer image, wxString type) {
@@ -86,70 +60,48 @@ Image::Image(Configuration *config, wxMemoryBuffer image, wxString type) {
   m_scaledBitmap.Create(1, 1);
   m_compressedImage = image;
   m_extension = type;
-  m_isOk = false;
-  m_width = 1;
-  m_height = 1;
-  m_originalWidth = 640;
-  m_originalHeight = 480;
 
+  wxLogBuffer errorAggregator;
   wxImage Image;
   if (m_compressedImage.GetDataLen() > 0) {
     wxMemoryInputStream istream(m_compressedImage.GetData(),
                                 m_compressedImage.GetDataLen());
+    Image.LoadFile(istream);
+    if(Image.IsOk())
     {
-      SuppressErrorDialogs logNull;
-      Image.LoadFile(istream);
+      m_originalWidth = Image.GetWidth();
+      m_originalHeight = Image.GetHeight();
+    }
+    else
+    {
+      InvalidBitmap(errorAggregator.GetBuffer());
     }
-    m_isOk = Image.IsOk();
-    m_originalWidth = Image.GetWidth();
-    m_originalHeight = Image.GetHeight();
   } else
-    InvalidBitmap();
-  m_maxWidth = -1;
-  m_maxHeight = -1;
+    InvalidBitmap(_("Image data had zero length!"));
 }
 
 Image::Image(Configuration *config, const wxBitmap &bitmap) {
   m_configuration = config;
-  m_isOk = false;
-  m_width = 1;
-  m_height = 1;
-  m_maxWidth = -1;
-  m_maxHeight = -1;
-  m_originalWidth = 640;
-  m_originalHeight = 480;
   LoadImage(bitmap);
   m_scaledBitmap.Create(1, 1);
 }
 
 // constructor which loads an image
-// filesystem cannot be passed by const reference as we want to keep the
-// pointer to the file system alive in a background task
 // cppcheck-suppress performance symbolName=filesystem
 Image::Image(Configuration *config, wxString image,
-             std::shared_ptr<wxFileSystem> &filesystem, bool remove)
+             wxString wxmxFile, bool remove)
 {
   m_svgImage = NULL;
   m_configuration = config;
   m_scaledBitmap.Create(1, 1);
-  m_isOk = false;
-  m_width = 1;
-  m_height = 1;
-  m_maxWidth = -1;
-  m_maxHeight = -1;
-  m_originalWidth = 640;
-  m_originalHeight = 480;
   m_ppi = m_configuration->GetPPI().x;
-  LoadImage(image, filesystem, remove);
+  LoadImage(image, wxmxFile, remove);
 }
 
 Image::Image(Configuration *config, const Image &image) {
   m_svgImage = NULL;
   m_configuration = config;
   m_scaledBitmap.Create(1, 1);
-  m_isOk = image.m_isOk;
-  m_width = 1;
-  m_height = 1;
   m_maxWidth = image.m_maxWidth;
   m_maxHeight = image.m_maxHeight;
   m_originalWidth = image.m_originalWidth;
@@ -160,13 +112,12 @@ Image::Image(Configuration *config, const Image &image) {
 }
 
 Image::~Image() {
+  SuppressErrorDialogs logNull;
   if(m_loadImageTask.joinable())
     m_loadImageTask.join();
   if(m_loadGnuplotSourceTask.joinable())
     m_loadGnuplotSourceTask.join();
-  m_isOk = false;
   if (!m_gnuplotSource.IsEmpty()) {
-    SuppressErrorDialogs logNull;
     if (wxFileExists(m_gnuplotSource))
     {
       if(!wxRemoveFile(m_gnuplotSource))
@@ -179,18 +130,15 @@ Image::~Image() {
       if(!wxRemoveFile(popoutname))
         wxLogMessage(_("Failed to delete gnuplot file %s"),
                      popoutname.utf8_str());
-
     }
   }
 
   if (!m_gnuplotData.IsEmpty()) {
-    SuppressErrorDialogs logNull;
     if (wxFileExists(m_gnuplotData))
     {
       if(!wxRemoveFile(m_gnuplotData))
         wxLogMessage(_("Failed to delete gnuplot data file %s"),
                      m_gnuplotData.utf8_str());
-
     }
   }
   if (m_svgImage)
@@ -212,19 +160,15 @@ wxMemoryBuffer Image::ReadCompressedImage(wxInputStream *data) {
 wxBitmap Image::GetUnscaledBitmap() {
   if(m_loadImageTask.joinable())
     m_loadImageTask.join();
-  if (!m_isOk) {
-    InvalidBitmap();
-    return m_scaledBitmap;
-  }
 
   SuppressErrorDialogs logNull;
   if (m_svgRast) {
     std::vector<unsigned char> imgdata(m_originalWidth * m_originalHeight * 4);
 
-    nsvgRasterize(m_svgRast.get(), m_svgImage, 0, 0, 1, imgdata.data(),
-                  m_originalWidth, m_originalHeight, m_originalWidth * 4);
+    wxm_nsvgRasterize(m_svgRast.get(), m_svgImage, 0, 0, 1, imgdata.data(),
+                      m_originalWidth, m_originalHeight, m_originalWidth * 4);
     return RGBA2wxBitmap(imgdata.data(), m_originalWidth,
-                                    m_originalHeight);
+                         m_originalHeight);
   } else {
     wxMemoryInputStream istream(m_compressedImage.GetData(),
                                 m_compressedImage.GetDataLen());
@@ -242,31 +186,22 @@ const wxMemoryBuffer Image::GetCompressedImage() const {
   return m_compressedImage;
 }
 
-size_t Image::GetOriginalWidth() const {
+std::size_t Image::GetOriginalWidth() const {
   if(m_loadImageTask.joinable())
     m_loadImageTask.join();
-  
+
   return m_originalWidth;
 }
 
-size_t Image::GetOriginalHeight() const {
-    if(m_loadImageTask.joinable())
+std::size_t Image::GetOriginalHeight() const {
+  if(m_loadImageTask.joinable())
     m_loadImageTask.join();
 
-    return m_originalHeight;
+  return m_originalHeight;
 }
 
-bool Image::IsOk() const {
-    if(m_loadImageTask.joinable())
-    m_loadImageTask.join();
-return m_isOk;
-}
-
-// filesystem cannot be passed by const reference as we want to keep the
-// pointer to the file system alive in a background task
-// cppcheck-suppress performance symbolName=filesystem
 void Image::GnuplotSource(wxString gnuplotFilename, wxString dataFilename,
-                          std::shared_ptr<wxFileSystem> &filesystem) {
+                          wxString wxmxFile) {
   SuppressErrorDialogs suppressor;
   if(m_loadGnuplotSourceTask.joinable())
     m_loadGnuplotSourceTask.join();
@@ -274,203 +209,174 @@ void Image::GnuplotSource(wxString gnuplotFilename, wxString dataFilename,
   m_gnuplotData = std::move(dataFilename);
   std::unique_ptr<ThreadNumberLimiter> limiter(new
                                                ThreadNumberLimiter(&m_gnuplotDataThreadRunning));
-  if (filesystem == NULL) {
-    m_loadGnuplotSourceTask = std::thread(&Image::LoadGnuplotSource_Backgroundtask2,
-                                          this,
-                                          std::move(limiter),
-                                          m_gnuplotSource, m_gnuplotData);
+  m_loadGnuplotSourceTask = std::thread(&Image::LoadGnuplotSource_Backgroundtask,
+                                        this,
+                                        std::move(limiter),
+                                        m_gnuplotSource, m_gnuplotData, wxmxFile);
+}
+
+void Image::LoadGnuplotSource_Backgroundtask(
+  std::unique_ptr<ThreadNumberLimiter> limiter,
+  wxString gnuplotFile, wxString dataFile, wxString wxmxFile)
+{
+  SuppressErrorDialogs suppressor;
+  if(wxmxFile.IsEmpty())
+  {
+    {
+      wxFileInputStream source(gnuplotFile);
+      LoadGnuplotSource(&source);
+    }
+    {
+      wxFileInputStream data(dataFile);
+      LoadGnuplotData(&data);
+    }
+  }
+  else
+  {
+    {
+      wxFileInputStream wxmx(wxmxFile);
+      WxmxStream source(wxmx, gnuplotFile);
+      LoadGnuplotSource(&source);
+    }
+    {
+      wxFileInputStream wxmx(wxmxFile);
+      WxmxStream data(wxmx, dataFile);
+      LoadGnuplotData(&data);
+    }
   }
-  else {
-    std::unique_ptr<wxFSFile> sourcefile(filesystem->OpenFile(m_gnuplotSource));
-    std::shared_ptr<wxInputStream> source;
-    if (sourcefile)
-      source = std::shared_ptr<wxInputStream> (sourcefile->DetachStream());
-    std::unique_ptr<wxFSFile> datafile(filesystem->OpenFile(m_gnuplotData));
-    std::shared_ptr<wxInputStream> data;
-    if (datafile)
-      data = std::shared_ptr<wxInputStream> (datafile->DetachStream());
-    m_loadGnuplotSourceTask = std::thread(&Image::LoadGnuplotSource_Backgroundtask1,
-                                          this,
-                                          std::move(limiter),
-                                          filesystem, source, data);
-  } 
 }
 
 void Image::CompressedGnuplotSource(wxString gnuplotFilename, wxString dataFilename,
-                                    std::shared_ptr<wxFileSystem> &filesystem) {
+                                    wxString wxmxFile) {
   if(m_loadGnuplotSourceTask.joinable())
     m_loadGnuplotSourceTask.join();
   std::unique_ptr<ThreadNumberLimiter> limiter(new
-                                               ThreadNumberLimiter(&m_gnuplotDataThreadRunning)); 
+                                               ThreadNumberLimiter(&m_gnuplotDataThreadRunning));
 
-    // Store the filenames without the ".gz".
   m_gnuplotSource = std::move(gnuplotFilename);
   m_gnuplotData = std::move(dataFilename);
-  if(m_gnuplotSource.EndsWith(".gz"))
-    m_gnuplotSource = m_gnuplotSource.Left(m_gnuplotSource.Length()-3);
-  if(m_gnuplotData.EndsWith(".gz"))
-    m_gnuplotData = m_gnuplotData.Left(m_gnuplotData.Length()-3);
-
-  
   m_loadGnuplotSourceTask =
     std::thread(&Image::LoadCompressedGnuplotSource_Backgroundtask,
                 this,
                 std::move(limiter),
-                filesystem,
-                std::shared_ptr<wxFSFile>(filesystem->OpenFile(m_gnuplotSource)),
-                std::shared_ptr<wxFSFile>(filesystem->OpenFile(m_gnuplotData)));
+                m_gnuplotSource,
+                m_gnuplotData,
+                wxmxFile);
+  // Store the filenames without the ".gz".
+  if(m_gnuplotSource.EndsWith(".gz"))
+    m_gnuplotSource = m_gnuplotSource.Left(m_gnuplotSource.Length()-3);
+  if(m_gnuplotData.EndsWith(".gz"))
+    m_gnuplotData = m_gnuplotData.Left(m_gnuplotData.Length()-3);
 }
 
-void Image::LoadGnuplotSource_Backgroundtask2(
-  std::unique_ptr<ThreadNumberLimiter> limiter,
-  wxString gnuplotFile,
-  wxString dataFile
-  ) {
-  // Error dialogues need to be created by the foreground thread.
-  SuppressErrorDialogs suppressor;
-  
-    if (wxFileExists(dataFile)) {
-      // Don't cache the data for unreasonably long files.
-      wxStructStat strucStat;
-      if(wxStat(dataFile, &strucStat) == 0)
-      {
-        if (strucStat.st_size >
-            m_configuration->MaxGnuplotMegabytes() * 1000 * 1000) {
-          wxLogMessage(_("Too much gnuplot data => Not storing it in the worksheet"));
-          m_gnuplotData_Compressed.Clear();
-          return;
-        }
-      }
 
-      wxFileInputStream source(gnuplotFile);
-      wxFileInputStream data(dataFile);
-      
-      LoadGnuplotSource_Backgroundtask(&source, &data);
-    }
-}
-
-void Image::LoadGnuplotSource_Backgroundtask(
-  wxInputStream *source,
-  wxInputStream *data)
+void Image::LoadGnuplotSource(
+  wxInputStream *source)
 {
   // The gnuplot source of the image is cached in a compressed form:
   //
   // as it is text-only and contains many redundancies it will get way
   // smaller this way.
-  {
-    if (source->IsOk()) {
-      wxTextInputStream textIn(*source, wxS('\t'),
-                               wxConvAuto(wxFONTENCODING_UTF8));
+  if (source->IsOk()) {
+    wxTextInputStream textIn(*source, wxS('\t'),
+                             wxConvAuto(wxFONTENCODING_UTF8));
 
-      wxMemoryOutputStream mstream;
-      int zlib_flags;
-      if (wxZlibOutputStream::CanHandleGZip())
-        zlib_flags = wxZLIB_GZIP;
-      else
-        zlib_flags = wxZLIB_ZLIB;
-      wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION, zlib_flags);
-      wxTextOutputStream textOut(zstream);
-      wxString line;
+    wxMemoryOutputStream mstream;
+    int zlib_flags;
+    if (wxZlibOutputStream::CanHandleGZip())
+      zlib_flags = wxZLIB_GZIP;
+    else
+      zlib_flags = wxZLIB_ZLIB;
+    wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION, zlib_flags);
+    wxTextOutputStream textOut(zstream);
+    wxString line;
 
-      // A RegEx that matches the name of the data file (needed if we ever
-      // want to move a data file into the temp directory of a new computer
-      // that locates its temp data somewhere strange).
-      wxRegEx replaceDataFileName("'[^']*maxout_[^']*_[0-9]*\\.data'");
-      while (!source->Eof()) {
-        line = textIn.ReadLine();
-        if (replaceDataFileName.Matches(line)) {
-          wxString dataFileName;
-          dataFileName = replaceDataFileName.GetMatch(line);
-          replaceDataFileName.Replace(&line, wxS("'<DATAFILENAME>'"));
-        }
-        textOut << line + wxS("\n");
+    // A RegEx that matches the name of the data file (needed if we ever
+    // want to move a data file into the temp directory of a new computer
+    // that locates its temp data somewhere strange).
+    wxRegEx replaceDataFileName("'[^']*maxout_[^']*_[0-9]*\\.data'");
+    while (!source->Eof()) {
+      line = textIn.ReadLine();
+      if (replaceDataFileName.Matches(line)) {
+        wxString dataFileName;
+        dataFileName = replaceDataFileName.GetMatch(line);
+        replaceDataFileName.Replace(&line, wxS("'<DATAFILENAME>'"));
       }
-      textOut.Flush();
-      zstream.Close();
-
-      m_gnuplotSource_Compressed.Clear();
-      m_gnuplotSource_Compressed.AppendData(
-        mstream.GetOutputStreamBuffer()->GetBufferStart(),
-        mstream.GetOutputStreamBuffer()->GetBufferSize());
+      textOut << line + wxS("\n");
     }
+    textOut.Flush();
+    zstream.Close();
 
-    {
-      if (data->IsOk()) {
-        wxTextInputStream textIn(*data, wxS('\t'),
-                                 wxConvAuto(wxFONTENCODING_UTF8));
-
-        wxMemoryOutputStream mstream;
-        int zlib_flags;
-        if (wxZlibOutputStream::CanHandleGZip())
-          zlib_flags = wxZLIB_GZIP;
-        else
-          zlib_flags = wxZLIB_ZLIB;
-        wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION,
-                                   zlib_flags);
-        wxTextOutputStream textOut(zstream);
-        wxString line;
-
-        while (!data->Eof()) {
-          line = textIn.ReadLine();
-          textOut << line + wxS("\n");
-        }
-        textOut.Flush();
-        zstream.Close();
-
-        m_gnuplotData_Compressed.Clear();
-        m_gnuplotData_Compressed.AppendData(
-          mstream.GetOutputStreamBuffer()->GetBufferStart(),
-          mstream.GetOutputStreamBuffer()->GetBufferSize());
-      }
-    }
+    m_gnuplotSource_Compressed.Clear();
+    m_gnuplotSource_Compressed.AppendData(
+      mstream.GetOutputStreamBuffer()->GetBufferStart(),
+      mstream.GetOutputStreamBuffer()->GetBufferSize());
   }
 }
 
-void Image::LoadGnuplotSource_Backgroundtask1(
-  std::unique_ptr<ThreadNumberLimiter> limiter,
-  std::shared_ptr<wxFileSystem> filesystem,
-  std::shared_ptr<wxInputStream> gnuplotFile,
-  std::shared_ptr<wxInputStream> dataFile
-  ) {
-  // Error dialogues need to be created by the foreground thread.
-  SuppressErrorDialogs suppressor;
-  wxFileInputStream source(m_gnuplotSource);
-  wxFileInputStream data(m_gnuplotData);
-  
-  LoadGnuplotSource_Backgroundtask(&source, &data);
+void Image::LoadGnuplotData(
+  wxInputStream *data)
+{
+  if (data->IsOk()) {
+    wxTextInputStream textIn(*data, wxS('\t'),
+                             wxConvAuto(wxFONTENCODING_UTF8));
+
+    wxMemoryOutputStream mstream;
+    int zlib_flags;
+    if (wxZlibOutputStream::CanHandleGZip())
+      zlib_flags = wxZLIB_GZIP;
+    else
+      zlib_flags = wxZLIB_ZLIB;
+    wxZlibOutputStream zstream(mstream, wxZ_BEST_COMPRESSION,
+                               zlib_flags);
+    wxTextOutputStream textOut(zstream);
+    wxString line;
+
+    while (!data->Eof()) {
+      line = textIn.ReadLine();
+      textOut << line + wxS("\n");
+    }
+    textOut.Flush();
+    zstream.Close();
+
+    m_gnuplotData_Compressed.Clear();
+    m_gnuplotData_Compressed.AppendData(
+      mstream.GetOutputStreamBuffer()->GetBufferStart(),
+      mstream.GetOutputStreamBuffer()->GetBufferSize());
+  }
 }
 
 void Image::LoadCompressedGnuplotSource_Backgroundtask(
   std::unique_ptr<ThreadNumberLimiter> limiter,
-  std::shared_ptr<wxFileSystem> filesystem,
-  std::shared_ptr<wxFSFile> sourcefile,
-  std::shared_ptr<wxFSFile> datafile) {
-
-  // Error dialogues need to be created by the foreground thread.
-  SuppressErrorDialogs suppressor;
-
-  // Read the gnuplot source
+  wxString sourcefile,
+  wxString datafile,
+  wxString wxmxFile
+  ) {
   {
-    if(sourcefile) { // open successful
-      std::unique_ptr<wxInputStream> input(sourcefile->DetachStream());
-      if (input->IsOk()) {
+    // Error dialogues need to be created by the foreground thread.
+    SuppressErrorDialogs suppressor;
+
+    // Read the gnuplot source
+    {
+      wxFileInputStream wxmx(wxmxFile);
+      WxmxStream source(wxmx, sourcefile);
+      if (!source.Eof()) {
         m_gnuplotSource_Compressed.Clear();
         wxMemoryOutputStream mstream;
-        input->Read(mstream);
+        source.Read(mstream);
         m_gnuplotSource_Compressed.AppendData(
           mstream.GetOutputStreamBuffer()->GetBufferStart(),
           mstream.GetOutputStreamBuffer()->GetBufferSize());
       }
     }
-  }
-  // Read the gnuplot data
-  {
-    if (datafile) { // open successful
-      std::unique_ptr<wxInputStream> input(datafile->DetachStream());
-      if (input->IsOk()) {
-        m_gnuplotData_Compressed.Clear();
+    // Read the gnuplot data
+    {
+      m_gnuplotData_Compressed.Clear();
+      wxFileInputStream wxmx(wxmxFile);
+      WxmxStream data(wxmx, datafile);
+      if (!data.Eof()) { // open successful
         wxMemoryOutputStream mstream;
-        input->Read(mstream);
+        data.Read(mstream);
         m_gnuplotData_Compressed.AppendData(
           mstream.GetOutputStreamBuffer()->GetBufferStart(),
           mstream.GetOutputStreamBuffer()->GetBufferSize());
@@ -479,6 +385,18 @@ void Image::LoadCompressedGnuplotSource_Backgroundtask(
   }
 }
 
+Image::WxmxStream::WxmxStream(wxInputStream &wxmxFile, wxString fileInWxmx):
+  wxZipInputStream(wxmxFile, wxConvLocal)
+{
+  while(!Eof())
+  {
+    wxZipEntry *contentsEntry = NULL;
+    contentsEntry = GetNextEntry();
+    if((!contentsEntry) || (contentsEntry->GetName() == fileInWxmx))
+      break;
+  }
+}
+
 const wxMemoryBuffer Image::GetGnuplotSource() {
   if(m_loadGnuplotSourceTask.joinable())
     m_loadGnuplotSourceTask.join();
@@ -706,11 +624,7 @@ wxBitmap Image::GetBitmap(double scale) {
   // Recalculate contains its own WaitForLoad object.
   Recalculate(scale);
 
-  if (!m_isOk) {
-    InvalidBitmap();
-    return m_scaledBitmap;
-  }
-
+  wxLogBuffer errorAggregator;
   // Let's see if we have cached the scaled bitmap with the right size
   if (m_scaledBitmap.GetWidth() == m_width)
     return m_scaledBitmap;
@@ -718,12 +632,12 @@ wxBitmap Image::GetBitmap(double scale) {
   // Seems like we need to create a new scaled bitmap.
   if (m_svgRast) {
     // First create rgba data
-    std::vector<unsigned char> imgdata(m_width * m_height * 4);
+    std::vector<unsigned char> imgdata(static_cast<std::size_t>(m_width) * m_height * 4);
 
-    nsvgRasterize(m_svgRast.get(), m_svgImage, 0, 0,
-                  static_cast<double>(m_width) / (static_cast<double>(m_originalWidth)),
-                  imgdata.data(),
-                  m_width, m_height, m_width * 4);
+    wxm_nsvgRasterize(m_svgRast.get(), m_svgImage, 0, 0,
+                      static_cast<double>(m_width) / (static_cast<double>(m_originalWidth)),
+                      imgdata.data(),
+                      m_width, m_height, m_width * 4);
     return m_scaledBitmap =
       RGBA2wxBitmap(imgdata.data(), m_width, m_height);
   } else {
@@ -734,12 +648,16 @@ wxBitmap Image::GetBitmap(double scale) {
 
       img = wxImage(istream, wxBITMAP_TYPE_ANY);
     }
-    m_isOk = true;
 
     if (img.Ok())
       m_scaledBitmap = wxBitmap(img);
     else
-      InvalidBitmap();
+    {
+      wxString errorMessage = errorAggregator.GetBuffer();
+      InvalidBitmap(errorMessage);
+      wxLogMessage("GetBitmap(): %s", errorMessage.mb_str());
+      Recalculate();
+    }
   }
 
   // Make sure we stay within sane defaults
@@ -758,32 +676,56 @@ wxBitmap Image::GetBitmap(double scale) {
   return m_scaledBitmap;
 }
 
-void Image::InvalidBitmap() {
-  m_isOk = false;
-  m_width = 800 * m_ppi / 96;
-  m_height = 600 * m_ppi / 96;
+void Image::InvalidBitmap(wxString message) {
+  m_originalWidth = m_width = 1200 * m_ppi / 96;
+  m_originalHeight = m_height = 900 * m_ppi / 96;
   // Create a "image not loaded" bitmap.
   m_scaledBitmap.Create(m_width, m_height);
-
+  wxString fileSystemMessage;
+  if(m_fromWxFS)
+    fileSystemMessage = _("\nImage was loaded from a .wxmx file");
   wxString error;
   if (m_imageName != wxEmptyString)
-    error =
-      wxString::Format(_("Error: Cannot render %s."), m_imageName.utf8_str());
+  {
+    if(message.IsEmpty())
+      error =
+        wxString::Format(_("Error: Cannot render %s."), m_imageName.utf8_str())  + fileSystemMessage;
+    else
+      error =
+        wxString::Format(_("Error: Cannot render %s:\n%s"), m_imageName.utf8_str(), message.utf8_str()) + fileSystemMessage;
+  }
   else
-    error = wxString::Format(_("Error: Cannot render the image."));
+  {
+    if(message.IsEmpty())
+      error = wxString::Format(_("Error: Cannot render the image.")) + fileSystemMessage;
+    else
+      error = wxString::Format(_("Error: Cannot render the image:\n%s"), message.utf8_str()) + fileSystemMessage;
+  }
 
-  wxMemoryDC dc;
-  dc.SelectObject(m_scaledBitmap);
+  {
+    wxMemoryDC dc;
+    dc.SelectObject(m_scaledBitmap);
+    dc.SetPen(*wxBLACK_PEN);
+    dc.SetBrush(*wxWHITE_BRUSH);
+    dc.Clear();
+    wxCoord width = 0, height = 0;
+    dc.GetTextExtent(error, &width, &height);
 
-  int width = 0, height = 0;
-  dc.GetTextExtent(error, &width, &height);
+    dc.DrawRectangle(0, 0, m_width - 1, m_height - 1);
+    dc.DrawLine(0, 0, m_width - 1, m_height - 1);
+    dc.DrawLine(0, m_height - 1, m_width - 1, 0);
 
-  dc.DrawRectangle(0, 0, m_width - 1, m_height - 1);
-  dc.DrawLine(0, 0, m_width - 1, m_height - 1);
-  dc.DrawLine(0, m_height - 1, m_width - 1, 0);
-
-  dc.GetTextExtent(error, &width, &height);
-  dc.DrawText(error, (m_width - width) / 2, (m_height - height) / 2);
+    dc.GetTextExtent(error, &width, &height);
+    dc.DrawText(error, (m_width - width) / 2, (m_height - height) / 2);
+  }
+  wxMemoryOutputStream mstream;
+  wxASSERT(m_scaledBitmap.IsOk());
+  wxImage image = m_scaledBitmap.ConvertToImage();
+  wxASSERT(image.IsOk());
+  image.SaveFile(mstream, wxBITMAP_TYPE_PNG);
+  m_compressedImage.Clear();
+  m_compressedImage.AppendData(mstream.GetOutputStreamBuffer()->GetBufferStart(),
+                               mstream.GetOutputStreamBuffer()->GetBufferSize());
 }
 
 void Image::LoadImage(const wxBitmap &bitmap) {
@@ -791,7 +733,6 @@ void Image::LoadImage(const wxBitmap &bitmap) {
     m_loadImageTask.join();
   // Convert the bitmap to a png image we can use as m_compressedImage
   wxImage image = bitmap.ConvertToImage();
-  m_isOk = image.IsOk();
   wxMemoryOutputStream stream;
   image.SaveFile(stream, wxBITMAP_TYPE_PNG);
   m_compressedImage.AppendData(stream.GetOutputStreamBuffer()->GetBufferStart(),
@@ -806,34 +747,41 @@ void Image::LoadImage(const wxBitmap &bitmap) {
   m_height = 1;
 }
 
-wxString Image::GetExtension() const { return m_extension; }
+wxString Image::GetExtension() const {
+  if(m_loadImageTask.joinable())
+    m_loadImageTask.join();
+  return m_extension;
+}
 
-// filesystem cannot be passed by const reference as we want to keep the
-// pointer to the file system alive in a background task
-// cppcheck-suppress performance symbolName=filesystem
-void Image::LoadImage(wxString image, std::shared_ptr<wxFileSystem> &filesystem,
+void Image::LoadImage(wxString image, wxString wxmxFile,
                       bool remove) {
   if(m_loadImageTask.joinable())
     m_loadImageTask.join();
+  m_fromWxFS = !wxmxFile.IsEmpty();
   m_extension = wxFileName(image).GetExt();
   m_extension = m_extension.Lower();
   m_imageName = image;
-  std::unique_ptr<ThreadNumberLimiter> limiter(new ThreadNumberLimiter()); 
+  std::unique_ptr<ThreadNumberLimiter> limiter(new ThreadNumberLimiter());
   m_compressedImage.Clear();
   m_scaledBitmap.Create(1, 1);
-  SuppressErrorDialogs logNull;
+  m_loadImageTask = std::thread(&Image::LoadImage_Backgroundtask,
+                                this,
+                                std::move(limiter),
+                                std::move(image), std::move(wxmxFile),
+                                remove
 
-  if (filesystem) {
-    std::unique_ptr<wxFSFile> fsfile(filesystem->OpenFile(image));
-    if (fsfile) { // open successful
-      std::unique_ptr<wxInputStream> istream(fsfile->DetachStream());
+    );
+}
 
-      m_compressedImage = ReadCompressedImage(istream.get());
-    }
+void Image::LoadImage_Backgroundtask(std::unique_ptr<ThreadNumberLimiter> limiter,
+                                     wxString image, wxString wxmxFile,
+                                     bool remove) {
+  wxLogBuffer errorAggregator;
 
-    // Closing and deleting fsfile is important: If this line is missing
-    // opening .wxmx files containing hundreds of images might lead to a
-    // "too many open files" error.
+  if (!wxmxFile.IsEmpty()) {
+    wxFileInputStream wxmx(wxmxFile);
+    WxmxStream imgData(wxmx, image);
+    m_compressedImage = ReadCompressedImage(&imgData);
   } else {
     wxFile file;
     // Support relative and absolute paths.
@@ -862,17 +810,11 @@ void Image::LoadImage(wxString image, std::shared_ptr<wxFileSystem> &filesystem,
         }
       }
     }
+    else
+      InvalidBitmap(errorAggregator.GetBuffer());
   }
 
-  m_loadImageTask = std::thread(&Image::LoadImage_Backgroundtask,
-                                this,
-                                std::move(limiter));
-
-}
-
-void Image::LoadImage_Backgroundtask(std::unique_ptr<ThreadNumberLimiter> limiter) {
-  m_isOk = false;
-
+  SuppressErrorDialogs suppressor;
   wxImage Image;
   if (m_compressedImage.GetDataLen() > 0) {
     if ((m_extension == "svg") || (m_extension == "svgz")) {
@@ -894,8 +836,8 @@ void Image::LoadImage_Backgroundtask(std::unique_ptr<ThreadNumberLimiter> limite
         zstream.Close();
         m_compressedImage.Clear();
         m_compressedImage.AppendData(
-				     mstream.GetOutputStreamBuffer()->GetBufferStart(),
-				     mstream.GetOutputStreamBuffer()->GetBufferSize());
+          mstream.GetOutputStreamBuffer()->GetBufferStart(),
+          mstream.GetOutputStreamBuffer()->GetBufferSize());
         m_extension += "z";
         m_imageName += "z";
       } else {
@@ -918,31 +860,25 @@ void Image::LoadImage_Backgroundtask(std::unique_ptr<ThreadNumberLimiter> limite
       int ppi = m_configuration->GetPPI().x;
 
       if (svgContents.data()) {
-        m_svgImage = nsvgParse(svgContents.data(), "px", ppi);
+        m_svgImage = wxm_nsvgParse(svgContents.data(), "px", ppi);
       }
 
       if (m_svgImage) {
         if (!m_svgRast)
-          m_svgRast.reset(nsvgCreateRasterizer());
-        if (m_svgRast)
-          m_isOk = true;
+          m_svgRast.reset(wxm_nsvgCreateRasterizer());
         m_originalWidth = m_svgImage->width;
         m_originalHeight = m_svgImage->height;
       }
     } else {
       wxMemoryInputStream istream(m_compressedImage.GetData(),
                                   m_compressedImage.GetDataLen());
-      {
-        SuppressErrorDialogs logNull;
-        Image.LoadFile(istream);
-      }
+      Image.LoadFile(istream);
       m_originalWidth = 700;
       m_originalHeight = 300;
 
       if (Image.Ok()) {
         m_originalWidth = Image.GetWidth();
         m_originalHeight = Image.GetHeight();
-        m_isOk = true;
         if (Image.HasOption(wxS("wxIMAGE_OPTION_RESOLUTION"))) {
           int resolution;
           resolution = Image.GetOptionInt(wxS("wxIMAGE_OPTION_RESOLUTION"));
@@ -955,7 +891,9 @@ void Image::LoadImage_Backgroundtask(std::unique_ptr<ThreadNumberLimiter> limite
             m_ppi = resolution;
         }
       } else {
-        InvalidBitmap();
+        wxString errorMessage = errorAggregator.GetBuffer();
+        InvalidBitmap(errorMessage);
+        wxLogMessage("LoadImage(): %s", errorMessage.mb_str());
       }
     }
   }
@@ -967,9 +905,9 @@ void Image::Recalculate(double scale) {
   // It would better to use a jthread for joining no-more used threads.
   // But that is C++20, which now (in 2023) is still too early.
   if((!m_gnuplotDataThreadRunning) && m_loadGnuplotSourceTask.joinable())
-     m_loadGnuplotSourceTask.join();
-  int width = m_originalWidth;
-  int height = m_originalHeight;
+    m_loadGnuplotSourceTask.join();
+  wxCoord width = m_originalWidth;
+  wxCoord height = m_originalHeight;
 
   // We want the image to get bigger if the user zooms in - and
   // if a high printing resolution requires us to scale everything up.
@@ -1010,10 +948,12 @@ void Image::Recalculate(double scale) {
 
   // Shrink to be smaller than the maximum size.
   if ((m_maxWidth > 0) &&
-      (scale * width > m_maxWidth * m_configuration->GetPPI().x))
+      (static_cast<wxCoord>(scale) * width >
+       m_maxWidth * static_cast<wxCoord>(m_configuration->GetPPI().x)))
     scale = m_maxWidth * m_configuration->GetPPI().x / width;
   if ((m_maxHeight > 0) &&
-      (scale * height > m_maxHeight * m_configuration->GetPPI().y))
+      (static_cast<wxCoord>(scale) * height >
+       m_maxHeight * static_cast<wxCoord>(m_configuration->GetPPI().y)))
     scale = m_maxHeight * m_configuration->GetPPI().y / height;
 
   // Set the width of the scaled image
@@ -1033,23 +973,23 @@ void Image::Recalculate(double scale) {
 const wxString &Image::GetBadImageToolTip() {
   // cppcheck-suppress returnTempReference
   return T_(
-	    "The image could not be displayed. It may be broken, in a wrong format "
-	    "or "
-	    "be the result of gnuplot not being able to write the image or not being "
-	    "able to understand what maxima wanted to plot.\n"
-	    "One example of the latter would be: Gnuplot refuses to plot entirely "
-	    "empty images");
+    "The image could not be displayed. It may be broken, in a wrong format "
+    "or "
+    "be the result of gnuplot not being able to write the image or not being "
+    "able to understand what maxima wanted to plot.\n"
+    "One example of the latter would be: Gnuplot refuses to plot entirely "
+    "empty images");
 }
 
 wxBitmap Image::RGBA2wxBitmap(const unsigned char imgdata[],
                               const int &width, const int &height,
 
 #if defined __WXOSX__
-                                  const int &scaleFactor
+                              const int &scaleFactor
 #else
-                                  const int &WXUNUSED(scaleFactor)
+                              const int &WXUNUSED(scaleFactor)
 #endif
-				  ) {
+  ) {
 #if defined __WXOSX__
   wxBitmap retval = wxBitmap(wxSize(width, height), 32, scaleFactor);
 #else
