@@ -34,25 +34,25 @@
 
 LicenseDialog::LicenseDialog(wxWindow *parent)
   : wxDialog(parent, -1, _("License"), wxDefaultPosition, wxDefaultSize,
-	     wxRESIZE_BORDER | wxCLOSE_BOX | wxMAXIMIZE_BOX |
-	     wxMINIMIZE_BOX) {
+             wxRESIZE_BORDER | wxCLOSE_BOX | wxMAXIMIZE_BOX |
+             wxMINIMIZE_BOX) {
   wxBoxSizer *vbox = new wxBoxSizer(wxVERTICAL);
   wxMemoryInputStream istream(WXM_LICENSE, WXM_LICENSE_SIZE);
   wxTextInputStream textIn(istream);
   m_movedToStart = false;
   Connect(wxEVT_TEXT_URL, wxTextUrlEventHandler(LicenseDialog::OnTextURLEvent),
-	  NULL, this);
+          NULL, this);
   wxString line;
   wxString licenseText;
 
   m_license = new wxTextCtrl(
-			     this, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize,
-			     wxTE_MULTILINE | wxHSCROLL | wxTE_READONLY | wxTE_AUTO_URL);
+                             this, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize,
+                             wxTE_MULTILINE | wxHSCROLL | wxTE_READONLY | wxTE_AUTO_URL);
 
   wxFont fnt = m_license->GetFont();
   wxClientDC dc(this);
   dc.SetFont(fnt);
-  long textWidth = 0;
+  wxCoord textWidth = 0;
   while (!istream.Eof()) {
     line = textIn.ReadLine();
     licenseText += line + wxS("\n");
@@ -115,7 +115,7 @@ void LicenseDialog::OnTextURLEvent(wxTextUrlEvent &event) {
   if (event.GetMouseEvent().LeftUp()) {
     wxTextCtrl *pTextCtrl = static_cast<wxTextCtrl *>(event.GetEventObject());
     wxLaunchDefaultBrowser(
-			   pTextCtrl->GetRange(event.GetURLStart(), event.GetURLEnd()));
+                           pTextCtrl->GetRange(event.GetURLStart(), event.GetURLEnd()));
   }
 }
 
