@@ -162,10 +162,7 @@ MathParser::MathParser(Configuration *cfg, const wxString &zipfile) {
     m_groupTags[wxS("heading6")] = &MathParser::GroupCellHeading6Tag;
   }
   m_highlight = false;
-  if (zipfile.Length() > 0) {
-    m_fileSystem = std::unique_ptr<wxFileSystem>(new wxFileSystem());
-    m_fileSystem->ChangePathTo(zipfile + wxS("#zip:/"), true);
-  }
+  m_wxmxFile = zipfile;
 }
 
 MathParser::~MathParser() {}
@@ -175,10 +172,10 @@ std::unique_ptr<Cell> MathParser::ParseVariableNameTag(wxXmlNode *node){
   if (children != NULL)
     {
       if((m_configuration->IsOperator(children->GetContent())) ||
-	 (node->GetAttribute(wxS("type")) == wxS("Operator")))
-	return ParseText(children, TS_OPERATOR);
+         (node->GetAttribute(wxS("type")) == wxS("Operator")))
+        return ParseText(children, TS_OPERATOR);
       else
-	return ParseText(children, TS_VARIABLE);
+        return ParseText(children, TS_VARIABLE);
     }
   return ParseText(children, TS_VARIABLE);
 }
@@ -217,7 +214,7 @@ int MathParser::CountChildren(wxXmlNode *node) {
 std::unique_ptr<Cell> MathParser::ParseRowTag(wxXmlNode *node) {
   if(node == NULL)
     return nullptr;
-  
+
   if (node->GetAttribute(wxS("list")) == wxS("true")) {
     wxXmlNode *child = node->GetChildren();
     child = SkipWhitespaceNode(child);
@@ -262,16 +259,16 @@ std::unique_ptr<Cell> MathParser::ParseHighlightTag(wxXmlNode *node) {
     {
       wxString name = node->GetAttribute(boxName);
       if(name == wxS("highlight"))
-	{
-	  bool highlight = m_highlight;
-	  m_highlight = true;
-	  auto tmp = ParseTag(node->GetChildren());
-	  m_highlight = highlight;
-	  return tmp;
-	}
+        {
+          bool highlight = m_highlight;
+          m_highlight = true;
+          auto tmp = ParseTag(node->GetChildren());
+          m_highlight = highlight;
+          return tmp;
+        }
       else
-	cell = std::make_unique<NamedBoxCell>(m_group, m_configuration, std::move(inner),
-					      name);
+        cell = std::make_unique<NamedBoxCell>(m_group, m_configuration, std::move(inner),
+                                              name);
     }
   cell->SetType(m_ParserStyle);
   ParseCommonAttrs(node, cell);
@@ -300,7 +297,7 @@ std::unique_ptr<Cell> MathParser::ParseAnimationTag(wxXmlNode *node) {
   wxString gnuplotData;
   bool del = node->GetAttribute(wxS("del"), wxS("false")) == wxS("true");
   auto animation =
-    std::make_unique<AnimationCell>(m_group, m_configuration, m_fileSystem);
+    std::make_unique<AnimationCell>(m_group, m_configuration, m_wxmxFile);
   auto const &str = node->GetChildren()->GetContent();
   wxArrayString images;
   wxString framerate;
@@ -340,10 +337,10 @@ std::unique_ptr<Cell> MathParser::ParseAnimationTag(wxXmlNode *node) {
       wxStringTokenizer dataFiles(gnuplotData, wxS(";"));
       wxStringTokenizer gnuplotFiles(gnuplotSources, wxS(";"));
       for (int i = 0; i < numImgs; i++) {
-	if ((dataFiles.HasMoreTokens()) && (gnuplotFiles.HasMoreTokens())) {
-	  animation->GnuplotSource(i, gnuplotFiles.GetNextToken(),
-				   dataFiles.GetNextToken(), m_fileSystem);
-	}
+        if ((dataFiles.HasMoreTokens()) && (gnuplotFiles.HasMoreTokens())) {
+          animation->GnuplotSource(i, gnuplotFiles.GetNextToken(),
+                                   dataFiles.GetNextToken(), m_wxmxFile);
+        }
       }
     }
   if(node->GetAttribute(wxS("gnuplotSources_gz"), &gnuplotSources) &&
@@ -353,13 +350,13 @@ std::unique_ptr<Cell> MathParser::ParseAnimationTag(wxXmlNode *node) {
       wxStringTokenizer dataFiles(gnuplotData, wxS(";"));
       wxStringTokenizer gnuplotFiles(gnuplotSources, wxS(";"));
       for (int i = 0; i < numImgs; i++) {
-	if ((dataFiles.HasMoreTokens()) && (gnuplotFiles.HasMoreTokens())) {
-	  animation->CompressedGnuplotSource(i, gnuplotFiles.GetNextToken(),
-					     dataFiles.GetNextToken(), m_fileSystem);
-	}
+        if ((dataFiles.HasMoreTokens()) && (gnuplotFiles.HasMoreTokens())) {
+          animation->CompressedGnuplotSource(i, gnuplotFiles.GetNextToken(),
+                                             dataFiles.GetNextToken(), m_wxmxFile);
+        }
       }
     }
-  
+
   return animation;
 }
 
@@ -367,24 +364,23 @@ std::unique_ptr<Cell> MathParser::ParseImageTag(wxXmlNode *node) {
   std::unique_ptr<ImgCell> imageCell;
   wxString filename(node->GetChildren()->GetContent());
 
-  if (m_fileSystem) // loading from zip
+  if (!m_wxmxFile.IsEmpty()) // loading from zip
     {
       imageCell = std::make_unique<ImgCell>(m_group, m_configuration, filename,
-					    m_fileSystem, false);
+                                            m_wxmxFile, false);
 
       wxString origImageFile =
         node->GetAttribute(wxS("origImageFile"), wxEmptyString);
 
       if (!origImageFile.empty()) {
-	imageCell->SetOrigImageFile(origImageFile);
+        imageCell->SetOrigImageFile(origImageFile);
       }
     } else {
-    std::shared_ptr<wxFileSystem> system_fs = {};
     if (node->GetAttribute(wxS("del"), wxS("yes")) != wxS("no")) {
       SuppressErrorDialogs suppressor;
-      if ((!wxFileExists(filename))||(wxImage::GetImageCount(filename) < 2))
+      if ((!wxFileExists(filename)) || (wxImage::GetImageCount(filename) < 2))
         imageCell = std::make_unique<ImgCell>(m_group, m_configuration,
-                                              filename, system_fs, true);
+                                              filename, wxEmptyString, true);
       else
         return std::make_unique<AnimationCell>(m_group, m_configuration,
                                                filename, true);
@@ -398,7 +394,7 @@ std::unique_ptr<Cell> MathParser::ParseImageTag(wxXmlNode *node) {
         filename = m_configuration->GetWorkingDirectory() + wxS("/") + filename;
       if (wxImage::GetImageCount(filename) < 2)
         imageCell = std::make_unique<ImgCell>(m_group, m_configuration,
-                                              filename, system_fs, false);
+                                              filename, wxEmptyString, false);
       else
         return std::make_unique<AnimationCell>(m_group, m_configuration,
                                                filename, false);
@@ -413,13 +409,13 @@ std::unique_ptr<Cell> MathParser::ParseImageTag(wxXmlNode *node) {
   wxString gnuplotSource;
   if(node->GetAttribute(wxS("gnuplotsource"), &gnuplotSource))
     {
-      wxString gnuplotData = node->GetAttribute(wxS("gnuplotdata"), wxEmptyString);      
-      imageCell->GnuplotSource(gnuplotSource, gnuplotData, m_fileSystem);
+      wxString gnuplotData = node->GetAttribute(wxS("gnuplotdata"), wxEmptyString);
+      imageCell->GnuplotSource(gnuplotSource, gnuplotData, m_wxmxFile);
     }
   if(node->GetAttribute(wxS("gnuplotsource_gz"), &gnuplotSource))
     {
-      wxString gnuplotData = node->GetAttribute(wxS("gnuplotdata_gz"), wxEmptyString);      
-      imageCell->CompressedGnuplotSource(gnuplotSource, gnuplotData, m_fileSystem);
+      wxString gnuplotData = node->GetAttribute(wxS("gnuplotdata_gz"), wxEmptyString);
+      imageCell->CompressedGnuplotSource(gnuplotSource, gnuplotData, m_wxmxFile);
     }
 
   if (node->GetAttribute(wxS("rect"), wxS("true")) == wxS("false"))
@@ -610,14 +606,16 @@ std::unique_ptr<GroupCell> MathParser::GroupCellFromCodeTag(wxXmlNode *node) {
   wxString isAutoAnswer = node->GetAttribute(wxS("auto_answer"), wxS("no"));
   if (isAutoAnswer == wxS("yes"))
     group->SetAutoAnswer(true);
-  int i = 1;
+  size_t i = 1;
   wxString answer;
   wxString question;
-  while (node->GetAttribute(wxString::Format(wxS("answer%i"), i), &answer)) {
-    if (node->GetAttribute(wxString::Format(wxS("question%i"), i), &question))
+  while (node->GetAttribute(wxString::Format(wxS("answer%li"), static_cast<long>(i)),
+                            &answer)) {
+    if (node->GetAttribute(wxString::Format(wxS("question%li"), static_cast<long>(i)),
+                           &question))
       group->SetAnswer(question, answer);
     else
-      group->SetAnswer(wxString::Format(wxS("Question #%i"), i), answer);
+      group->SetAnswer(wxString::Format(wxS("Question #%li"), static_cast<long>(i)), answer);
     i++;
   }
   ParseCommonGroupCellAttrs(node, group);
@@ -630,10 +628,10 @@ MathParser::HandleNullPointer(std::unique_ptr<Cell> &&cell) {
   if (!tmp) {
     tmp = std::make_unique<VisiblyInvalidCell>(m_group, m_configuration);
     tmp->SetToolTip(
-		    &T_("The xml data from maxima or from the .wxmx file was missing data "
-			"here.\n"
-			"If you find a way how to reproduce this problem please file a bug "
-			"report against wxMaxima."));
+                    &T_("The xml data from maxima or from the .wxmx file was missing data "
+                        "here.\n"
+                        "If you find a way how to reproduce this problem please file a bug "
+                        "report against wxMaxima."));
     tmp->SetStyle(TS_ERROR);
   }
   return tmp;
@@ -715,9 +713,9 @@ std::unique_ptr<Cell> MathParser::ParseDiffTag(wxXmlNode *node) {
     diff->SetType(m_ParserStyle);
   } else {
     diff = std::make_unique<DiffCell>(
-				      m_group, m_configuration,
-				      Cell::MakeVisiblyInvalidCell(m_group, m_configuration),
-				      Cell::MakeVisiblyInvalidCell(m_group, m_configuration));
+                                      m_group, m_configuration,
+                                      Cell::MakeVisiblyInvalidCell(m_group, m_configuration),
+                                      Cell::MakeVisiblyInvalidCell(m_group, m_configuration));
   }
   ParseCommonAttrs(node, diff);
   return diff;
@@ -764,11 +762,11 @@ std::unique_ptr<Cell> MathParser::ParseSubSupTag(wxXmlNode *node) {
       pos = child->GetAttribute("pos", wxEmptyString);
       if (pos == "presub")
         subsup->SetPreSub(std::move(cell));
-      if (pos == "presup")
+      else if (pos == "presup")
         subsup->SetPreSup(std::move(cell));
-      if (pos == "postsup")
+      else if (pos == "postsup")
         subsup->SetPostSup(std::move(cell));
-      if (pos == "postsub")
+      else if (pos == "postsub")
         subsup->SetPostSub(std::move(cell));
       child = SkipWhitespaceNode(child);
       child = GetNextTag(child);
@@ -872,7 +870,7 @@ std::unique_ptr<Cell> MathParser::ParseFunTag(wxXmlNode *node) {
         auto end = HandleNullPointer(ParseTag(child, false));
 
         auto interval = std::make_unique<IntervalCell>(
-						       m_group, m_configuration, std::move(start), std::move(end));
+                                                       m_group, m_configuration, std::move(start), std::move(end));
         ParseCommonAttrs(node, interval);
         return interval;
       }
@@ -910,17 +908,17 @@ std::unique_ptr<Cell> MathParser::ParseText(wxXmlNode *node, TextStyle style) {
       if (style == TS_NUMBER) {
         if (value.Length() >= 20)
           cell =
-	    std::make_unique<LongNumberCell>(m_group, m_configuration, value);
+            std::make_unique<LongNumberCell>(m_group, m_configuration, value);
         else
           cell = std::make_unique<TextCell>(m_group, m_configuration, value,
                                             style);
       } else if ((style == TS_LABEL) || (style == TS_USERLABEL) ||
                  (style == TS_MAIN_PROMPT) || (style == TS_OTHER_PROMPT))
         cell =
-	  std::make_unique<LabelCell>(m_group, m_configuration, value, style);
+          std::make_unique<LabelCell>(m_group, m_configuration, value, style);
       else
         cell =
-	  std::make_unique<TextCell>(m_group, m_configuration, value, style);
+          std::make_unique<TextCell>(m_group, m_configuration, value, style);
 
       switch (style) {
       case TS_ERROR:
@@ -973,7 +971,7 @@ void MathParser::ParseCommonAttrs(wxXmlNode *node, Cell *cell) {
 }
 
 void MathParser::ParseCommonGroupCellAttrs(
-					   wxXmlNode *node, const std::unique_ptr<GroupCell> &group) {
+                                           wxXmlNode *node, const std::unique_ptr<GroupCell> &group) {
   if (!group || !node)
     return;
 
@@ -1064,7 +1062,7 @@ std::unique_ptr<Cell> MathParser::ParseLimitTag(wxXmlNode *node) {
 
   auto limit =
     std::make_unique<LimitCell>(m_group, m_configuration, std::move(base),
-				std::move(under), std::move(name));
+                                std::move(under), std::move(name));
   limit->SetType(m_ParserStyle);
   ParseCommonAttrs(node, limit);
   return limit;
@@ -1199,8 +1197,8 @@ std::unique_ptr<Cell> MathParser::ParseTag(wxXmlNode *node, bool all) {
       if (!tree.GetLastAppended() &&
           (node->GetAttribute(wxS("listdelim")) != wxS("true"))) {
         auto tmp = std::make_unique<VisiblyInvalidCell>(
-							m_group, m_configuration,
-							wxString::Format(m_unknownXMLTagToolTip, tagName));
+                                                        m_group, m_configuration,
+                                                        wxString::Format(m_unknownXMLTagToolTip, tagName));
         tree.Append(std::move(tmp));
         gotInvalid = true;
       }
@@ -1275,19 +1273,19 @@ std::unique_ptr<Cell> MathParser::ParseLine(wxString s, CellType style) {
       wxLogNull suppressErrorMessages;
       xml.Load(xmlStream, wxS("UTF-8"), wxXMLDOC_KEEP_WHITESPACE_NODES);
     }
-    
+
     wxXmlNode *doc = xml.GetRoot();
 
     if (doc != NULL)
       cell = ParseTag(doc->GetChildren());
   } else {
     cell = std::make_unique<TextCell>(
-				      m_group, m_configuration,
-				      T_("(wxMaxima is configured not to show long expressions - which would be slow)"),
-				      TS_WARNING);
+                                      m_group, m_configuration,
+                                      T_("(wxMaxima is configured not to show long expressions - which would be slow)"),
+                                      TS_WARNING);
     cell->SetToolTip(&T_(
-			 "The maximum size of the expressions wxMaxima is allowed to display "
-			 "can be changed in the configuration dialogue."));
+                         "The maximum size of the expressions wxMaxima is allowed to display "
+                         "can be changed in the configuration dialogue."));
     cell->ForceBreakLine(true);
   }
   return cell;
