@@ -57,7 +57,7 @@ wxString MaximaManual::GetHelpfileAnchorName(wxString keyword) {
 
   if(m_helpFileAnchors.size() < 100)
     LoadBuiltInManualAnchors();
-  
+
   auto anchor = m_helpFileAnchors.find(keyword);
   if (anchor == m_helpFileAnchors.end())
     return wxEmptyString;
@@ -65,7 +65,7 @@ wxString MaximaManual::GetHelpfileAnchorName(wxString keyword) {
     return anchor->second;
 }
 void MaximaManual::WaitForBackgroundProcess() {
-  unsigned long nestedWaits = m_nestedBackgroundProcessWaits;
+  std::size_t nestedWaits = m_nestedBackgroundProcessWaits;
   m_nestedBackgroundProcessWaits++;
 
   if (!m_helpFileAnchorsThreadActive.try_lock()) {
@@ -77,7 +77,7 @@ void MaximaManual::WaitForBackgroundProcess() {
       (void)nestedWaits;
 #if wxCHECK_VERSION(3, 1, 5)
       if (nestedWaits == 0)
-	wxTheApp->SafeYield(NULL, false);
+        wxTheApp->SafeYield(NULL, false);
 #endif
     }
   }
@@ -135,7 +135,7 @@ bool MaximaManual::LoadManualAnchorsFromCache() {
 
   if (LoadManualAnchorsFromXML(xmlDocument)) {
     wxLogMessage(_("Read the entries the maxima manual offers from %s"),
-		 Dirstructure::Get()->AnchorsCacheFile().utf8_str());
+                 Dirstructure::Get()->AnchorsCacheFile().utf8_str());
     return true;
   }
   return !m_helpFileURLs_singlePage.empty();
@@ -169,13 +169,13 @@ void MaximaManual::AnchorAliasses(HelpFileAnchors &anchors) {
 }
 
 void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
-					  wxString maximaVersion,
-					  wxString saveName) {
+                                          wxString maximaVersion,
+                                          wxString saveName) {
   SuppressErrorDialogs suppressor;
 
-  long foundAnchorsTotal = 0;
+  std::size_t foundAnchorsTotal = 0;
   if (m_helpFileURLs_singlePage.empty() && (!(m_maximaHtmlDir.IsEmpty()))) {
-    wxArrayString helpFiles;
+    std::vector<wxString> helpFiles;
     {
       GetHTMLFiles htmlFilesTraverser(helpFiles, m_maximaHtmlDir);
       wxDir dir(m_maximaHtmlDir);
@@ -183,14 +183,14 @@ void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
     }
     {
       GetHTMLFiles_Recursive htmlFilesTraverser(
-						helpFiles, m_configuration->MaximaShareDir());
+                                                helpFiles, m_configuration->MaximaShareDir());
       wxDir dir(m_configuration->MaximaShareDir());
       dir.Traverse(htmlFilesTraverser);
     }
 
     for (const auto &file : helpFiles) {
       bool is_Singlepage = file.Contains("_singlepage.");
-      long foundAnchors = 0;
+      std::size_t foundAnchors = 0;
       wxString fileURI = wxURI(wxS("file://") + file).BuildURI();
       // wxWidgets cannot automatically replace a # as it doesn't know if it is
       // a anchor separator
@@ -209,8 +209,8 @@ void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
 #endif
 
       wxLogMessage(_("Scanning help file %s for anchors"),
-		   file.ToUTF8().data());
-    
+                   file.ToUTF8().data());
+
       wxRegEx idExtractor(".*<span id=\\\"([a-zAZ0-9_-]*)\\\"");
       wxRegEx idExtractor2("<dt id=\\\"(index-[a-zAZ0-9_-]*)\\\"");
       wxRegEx idExtractor3("<dt [^>]* id=\\\"(index-[a-zAZ0-9_-]*)\\\"");
@@ -232,15 +232,15 @@ void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
             else {
               if (idExtractor2.Replace(&token, "\\1") > 0)
                 id = token;
-	      else
-		{
-		  if (idExtractor3.Replace(&token, "\\1") > 0)
-		    id = token;
-		  else {
-		    if (idExtractor_oldManual.Replace(&token, "\\1") > 0)
-		      id = token;
-		  }
-		}
+              else
+                {
+                  if (idExtractor3.Replace(&token, "\\1") > 0)
+                    id = token;
+                  else {
+                    if (idExtractor_oldManual.Replace(&token, "\\1") > 0)
+                      id = token;
+                  }
+                }
             }
             if (!id.IsEmpty()) {
               // anchorless tokens begin with "index-"
@@ -270,18 +270,18 @@ void MaximaManual::CompileHelpFileAnchors(wxString maximaHtmlDir,
       AnchorAliasses(m_helpFileURLs_filePerChapter);
       AnchorAliasses(m_helpFileURLs_singlePage);
       wxLogMessage(_("Found %li anchors, %li anchors total."),
-		   foundAnchors, foundAnchorsTotal);
+                   static_cast<long>(foundAnchors), static_cast<long>(foundAnchorsTotal));
     }
     if(foundAnchorsTotal < 100)
       {
-	wxLogMessage(_("Have only %li keyword anchors at the end of parsing the maxima manual => "
-		       "Not caching the result of using the built-in keyword list"),
-		     foundAnchorsTotal);
-	LoadBuiltInManualAnchors();
+        wxLogMessage(_("Have only %li keyword anchors at the end of parsing the maxima manual => "
+                       "Not caching the result of using the built-in keyword list"),
+                     static_cast<long>(foundAnchorsTotal));
+        LoadBuiltInManualAnchors();
       }
     else
       {
-	SaveManualAnchorsToCache(maximaHtmlDir, maximaVersion, saveName);
+        SaveManualAnchorsToCache(maximaHtmlDir, maximaVersion, saveName);
       }
   }
   m_helpFileAnchorsThreadActive.unlock();
@@ -293,8 +293,9 @@ MaximaManual::GetHTMLFiles::OnFile(const wxString &filename) {
   wxString newItem =
     m_prefix + wxFileName::GetPathSeparator() + newItemName.GetFullName();
   newItem.Replace(wxFileName::GetPathSeparator(), "/");
-  if (newItem.EndsWith(".html") && (m_files.Index(newItem) == wxNOT_FOUND))
-    m_files.Add(newItem);
+  if (newItem.EndsWith(".html") &&
+      (std::find(m_files.begin(), m_files.end(), newItem) == m_files.end()))
+    m_files.push_back(newItem);
   return wxDIR_CONTINUE;
 }
 
@@ -309,8 +310,9 @@ MaximaManual::GetHTMLFiles_Recursive::OnFile(const wxString &filename) {
   newItemName.MakeAbsolute();
   wxString newItem = newItemName.GetFullPath();
   newItem.Replace(wxFileName::GetPathSeparator(), "/");
-  if (newItem.EndsWith(".html") && (m_files.Index(newItem) == wxNOT_FOUND))
-    m_files.Add(newItem);
+  if (newItem.EndsWith(".html") &&
+      (std::find(m_files.begin(), m_files.end(), newItem) == m_files.end()))
+    m_files.push_back(newItem);
   return wxDIR_CONTINUE;
 }
 
@@ -320,13 +322,13 @@ MaximaManual::GetHTMLFiles_Recursive::OnDir(const wxString &WXUNUSED(dirname)) {
 }
 
 void MaximaManual::SaveManualAnchorsToCache(wxString maximaHtmlDir,
-					    wxString maximaVersion,
-					    wxString saveName) {
-  long num = m_helpFileURLs_singlePage.size();
+                                            wxString maximaVersion,
+                                            wxString saveName) {
+  auto num = m_helpFileURLs_singlePage.size();
   if (num <= 50) {
     wxLogMessage(_("Found only %li keywords in maxima's "
-		   "manual. Not caching them to disc."),
-		 num);
+                   "manual. Not caching them to disc."),
+                 static_cast<long>(num));
     return;
   }
   wxXmlAttribute *htmlDir =
@@ -339,7 +341,7 @@ void MaximaManual::SaveManualAnchorsToCache(wxString maximaHtmlDir,
     new wxXmlNode(NULL, wxXML_DOCUMENT_NODE, wxEmptyString, wxEmptyString);
   wxXmlNode *headNode =
     new wxXmlNode(topNode, wxXML_ELEMENT_NODE, wxS("maxima_toc"),
-		  wxEmptyString, maximaVersionNode);
+                  wxEmptyString, maximaVersionNode);
 
   MaximaManual::HelpFileAnchors::const_iterator it;
   for (it = m_helpFileAnchors.begin(); it != m_helpFileAnchors.end(); ++it) {
@@ -347,25 +349,25 @@ void MaximaManual::SaveManualAnchorsToCache(wxString maximaHtmlDir,
       new wxXmlNode(headNode, wxXML_ELEMENT_NODE, "entry");
     {
       wxXmlNode *keyNode =
-	new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "key");
+        new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "key");
       new wxXmlNode(keyNode, wxXML_TEXT_NODE, wxEmptyString, it->first);
     }
     {
       wxXmlNode *anchorNode =
-	new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "anchor");
+        new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "anchor");
       new wxXmlNode(anchorNode, wxXML_TEXT_NODE, wxEmptyString, it->second);
     }
     if (m_helpFileURLs_singlePage.find(it->first) !=
         m_helpFileURLs_singlePage.end()) {
       wxXmlNode *keyNode =
-	new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "url_singlepage");
+        new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "url_singlepage");
       new wxXmlNode(keyNode, wxXML_TEXT_NODE, wxEmptyString,
                     m_helpFileURLs_singlePage[it->first]);
     }
     if (m_helpFileURLs_filePerChapter.find(it->first) !=
         m_helpFileURLs_filePerChapter.end()) {
       wxXmlNode *keyNode =
-	new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "url_fileperchapter");
+        new wxXmlNode(manualEntry, wxXML_ELEMENT_NODE, "url_fileperchapter");
       new wxXmlNode(keyNode, wxXML_TEXT_NODE, wxEmptyString,
                     m_helpFileURLs_filePerChapter[it->first]);
     }
@@ -373,16 +375,15 @@ void MaximaManual::SaveManualAnchorsToCache(wxString maximaHtmlDir,
   wxXmlDocument xmlDoc;
   xmlDoc.SetDocumentNode(topNode);
   wxXmlNode *commentNode = new wxXmlNode(
-					 NULL, wxXML_COMMENT_NODE, wxEmptyString,
-					 _("This file is generated by wxMaxima\n"
-					   "It caches the list of subjects maxima's manual offers and is "
-					   "automatically\n"
-					   "overwritten if maxima's version changes or the file cannot be read"));
+                                         NULL, wxXML_COMMENT_NODE, wxEmptyString,
+                                         _("This file is generated by wxMaxima\n"
+                                           "It caches the list of subjects maxima's manual offers and is "
+                                           "automatically\n"
+                                           "overwritten if maxima's version changes or the file cannot be read"));
 
   xmlDoc.AppendToProlog(commentNode);
   wxLogMessage(_("Trying to cache the list of subjects the "
-		 "manual contains in the file %s."),
-	       saveName.utf8_str());
+                 "manual contains in the file %s."), saveName.utf8_str());
   xmlDoc.Save(saveName);
 }
 
@@ -403,8 +404,8 @@ bool MaximaManual::LoadManualAnchorsFromXML(const wxXmlDocument &xmlDocument,
   wxString htmlDir = headNode->GetAttribute(wxS("html_dir"));
   wxString cacheMaximaVersion = headNode->GetAttribute(wxS("maxima_version"));
   wxLogMessage(_("Maxima version: %s, Anchors cache version"),
-	       m_maximaVersion.utf8_str(),
-	       cacheMaximaVersion.utf8_str());
+               m_maximaVersion.utf8_str(),
+               cacheMaximaVersion.utf8_str());
   if (checkManualVersion && ((cacheMaximaVersion != m_maximaVersion) ||
                              (htmlDir != m_maximaHtmlDir))) {
     if (cacheMaximaVersion != m_maximaVersion)
@@ -421,9 +422,9 @@ bool MaximaManual::LoadManualAnchorsFromXML(const wxXmlDocument &xmlDocument,
     wxLogMessage(_("No entries in the caches for the subjects the manual contains."));
     return false;
   }
-  long anchors = 0;
-  long urls_FilePerChapter = 0;
-  long urls_SinglePage = 0;
+  std::size_t anchors = 0;
+  std::size_t urls_FilePerChapter = 0;
+  std::size_t urls_SinglePage = 0;
   while (entry) {
     if (entry->GetName() == wxS("entry")) {
       wxString key;
@@ -444,27 +445,27 @@ bool MaximaManual::LoadManualAnchorsFromXML(const wxXmlDocument &xmlDocument,
         node = node->GetNext();
       }
       if ((!key.IsEmpty()) && (!anchor.IsEmpty()))
-	{
-	  anchors++;
-	  m_helpFileAnchors[key] = anchor;
-	}
+        {
+          anchors++;
+          m_helpFileAnchors[key] = anchor;
+        }
       if ((!key.IsEmpty()) && (!url_filePerChapter.IsEmpty()))
-	{
-	  urls_FilePerChapter++;
-	  m_helpFileURLs_filePerChapter[key] = url_filePerChapter;
-	}
+        {
+          urls_FilePerChapter++;
+          m_helpFileURLs_filePerChapter[key] = url_filePerChapter;
+        }
       if ((!key.IsEmpty()) && (!url_singlepage.IsEmpty()))
-	{
-	  urls_SinglePage++;
-	  m_helpFileURLs_singlePage[key] = url_singlepage;
-	}
+        {
+          urls_SinglePage++;
+          m_helpFileURLs_singlePage[key] = url_singlepage;
+        }
     }
     entry = entry->GetNext();
   }
   wxLogMessage(_("Found %li anchors, URLs (individual files): %li, URLs (singlepage): %li"),
-                                anchors,
-                                urls_FilePerChapter,
-				urls_SinglePage);
+               static_cast<long>(anchors),
+               static_cast<long>(urls_FilePerChapter),
+               static_cast<long>((long)urls_SinglePage));
   return !m_helpFileURLs_singlePage.empty();
 }
 
@@ -500,9 +501,9 @@ void MaximaManual::FindMaximaHtmlDir(wxString docDir) {
   // Cygwin uses /c/something instead of c:/something and passes this path to
   // the web browser - which doesn't support cygwin paths => convert the path to
   // a native windows pathname if needed.
-  if (headerFile.Length() > 1 && headerFile[1] == wxS('/')) {
-    headerFile[1] = headerFile[2];
-    headerFile[2] = wxS(':');
+  if (headerFile.Length() > 1 && headerFile.at(1) == wxS('/')) {
+    headerFile.at(1) = headerFile.at(2);
+    headerFile.at(2) = wxS(':');
   }
 #endif // __CYGWIN__
   wxPathList helpfilepaths;
@@ -523,7 +524,7 @@ void MaximaManual::FindMaximaHtmlDir(wxString docDir) {
   if (helpfile_cleanup.IsFileReadable()) {
     m_maximaHtmlDir = helpfile_cleanup.GetPath();
     wxLogMessage(_("Found the maxima HTML manual in the folder %s."),
-				  m_maximaHtmlDir.ToUTF8().data());
+                 m_maximaHtmlDir.ToUTF8().data());
   } else {
     m_maximaHtmlDir.clear();
     wxLogMessage(_("Didn't find the maxima HTML manual."));
@@ -545,13 +546,13 @@ void MaximaManual::LoadHelpFileAnchors(wxString docdir,
         }
         m_helpFileAnchorsThreadActive.lock();
         m_helpfileanchorsThread =
-	  std::unique_ptr<std::thread>(
-				       new std::thread(&MaximaManual::CompileHelpFileAnchors,
-						       this,
-						       m_maximaHtmlDir,
-						       m_maximaVersion,
-						       Dirstructure::AnchorsCacheFile()
-						       ));
+          std::unique_ptr<std::thread>(
+                                       new std::thread(&MaximaManual::CompileHelpFileAnchors,
+                                                       this,
+                                                       m_maximaHtmlDir,
+                                                       m_maximaVersion,
+                                                       Dirstructure::AnchorsCacheFile()
+                                                       ));
       } else {
         wxLogMessage(_("Maxima help file not found!"));
         LoadBuiltInManualAnchors();
