@@ -27,6 +27,7 @@
 
 #include <vector>
 #include <utility>
+#include <algorithm>
 #include <wx/mstream.h>
 #include <wx/rawbmp.h>
 #include <wx/txtstrm.h>
@@ -38,7 +39,7 @@
 #include "Image.h"
 #include "invalidImage.h"
 
-SvgBitmap::SvgBitmap(wxWindow *window, const unsigned char *data, size_t len,
+SvgBitmap::SvgBitmap(wxWindow *window, const unsigned char *data, const std::size_t len,
                      int width, int height)
   : m_window(window) {
   // Unzip the .svgz image
@@ -58,16 +59,23 @@ SvgBitmap::SvgBitmap(wxWindow *window, const unsigned char *data, size_t len,
 
   // Render the .svgz image
   if (!m_svgRast)
-    m_svgRast = nsvgCreateRasterizer();
+    m_svgRast = wxm_nsvgCreateRasterizer();
   if (!m_svgRast)
     wxBitmap::operator=(GetInvalidBitmap(width));
   if (svgContents.size() < 2)
     wxBitmap::operator=(GetInvalidBitmap(width));
 
-  m_svgImage.reset(nsvgParse(svgContents.data(), "px", 96));
+  m_svgImage.reset(wxm_nsvgParse(svgContents.data(), "px", 96));
   SetSize(width, height);
 }
 
+SvgBitmap::SvgBitmap(wxWindow *window, const wxString data, wxSize siz)
+{
+  wxCharBuffer buffer = data.ToUTF8();
+  m_svgImage.reset(wxm_nsvgParse(buffer.data(), "px", 96));
+  SetSize(siz.x, siz.y);
+}
+
 SvgBitmap::~SvgBitmap() {}
 
 const SvgBitmap &SvgBitmap::SetSize(int width, int height) {
@@ -77,7 +85,9 @@ const SvgBitmap &SvgBitmap::SetSize(int width, int height) {
     height = 1;
   // Set the bitmap to the new size
 #if defined __WXOSX__
-  int scaleFactor = m_window->GetContentScaleFactor();
+  int scaleFactor = 1;
+  if (m_window != NULL)
+    scaleFactor = m_window->GetContentScaleFactor();
   if (scaleFactor < 1)
     scaleFactor = 1;
   if (scaleFactor > 16)
@@ -92,13 +102,13 @@ const SvgBitmap &SvgBitmap::SetSize(int width, int height) {
     return *this;
   }
 
-  std::vector<unsigned char> imgdata((long)width * height * 4);
+  std::vector<unsigned char> imgdata(static_cast<std::size_t>(width) * height * 4);
 
   // Actually render the bitmap
-  nsvgRasterize(m_svgRast, m_svgImage.get(), 0, 0,
-                wxMin(static_cast<double>(width) / static_cast<double>(m_svgImage->width),
-                      static_cast<double>(height) / static_cast<double>(m_svgImage->height)),
-                imgdata.data(), width, height, width * 4);
+  wxm_nsvgRasterize(m_svgRast, m_svgImage.get(), 0, 0,
+                    std::min(static_cast<double>(width) / static_cast<double>(m_svgImage->width),
+                             static_cast<double>(height) / static_cast<double>(m_svgImage->height)),
+                    imgdata.data(), width, height, width * 4);
 
   // Copy the bitmap to this object's bitmap storage
   wxAlphaPixelData bmpdata(*this);
@@ -119,11 +129,11 @@ const SvgBitmap &SvgBitmap::SetSize(int width, int height) {
   return *this;
 }
 
-SvgBitmap::SvgBitmap(wxWindow *window, const unsigned char *data, size_t len,
+SvgBitmap::SvgBitmap(wxWindow *window, const unsigned char *data, const std::size_t len,
                      wxSize siz)
   : SvgBitmap(window, data, len, siz.x, siz.y) {}
 
-SvgBitmap &SvgBitmap::operator=(SvgBitmap &&o) {
+SvgBitmap &SvgBitmap::operator=(SvgBitmap &&o) noexcept {
   wxBitmap::operator=(o);
   m_svgImage = std::move(o.m_svgImage);
   return *this;
@@ -134,12 +144,19 @@ wxBitmap SvgBitmap::GetInvalidBitmap(int targetSize) {
   img.Rescale(targetSize, targetSize, wxIMAGE_QUALITY_HIGH);
   wxBitmap retval;
 #if defined __WXOSX__
+  int scaleFactor = 1;
+  if (m_window != NULL)
+    scaleFactor = m_window->GetContentScaleFactor();
+  if (scaleFactor < 1)
+    scaleFactor = 1;
+  if (scaleFactor > 16)
+    scaleFactor = 16;
   retval =
-    wxBitmap(img, wxBITMAP_SCREEN_DEPTH, m_window->GetContentScaleFactor());
+    wxBitmap(img, wxBITMAP_SCREEN_DEPTH, scaleFactor);
 #else
   retval = wxBitmap(img, wxBITMAP_SCREEN_DEPTH);
 #endif
   return retval;
 }
 
-struct NSVGrasterizer *SvgBitmap::m_svgRast = NULL;
+struct wxm_NSVGrasterizer *SvgBitmap::m_svgRast = NULL;
