@@ -31,8 +31,8 @@
 #include <memory>
 #include "precomp.h"
 #include <wx/bitmap.h>
-#include "nanoSVG/nanosvg.h"
-#include "nanoSVG/nanosvgrast.h"
+#include "nanosvg_private.h"
+#include "nanosvgrast_private.h"
 #include "Cell.h"
 #define NANOSVG_ALL_COLOR_KEYWORDS
 
@@ -42,11 +42,12 @@ class SvgBitmap: public wxBitmap
 {
 public:
 //! A constructor that loads the data into a wxBitmap
-  SvgBitmap(wxWindow *window, const unsigned char *data, size_t len, int width = 640, int height = 480);
-  SvgBitmap(wxWindow *window, const unsigned char *data, size_t len, wxSize siz);
+  SvgBitmap(wxWindow *window, const unsigned char *data, const size_t len, int width = 640, int height = 480);
+  SvgBitmap(wxWindow *window, const unsigned char *data, const std::size_t len, wxSize siz);
+  SvgBitmap(wxWindow *window, const wxString data, wxSize siz);
   ~SvgBitmap() override;
   SvgBitmap(SvgBitmap &&) = delete;
-  SvgBitmap &operator=(SvgBitmap &&o);
+  SvgBitmap &operator=(SvgBitmap &&o) noexcept;
 
   //! Sets the bitmap to a new size and renders the svg image at this size.
   const SvgBitmap& SetSize(int width, int height);
@@ -59,10 +60,10 @@ public:
   wxBitmap GetInvalidBitmap(int targetSize);
 private:
   //! No idea what nanoSVG stores here. But can be shared between images.
-  static struct NSVGrasterizer* m_svgRast;
+  static struct wxm_NSVGrasterizer* m_svgRast;
   //! The renderable svg image after we have read it in
-  std::unique_ptr<NSVGimage, decltype(std::free)*> m_svgImage{nullptr, std::free};
-  //! The window this bitmap will be drawn on
+  std::unique_ptr<wxm_NSVGimage, decltype(std::free)*> m_svgImage{nullptr, std::free};
+  //! The window this bitmap will be drawn o
   wxWindow *m_window = NULL;
 };
 
