@@ -31,6 +31,9 @@
  */
 
 #include <wx/colour.h>
+#include <map>
+#include <string>
+#include <ostream>
 #include <wx/config.h>
 #include <wx/font.h>
 #include <wx/settings.h>
@@ -63,7 +66,7 @@ public:
   Style(const Style &);
 
   Style &operator=(const Style &);
-  //! Compares 
+  //! Compares
   bool operator==(const Style &o) const;
 
   /*! Read this style from a config source.
@@ -74,11 +77,11 @@ public:
   Style &Read(wxConfigBase *config, const wxString &where);
   //! Write this style to a config source
   void Write(wxConfigBase *config, const wxString &where) const;
-  
+
   //! Gets a style that represents a given font. The font gets cached.
   static const Style &FromFont(const wxFont &font);
   //! Gets a style that represents a stock font. The font is pre-cached.
-  static const Style &FromStockFont(wxStockGDI::Item font);
+  static Style FromStockFont(wxStockGDI::Item font);
 
   constexpr static wxFontFamily Default_Family{wxFONTFAMILY_DEFAULT};
   constexpr static wxFontEncoding Default_Encoding{wxFONTENCODING_DEFAULT};
@@ -168,7 +171,7 @@ public:
     return wxCHECK_VERSION(3, 1, 2); } //-V686 //-V501
   //! Returns the font size that this style has when not zoomed or being used as subscript/...
   static AFontSize GetFontSize(const wxFont &);
-  //! Sets the font size that this style has when not zoomed or being used as subscript/...  
+  //! Sets the font size that this style has when not zoomed or being used as subscript/...
   static void SetFontSize(wxFont &, AFontSize fontSize);
   //! Empties the font variant cache.
   void ClearCache()
@@ -189,7 +192,7 @@ private:
   //! A hashmap that tells us which font cache caches the font this textstyle uses
   static FontVariantCachesMap m_fontCaches;
 
-  //! The data that defines this text style 
+  //! The data that defines this text style
   struct Data
   {
     // 8/4-byte members
@@ -197,7 +200,7 @@ private:
 
       The font cache is declared as "mutual", which means: It is allowed to change
       in read-only objects.
-     */
+    */
     mutable std::shared_ptr<FontVariantCache> fontCache;
     // 4-byte members
     uint32_t rgbColor = Default_ColorRGB;
@@ -272,4 +275,7 @@ enum TextStyle : int8_t
   TS_INVALID //!< If a text style cannot be determined this value is used
 };
 
+//! Allow Standard c++ streams to print out our enum values as text.
+std::ostream& operator<<(std::ostream& out, const TextStyle textstyle);
+
 #endif // TEXTSTYLE_H
