@@ -39,7 +39,7 @@ extern unsigned int  media_playback_start_reverse_svg_gz_len;
 /*! A minimalistic Tip of the day dialogue
 
   We roll our own dialogue here as the one from wxWidgets is modal (which
-  means it blocks the application until it is closed) and Ubuntu's Focus 
+  means it blocks the application until it is closed) and Ubuntu's Focus
   Stealing Prevention makes it pop up below wxMaxima (which means the user
   has no means of finding out it needs closing).
 
@@ -61,7 +61,7 @@ private:
   wxTextCtrl *m_tip;
   wxString GetTip();
   wxCheckBox *m_showAtStartup;
-  wxImage GetImage(unsigned char *data, size_t len);
+  wxImage GetImage(unsigned char *data, std::size_t len);
   wxArrayString m_tips;
 };
 
