@@ -115,7 +115,7 @@ public:
   wxBitmap  m_needsInformationIcon;
   wxBitmap  m_PlayButton;
   wxBitmap  m_StopButton;
-  
+
   void CanUndo(bool value)
     {
       if (value != m_canUndo_old)
@@ -204,7 +204,7 @@ public:
   int GetIdealHeight(){
     return m_needsInformationIcon.GetSize().y;
   }
-  
+
   //! Remove all ools and then add all tools that are requested/fit in the toolbar/...
   void AddTools();
 
@@ -256,7 +256,7 @@ public:
   bool ShowOpenSave(){bool show = true; wxConfig::Get()->Read("Toolbar/showOpenSave", &show);
     return show;}
   void ShowOpenSave(bool show){wxConfig::Get()->Write("Toolbar/showOpenSave", show);}
-  
+
   bool ShowNew(){bool show = true; wxConfig::Get()->Read("Toolbar/showNew", &show);
     return show;}
   void ShowNew(bool show){wxConfig::Get()->Write("Toolbar/showNew", show);}
@@ -280,7 +280,7 @@ public:
   bool ShowSelectAll(){bool show = true; wxConfig::Get()->Read("Toolbar/showSelectAll", &show);
     return show;}
   void ShowSelectAll(bool show){wxConfig::Get()->Write("Toolbar/showSelectAll", show);}
-  
+
 protected:
   void OnSize(wxSizeEvent &event);
   void OnMouseRightDown(wxMouseEvent &event);
@@ -304,7 +304,7 @@ private:
   bool m_canPrint_old = true;
   bool m_canEvalTillHere_old = true;
   bool m_canEvalThisCell_old = true;
-  std::unique_ptr<struct NSVGrasterizer, decltype(std::free)*> m_svgRast{nullptr, std::free};
+  std::unique_ptr<struct wxm_NSVGrasterizer, decltype(std::free)*> m_svgRast{nullptr, std::free};
   bool m_worksheetEmpty_old  = false ;
   AnimationStartStopState m_AnimationStartStopState;
   //! True if we show the "needs information" button.
