@@ -28,6 +28,7 @@
 
 #include <memory>
 #include "GroupCell.h"
+#include <vector>
 
 class wxTextBuffer;
 
@@ -51,6 +52,16 @@ enum WXMHeaderId {
   WXM_FOLD, WXM_FOLD_END,
   WXM_HIDE,
   WXM_AUTOANSWER,
+  // The WXM_HIDDEN_* entries try to recover broken wxm files
+  WXM_HIDDEN_INPUT = GC_TYPE_CODE + 128,
+  WXM_HIDDEN_TITLE = GC_TYPE_TITLE + 128,
+  WXM_HIDDEN_SECTION = GC_TYPE_SECTION + 128,
+  WXM_HIDDEN_SUBSECTION = GC_TYPE_SUBSECTION + 128,
+  WXM_HIDDEN_SUBSUBSECTION = GC_TYPE_SUBSUBSECTION + 128,
+  WXM_HIDDEN_HEADING5 = GC_TYPE_HEADING5 + 128,
+  WXM_HIDDEN_HEADING6 = GC_TYPE_HEADING6 + 128,
+  WXM_HIDDEN_COMMENT = GC_TYPE_TEXT + 128,
+  WXM_HIDDEN_CAPTION = GC_TYPE_IMAGE + 128,
 
   WXM_MAX // Must be the last member
 };
@@ -67,7 +78,7 @@ namespace Format
   wxString TreeToWXM(GroupCell *cell, bool wxm = true);
 
 //! Converts a wxm description into individual cells
-  std::unique_ptr<GroupCell> TreeFromWXM(const wxArrayString &wxmLines, Configuration *config);
+  std::unique_ptr<GroupCell> TreeFromWXM(const std::vector<wxString> &wxmLines, Configuration *config);
 
 /*! Parses the contents of a .wxm file into individual cells.
  * Invokes TreeFromWXM on pre-processed data,
@@ -91,6 +102,7 @@ namespace Format
 
 //! First line of the WXM files - used by both loading and saving code.
   extern const wxString WXMFirstLine;
+  extern const wxString m_emptyString;
 
 }; // namespace Format
 
