@@ -471,11 +471,11 @@ private:
     Refresh() or RequestRedraw() function of this class.
 
     Using multiple threads in order to speed up this process is kind of hard:
-     * Using more than one wxPaintDC at the same time isn't supported by most
-       (if not all) operating systems.
-     * Drawing in a wxMemoryDC and then blitting the result in the central
-       wxPaintDC works, but each wxMemoryDC needs to draw into a separate bitmap
-       for that to work.
+    * Using more than one wxPaintDC at the same time isn't supported by most
+    (if not all) operating systems.
+    * Drawing in a wxMemoryDC and then blitting the result in the central
+    wxPaintDC works, but each wxMemoryDC needs to draw into a separate bitmap
+    for that to work.
   */
   void OnPaint(wxPaintEvent &event);
   //! Draws a groupcell on the DC
@@ -486,12 +486,12 @@ private:
     stuff with bitmaps is possible to do in multiple threads at the same time so
     as long as there is a mutex watching that we do the blit when no-one else
     accesses the DC should be fine.
-   */
+  */
   void DrawGroupCell_UsingBitmap(wxDC *dc, GroupCell *cell, wxRect DrawRegion);
 
   //! All that has need to be done before drawing a GroupCell in a DC
   void PrepareDrawGC(wxDC &dc);
-  
+
   void OnSize(wxSizeEvent &event);
 
   void OnMouseRightDown(wxMouseEvent &event);
@@ -632,7 +632,7 @@ private:
   wxTimer m_caretTimer;
   //! True if no changes have to be saved.
   bool m_saved = true;
-  wxArrayString m_completions;
+  std::vector<wxString> m_completions;
   bool m_autocompleteTemplates;
   AutocompletePopup *m_autocompletePopup;
 
@@ -810,7 +810,7 @@ public:
   void ScrollToError();
 
   //! The find-and-replace-dialog
-  FindReplaceDialog *m_findDialog;
+  FindReplaceDialog *m_findDialog = NULL;
 
   /*! True = schedule an update of the table of contents
 
@@ -828,9 +828,9 @@ public:
   */
   bool CanMergeSelection() const;
 
-  bool CanUndo() const { return CanTreeUndo() || CanUndoInsideCell(); }
+  bool CanUndo() const;
 
-  bool CanRedo() const { return CanTreeRedo() || CanRedoInsideCell(); }
+  bool CanRedo() const;
 
   void Undo();
 
@@ -849,7 +849,7 @@ public:
     \param The worksheet's initial location
     \param The worksheet's initial size
     \param reactToEvents Can be set to false for creating an example panel, for example
-           for the config dialogue.
+    for the config dialogue.
   */
   Worksheet(wxWindow *parent, int id, Configuration *config,
             wxPoint pos = wxDefaultPosition, wxSize size = wxDefaultSize,
@@ -917,10 +917,10 @@ public:
 
   void ResetInputPrompts();
 
-  bool CanCopy(bool fromActive = false)
+  bool CanCopy()
     {
       return m_cellPointers.m_selectionStart ||
-        (fromActive && m_cellPointers.m_activeCell &&
+        (m_cellPointers.m_activeCell &&
          m_cellPointers.m_activeCell->CanCopy());
     }
 
@@ -974,7 +974,7 @@ public:
   void DeleteSelection();
 
   void TOCdnd();
-  
+
   //! Is it possible to delete the cells between start and end?
   bool CanDeleteRegion(GroupCell *start, GroupCell *end) const;
 
@@ -1147,17 +1147,17 @@ public:
   }
   bool StatusTextHas(){return m_statusTextHas;}
 private:
-    /* ! A timer that tells us to urgently update the display
+  /* ! A timer that tells us to urgently update the display
 
      Normally we priorize tasks: If there are GUI actions to process we do so.
-     If not we look if there is data from maxima to process. If not we 
+     If not we look if there is data from maxima to process. If not we
      If not we recalculate the worksheet element sizes and positions and if
      there still is no pressing task we update the display. This way we
      respond quickly to the most important inputs.
 
      This timer, if expired, tells us that if we don't update the screen now
      maxima feels like not being responsive.
-   */
+  */
   wxTimer m_displayTimeoutTimer;
 
   template <class T_SRC, class T_DEST>
@@ -1385,13 +1385,13 @@ public:
   /*! Update the info which cell is the last of the worksheet
 
     Also adjusts the scrollbar range to the worksheet length
-   */
+  */
   GroupCell *UpdateMLast();
   /*! Update the info which cell is the last of the worksheet
 
     Also adjusts the scrollbar range to the worksheet length
     \param gc The last GroupCell of the worksheet
-   */
+  */
   GroupCell *UpdateMLast(GroupCell *gc);
 
   void FoldOccurred();
@@ -1416,22 +1416,7 @@ public:
     See also OnThumbtrack and OnMouseWheel
   */
   void OnScrollChanged(wxScrollEvent &ev);
-  /*! Called if the user uses the touchpad for scrolling
-
-    Why we need to override this signal is that on Linux and at least on
-    wxGTK and wxWidgets 3.0+3.1 each single scroll step generates its own
-    thumbtrack event that forces an immediate scroll of the worksheet
-    including an immediate redraw. It therefore is possible for a user
-    to queue hundreds of thumbtrack events per seconds while wxMaxima's
-    framerate (and event processing speed) might be considerably lower
-    than that.
-
-    OnThumbtrack is a try to merge all scroll events until the idle task
-    redraws the worksheet.
-
-    See also OnMouseWheel and OnScrollChanged
-  */
-  void OnThumbtrack(wxScrollWinEvent &ev);
+  void OnScrollEvent(wxScrollWinEvent &ev);
   /*! Called if the mouse wheel sents events
 
     The virtual mouse wheel touchpads provide are handled by OnThumbtrack instead.
@@ -1451,7 +1436,7 @@ public:
     Used by the find dialog.
   */
   bool FindNext(const wxString &str, bool down, bool ignoreCase, bool warn = true);
-  bool FindNext_Regex(const wxString &str, bool down, bool warn = true);
+  bool FindNext_Regex(const wxString &str, const bool &down, bool warn = true);
 
   /*! Replace the current occurrence of a string
 
@@ -1561,7 +1546,7 @@ public:
   int GetCellIndex(Cell *cell) const;
 
   //! Suggestions for how the word that was right-clicked on could continue
-  wxArrayString m_replacementsForCurrentWord;
+  std::vector<wxString> m_replacementsForCurrentWord;
   //Simple iterator over a Maxima input string, skipping comments and strings
   class SimpleMathConfigurationIterator
   {
@@ -1577,7 +1562,7 @@ public:
     inline wxChar operator*() const
       { return input[pos]; }
 
-    unsigned int pos;
+    std::size_t pos;
 
     /*! reference to input string (must be a reference, so it can be modified)
 
