@@ -38,7 +38,7 @@
 AbsCell::AbsCell(GroupCell *group, Configuration *config,
                  std::unique_ptr<Cell> &&inner)
   : Cell(group, config), m_innerCell(std::move(inner)) {
-  InitBitFields();
+  InitBitFields_AbsCell();
   SetStyle(TS_VARIABLE);
 }
 
@@ -47,7 +47,7 @@ AbsCell::AbsCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=AbsCell::m_close
 AbsCell::AbsCell(GroupCell *group, const AbsCell &cell)
   : AbsCell(group, cell.m_configuration,
-	    CopyList(group, cell.m_innerCell.get())) {
+            CopyList(group, cell.m_innerCell.get())) {
   CopyCommonData(cell);
 }
 
@@ -89,15 +89,15 @@ void AbsCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     m_innerCell->DrawList(in, dc, antialiassingDC);
 
     dc->DrawLine(
-		 point.x + Scale_Px(2) + m_configuration->GetDefaultLineWidth() / 2,
-		 point.y - m_center + Scale_Px(2),
-		 point.x + Scale_Px(2) + m_configuration->GetDefaultLineWidth() / 2,
-		 point.y - m_center + m_height - Scale_Px(2));
+                 point.x + Scale_Px(2) + m_configuration->GetDefaultLineWidth() / 2,
+                 point.y - m_center + Scale_Px(2),
+                 point.x + Scale_Px(2) + m_configuration->GetDefaultLineWidth() / 2,
+                 point.y - m_center + m_height - Scale_Px(2));
     dc->DrawLine(point.x + m_width - Scale_Px(2) - 1 -
-		 m_configuration->GetDefaultLineWidth() / 2,
+                 m_configuration->GetDefaultLineWidth() / 2,
                  point.y - m_center + Scale_Px(2),
                  point.x + m_width - Scale_Px(2) - 1 -
-		 m_configuration->GetDefaultLineWidth() / 2,
+                 m_configuration->GetDefaultLineWidth() / 2,
                  point.y - m_center + m_height - Scale_Px(2));
   }
 }
