@@ -43,7 +43,6 @@
 #include <wx/config.h>
 #include <wx/file.h>
 #include <wx/filename.h>
-#include <wx/filesys.h>
 #include <wx/fs_mem.h>
 #include <wx/imaggif.h>
 #include <wx/mstream.h>
@@ -52,17 +51,15 @@
 #include <wx/wfstream.h>
 #include <wx/window.h>
 
-// filesystem cannot be passed by const reference as we want to keep the
-// pointer to the file system alive in a background task
-// cppcheck-suppress performance symbolName=filesystem
 AnimationCell::AnimationCell(GroupCell *group, Configuration *config,
-                             std::shared_ptr<wxFileSystem> &filesystem,
+                             const wxString &wxmxFile,
                              int framerate)
-  : ImgCellBase(group, config),
-    m_timer(m_cellPointers->GetWorksheet(), wxWindow::NewControlId()),
-    m_fileSystem(filesystem), m_framerate(framerate), m_displayed(0),
-    m_imageBorderWidth(Scale_Px(1)) {
-  InitBitFields();
+: ImgCellBase(group, config),
+  m_timer(m_cellPointers->GetWorksheet(), wxWindow::NewControlId()),
+  m_framerate(framerate), m_displayed(0),
+  m_imageBorderWidth(Scale_Px(1)),
+  m_wxmxFile(wxmxFile) {
+  InitBitFields_AnimationCell();
   m_type = MC_TYPE_SLIDE;
   ReloadTimer();
 }
@@ -72,7 +69,7 @@ AnimationCell::AnimationCell(GroupCell *group, Configuration *config,
   : ImgCellBase(group, config),
     m_timer(m_cellPointers->GetWorksheet(), wxWindow::NewControlId()),
     m_framerate(framerate), m_displayed(0), m_imageBorderWidth(Scale_Px(1)) {
-  InitBitFields();
+  InitBitFields_AnimationCell();
   m_type = MC_TYPE_SLIDE;
   ReloadTimer();
 }
@@ -181,7 +178,7 @@ void AnimationCell::LoadImages(wxMemoryBuffer imageData) {
     wxImage image;
     image.LoadFile(istream2, wxBITMAP_TYPE_ANY, i);
     m_images.push_back(
-		       std::make_shared<Image>(m_configuration, wxBitmap(image)));
+                       std::make_shared<Image>(m_configuration, wxBitmap(image)));
   }
 }
 
@@ -194,7 +191,7 @@ void AnimationCell::LoadImages(wxString imageFile) {
     wxImage image;
     image.LoadFile(imageFile, wxBITMAP_TYPE_ANY, i);
     m_images.push_back(
-		       std::make_shared<Image>(m_configuration, wxBitmap(image)));
+                       std::make_shared<Image>(m_configuration, wxBitmap(image)));
   }
 }
 
@@ -213,7 +210,7 @@ void AnimationCell::LoadImages(wxArrayString images, bool deleteRead) {
           dataFilename = i;
         else {
           m_images.push_back(std::make_shared<Image>(m_configuration, i,
-                                                     m_fileSystem, deleteRead));
+                                                     m_wxmxFile, deleteRead));
           if (gnuplotFilename != wxEmptyString) {
             if (m_images.back())
               m_images.back()->GnuplotSource(gnuplotFilename, dataFilename);
@@ -221,7 +218,7 @@ void AnimationCell::LoadImages(wxArrayString images, bool deleteRead) {
         }
       }
     }
-  m_fileSystem = NULL;
+  m_wxmxFile = wxEmptyString;
   m_displayed = 0;
 }
 
@@ -233,26 +230,26 @@ void AnimationCell::SetDisplayedIndex(int ind) {
     m_displayed = 0;
 }
 
-double AnimationCell::GetMaxWidth() const {
+wxCoord AnimationCell::GetMaxWidth() const {
   if (!IsOk())
     return -1;
   else
-    return m_images[m_displayed]->GetMaxWidth();
+    return m_images.at(m_displayed)->GetMaxWidth();
 }
 
-double AnimationCell::GetHeightList() const {
+wxCoord AnimationCell::GetHeightList() const {
   if (!IsOk())
     return -1;
   else
-    return m_images[m_displayed]->GetHeightList();
+    return m_images.at(m_displayed)->GetHeightList();
 }
 
-void AnimationCell::SetMaxWidth(double width) {
+void AnimationCell::SetMaxWidth(wxCoord width) {
   for (const auto &i: m_images)
     (*i).SetMaxWidth(width);
 }
 
-void AnimationCell::SetMaxHeight(double height) {
+void AnimationCell::SetMaxHeight(wxCoord height) {
   for (const auto &i: m_images)
     (*i).SetMaxHeight(height);
 }
@@ -265,16 +262,16 @@ void AnimationCell::Recalculate(AFontSize fontsize) {
   for (auto &i: m_images) {
     if(i != NULL)
       {
-	if (m_configuration->GetPrinting()) {
-	  i->Recalculate(m_configuration->GetZoomFactor() *
-			 PRINT_SIZE_MULTIPLIER);
-	} else {
-	  i->Recalculate();
-	}
-	if (m_width < i->m_width + 2 * m_imageBorderWidth)
-	  m_width = i->m_width + 2 * m_imageBorderWidth;
-	if (m_height < i->m_height + 2 * m_imageBorderWidth)
-	  m_height = i->m_height + 2 * m_imageBorderWidth;
+        if (m_configuration->GetPrinting()) {
+          i->Recalculate(m_configuration->GetZoomFactor() *
+                         PRINT_SIZE_MULTIPLIER);
+        } else {
+          i->Recalculate();
+        }
+        if (m_width < i->m_width + 2 * m_imageBorderWidth)
+          m_width = i->m_width + 2 * m_imageBorderWidth;
+        if (m_height < i->m_height + 2 * m_imageBorderWidth)
+          m_height = i->m_height + 2 * m_imageBorderWidth;
       }
   }
   m_center = m_height / 2;
@@ -289,7 +286,7 @@ void AnimationCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
   if (m_animationRunning)
     ReloadTimer();
 
-  if (DrawThisCell(point) && (m_images[m_displayed] != NULL)) {
+  if (DrawThisCell(point) && (m_images.at(m_displayed) != NULL)) {
     // Start the timer once the animation appears on the screen.
     // But start it only once: Else the animation could be refreshed
     // more frequent than it can be drawn. Each update of the animation
@@ -305,23 +302,23 @@ void AnimationCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     // Slide show cells have a red border except if they are selected
     if (m_drawBoundingBox)
       dc->SetPen(*(wxThePenList->FindOrCreatePen(
-						 m_configuration->GetColor(TS_SELECTION))));
+                                                 m_configuration->GetColor(TS_SELECTION))));
     else
       dc->SetPen(*wxRED_PEN);
     dc->DrawRectangle(wxRect(point.x, point.y - m_center, m_width, m_height));
 
     wxBitmap bitmap =
       (m_configuration->GetPrinting()
-       ? m_images[m_displayed]->GetBitmap(
-					  m_configuration->GetZoomFactor() * PRINT_SIZE_MULTIPLIER)
-       : m_images[m_displayed]->GetBitmap());
+       ? m_images.at(m_displayed)->GetBitmap(
+                                             m_configuration->GetZoomFactor() * PRINT_SIZE_MULTIPLIER)
+       : m_images.at(m_displayed)->GetBitmap());
     bitmapDC.SelectObject(bitmap);
 
     int imageBorderWidth = m_imageBorderWidth;
     if (m_drawBoundingBox) {
       imageBorderWidth = Scale_Px(3);
       dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
-						       m_configuration->GetColor(TS_SELECTION))));
+                                                       m_configuration->GetColor(TS_SELECTION))));
       dc->DrawRectangle(wxRect(point.x, point.y - m_center, m_width, m_height));
     }
 
@@ -333,7 +330,7 @@ void AnimationCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     {
       // The cell isn't drawn => No need to keep it's image cache for now.
       if(!GetRect().Intersects(m_configuration->GetVisibleRegion()))
-	ClearCache();
+        ClearCache();
     }
 
   // If we need a selection border on another redraw we will be informed by
@@ -375,18 +372,18 @@ wxString AnimationCell::ToXML() const {
         gnuplotSourceFiles += gnuplotSource + wxS(".gz;");
         const wxMemoryBuffer data = i->GetCompressedGnuplotSource();
         if (data.GetDataLen() > 0)
-	  m_configuration->PushFileToSave(gnuplotSource + wxS(".gz"), data);
+          m_configuration->PushFileToSave(gnuplotSource + wxS(".gz"), data);
       }
       if (gnuplotData != wxEmptyString) {
         gnuplotDataFiles += gnuplotData + wxS(".gz;");
         const wxMemoryBuffer data = i->GetCompressedGnuplotData();
         if (data.GetDataLen() > 0)
-	  m_configuration->PushFileToSave(gnuplotData + wxS(".gz"), data);
+          m_configuration->PushFileToSave(gnuplotData + wxS(".gz"), data);
       }
 
       if (i->GetCompressedImage())
-	m_configuration->PushFileToSave(basename + i->GetExtension(),
-					i->GetCompressedImage());
+        m_configuration->PushFileToSave(basename + i->GetExtension(),
+                                        i->GetCompressedImage());
       images += basename + i->GetExtension() + wxS(";");
     }
   }
@@ -395,17 +392,17 @@ wxString AnimationCell::ToXML() const {
   flags = wxS(" gnuplotSources_gz=\"") + gnuplotSourceFiles + wxS("\"");
   flags += wxS(" gnuplotData_gz=\"") + gnuplotDataFiles + "\"";
   if ((Length() > 0) && (m_images[0] != NULL))
-    flags += wxString::Format(wxS(" ppi=\"%i\""), m_images[0]->GetPPI());
+    flags += wxString::Format(wxS(" ppi=\"%li\""), static_cast<long>(m_images[0]->GetPPI()));
   if (HasHardLineBreak())
     flags += wxS(" breakline=\"true\"");
   if (m_animationRunning)
     flags += wxS(" running=\"true\"");
   else
     flags += wxS(" running=\"false\"");
-  flags += wxString::Format(wxS(" frame=\"%i\""), m_displayed);
+  flags += wxString::Format(wxS(" frame=\"%li\""), static_cast<long>(m_displayed));
 
   if (m_framerate > 0)
-    flags += wxString::Format(wxS(" fr=\"%i\""), GetFrameRate());
+    flags += wxString::Format(wxS(" fr=\"%li\""), static_cast<long>(GetFrameRate()));
   return wxS("\n<slide") + flags + wxS(">") + images + wxS("</slide>");
 }
 
@@ -416,7 +413,7 @@ void AnimationCell::SetPPI(int ppi) {
 }
 
 wxSize AnimationCell::ToImageFile(wxString file) {
-  return m_images[m_displayed]->ToImageFile(file);
+  return m_images.at(m_displayed)->ToImageFile(file);
 }
 
 wxString AnimationCell::ToRTF() const {
@@ -433,19 +430,19 @@ wxString AnimationCell::ToRTF() const {
   // Extract the description of the image data
   wxString image;
   wxMemoryBuffer imgdata;
-  if (m_images[m_displayed]->GetExtension().Lower() == wxS("png")) {
-    imgdata = m_images[m_displayed]->GetCompressedImage();
+  if (m_images.at(m_displayed)->GetExtension().Lower() == wxS("png")) {
+    imgdata = m_images.at(m_displayed)->GetCompressedImage();
     image = wxS("\\pngblip\n");
-  } else if ((m_images[m_displayed]->GetExtension().Lower() == wxS("jpg")) ||
-             (m_images[m_displayed]->GetExtension().Lower() == wxS("jpeg"))) {
-    imgdata = m_images[m_displayed]->GetCompressedImage();
+  } else if ((m_images.at(m_displayed)->GetExtension().Lower() == wxS("jpg")) ||
+             (m_images.at(m_displayed)->GetExtension().Lower() == wxS("jpeg"))) {
+    imgdata = m_images.at(m_displayed)->GetCompressedImage();
     image = wxS("\\jpegblip\n");
   } else {
     // Convert any non-rtf-enabled format to .png before adding it to the .rtf
     // file.
     image = wxS("\\pngblip\n");
     wxImage imagedata =
-      m_images[m_displayed]->GetUnscaledBitmap().ConvertToImage();
+      m_images.at(m_displayed)->GetUnscaledBitmap().ConvertToImage();
     wxMemoryOutputStream stream;
     imagedata.SaveFile(stream, wxBITMAP_TYPE_PNG);
     imgdata.AppendData(stream.GetOutputStreamBuffer()->GetBufferStart(),
@@ -453,9 +450,9 @@ wxString AnimationCell::ToRTF() const {
   }
 
   image += wxString::Format(
-			    wxS("\\picw%lu\\pich%lu "),
-			    (unsigned long)m_images[m_displayed]->GetOriginalWidth(),
-			    (unsigned long)m_images[m_displayed]->GetOriginalHeight());
+                            wxS("\\picw%lu\\pich%lu "),
+                            (unsigned long)m_images.at(m_displayed)->GetOriginalWidth(),
+                            (unsigned long)m_images.at(m_displayed)->GetOriginalHeight());
 
   // Convert the data into a hexadecimal string
   for (size_t i = 0; i <= imgdata.GetDataLen(); i++)
@@ -528,7 +525,7 @@ bool AnimationCell::CopyToClipboard() const {
                _("Bug: The clipboard is already opened"));
   if (wxTheClipboard->Open()) {
     bool res = wxTheClipboard->SetData(
-				       new wxBitmapDataObject(m_images[m_displayed]->GetUnscaledBitmap()));
+                                       new wxBitmapDataObject(m_images.at(m_displayed)->GetUnscaledBitmap()));
     wxTheClipboard->Close();
     return res;
   }
@@ -542,9 +539,7 @@ bool AnimationCell::IsOk() const {
     return false;
   if (m_displayed < 0)
     return false;
-  if (!m_images[m_displayed])
-    return false;
-  if (!m_images[m_displayed]->IsOk())
+  if (!m_images.at(m_displayed))
     return false;
   return true;
 }
