@@ -36,14 +36,14 @@ AtCell::AtCell(GroupCell *group, Configuration *config,
                std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&index)
   : Cell(group, config), m_baseCell(std::move(base)),
     m_indexCell(std::move(index)) {
-  InitBitFields();
+  InitBitFields_AtCell();
   SetStyle(TS_VARIABLE);
 }
 
 AtCell::AtCell(GroupCell *group, const AtCell &cell)
   : AtCell(group, cell.m_configuration,
-	   CopyList(group, cell.m_baseCell.get()),
-	   CopyList(group, cell.m_indexCell.get())) {
+           CopyList(group, cell.m_baseCell.get()),
+           CopyList(group, cell.m_indexCell.get())) {
   CopyCommonData(cell);
 }
 
