@@ -33,9 +33,9 @@
 #include "CellImpl.h"
 
 BoxCell::BoxCell(GroupCell *group, Configuration *config,
-                             std::unique_ptr<Cell> &&inner)
+                 std::unique_ptr<Cell> &&inner)
   : Cell(group, config), m_innerCell(std::move(inner)) {
-  InitBitFields();
+  InitBitFields_BoxCell();
   SetStyle(TS_VARIABLE);
 }
 
@@ -44,7 +44,7 @@ BoxCell::BoxCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=BoxCell::m_close
 BoxCell::BoxCell(GroupCell *group, const BoxCell &cell)
   : BoxCell(group, cell.m_configuration,
-		  CopyList(group, cell.m_innerCell.get())) {
+            CopyList(group, cell.m_innerCell.get())) {
   CopyCommonData(cell);
 }
 
@@ -90,29 +90,29 @@ void BoxCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     m_innerCell->DrawList(in, dc, antialiassingDC);
 
     dc->DrawLine(
-		 point.x + Scale_Px(2),
-		 point.y - m_center + m_height - Scale_Px(2),
+                 point.x + Scale_Px(2),
+                 point.y - m_center + m_height - Scale_Px(2),
                  point.x + m_width - Scale_Px(2) - 1,
                  point.y - m_center + m_height - Scale_Px(2)
-		 );
+                 );
     dc->DrawLine(
-		 point.x + Scale_Px(2),
-		 point.y - m_center + Scale_Px(2),
+                 point.x + Scale_Px(2),
+                 point.y - m_center + Scale_Px(2),
                  point.x + m_width - Scale_Px(2) - 1,
                  point.y - m_center + Scale_Px(2)
-		 );
+                 );
     dc->DrawLine(
-		 point.x + Scale_Px(2),
-		 point.y - m_center + m_height - Scale_Px(2),
-		 point.x + Scale_Px(2),
+                 point.x + Scale_Px(2),
+                 point.y - m_center + m_height - Scale_Px(2),
+                 point.x + Scale_Px(2),
                  point.y - m_center + Scale_Px(2)
-		 );
+                 );
     dc->DrawLine(
                  point.x + m_width - Scale_Px(2) - 1,
-		 point.y - m_center + Scale_Px(2),
+                 point.y - m_center + Scale_Px(2),
                  point.x + m_width - Scale_Px(2) - 1,
                  point.y - m_center + m_height - Scale_Px(2)
-		 );
+                 );
   }
 }
 
@@ -138,8 +138,8 @@ wxString BoxCell::ToTeX() const {
 }
 
 wxString BoxCell::ToMathML() const {
-   return wxS("<apply><box/><ci>") + m_innerCell->ListToMathML() +
-      wxS("</ci></apply>");
+  return wxS("<apply><box/><ci>") + m_innerCell->ListToMathML() +
+    wxS("</ci></apply>");
 }
 
 wxString BoxCell::ToOMML() const {
