@@ -34,10 +34,15 @@
 #include "TextCell.h"
 #include "VisiblyInvalidCell.h"
 #include "stx/unique_cast.hpp"
+#include <algorithm>
 #include <utility>
 #include <wx/regex.h>
 #include <wx/sstream.h>
 #include <wx/xml/xml.h>
+#include "SvgBitmap.h"
+#if wxCHECK_VERSION(3, 1, 6)
+#include <wx/bmpbndl.h>
+#endif
 
 const wxString &Cell::GetLocalToolTip() const { return *m_toolTip; }
 
@@ -59,7 +64,7 @@ Cell::Cell(GroupCell *group, Configuration *config)
   : m_group(group), m_configuration(config), m_toolTip(&wxm::emptyString),
     m_fontSize_Scaled(-1) {
   wxASSERT((!group) || ((group->GetType() == MC_TYPE_GROUP || group == this)));
-  InitBitFields();
+  InitBitFields_Cell();
   ResetSize();
 }
 
@@ -127,12 +132,48 @@ void Cell::SetType(CellType type) {
     GetGroup()->ResetSize();
 }
 
+wxBitmap Cell::BitmapFromSVG(wxString svgData, wxSize size)
+{
+  svgData.Replace("\"currentColor\"",
+                  "\"#" + wxColor2HtmlString(GetForegroundColor()) + "\"");
+#if wxCHECK_VERSION(3, 1, 6)
+  wxBitmapBundle sumbitmap = wxBitmapBundle::FromSVG(svgData.c_str(),
+                                                     size);
+  // Make the bitmap hi-res, if the OS supports and needs that
+  const wxWindow *worksheet = m_configuration->GetWorkSheet();
+  if(worksheet)
+    sumbitmap.GetPreferredBitmapSizeFor(worksheet);
+  wxBitmap bmp(sumbitmap.GetBitmap(size));
+#else
+  SvgBitmap bmp(m_configuration->GetWorkSheet(),
+                svgData,
+                size);
+#endif
+  return bmp;
+}
+
+bool Cell::FirstLineOnlyEditor()
+{
+  wxASSERT(GetGroup()->GetType() == MC_TYPE_GROUP);
+  return GetGroup()->FirstLineOnlyEditor();
+}
+
+wxString Cell::wxColor2HtmlString(wxColor col)
+{
+  return wxString::Format("%02X%02X%02X%02X",
+                          (unsigned int) col.Red(),
+                          (unsigned int) col.Green(),
+                          (unsigned int) col.Blue(),
+                          (unsigned int) col.Alpha());
+}
+
 void Cell::CopyCommonData(const Cell &cell) {
   wxASSERT(m_toolTip && !m_ownsToolTip);
   wxASSERT(cell.m_toolTip);
   if (cell.m_ownsToolTip) {
     m_ownsToolTip = true;
-    m_toolTip = new wxString(*cell.m_toolTip);
+    if(cell.m_toolTip)
+      m_toolTip = new wxString(*cell.m_toolTip);
   } else
     m_toolTip = cell.m_toolTip;
 
@@ -161,9 +202,9 @@ void Cell::ClearCacheList() {
     tmp.ClearCache();
 }
 
-int Cell::CellsInListRecursive() const {
+unsigned long Cell::CellsInListRecursive() const {
   //! The number of cells the current group contains (-1, if no GroupCell)
-  int cells = 0;
+  unsigned cells = 0;
 
   for (const Cell &tmp : OnList(this)) {
     ++cells;
@@ -191,8 +232,8 @@ void Cell::FontsChangedList() {
 GroupCell *Cell::GetGroup() const {
   GroupCell *group = m_group;
   wxASSERT_MSG(
-	       group,
-	       _("Bug: Math Cell that claims to have no group Cell it belongs to"));
+               group,
+               _("Bug: Math Cell that claims to have no group Cell it belongs to"));
   return group;
 }
 
@@ -213,7 +254,7 @@ int Cell::GetCenterList() const {
       if ((&tmp != this) && (tmp.m_breakLine))
         break;
       if (!tmp.m_isBrokenIntoLines)
-        maxCenter = wxMax(maxCenter, tmp.m_center);
+        maxCenter = std::max(maxCenter, tmp.m_center);
     }
     m_maxCenter.SetCached(maxCenter);
   }
@@ -227,7 +268,7 @@ int Cell::GetMaxDrop() const {
       if ((&tmp != this) && (tmp.m_breakLine))
         break;
       if (!tmp.m_isBrokenIntoLines)
-        maxDrop = wxMax(maxDrop, tmp.m_height - tmp.m_center);
+        maxDrop = std::max(maxDrop, tmp.m_height - tmp.m_center);
     }
     m_maxDrop.SetCached(maxDrop);
   }
@@ -275,11 +316,11 @@ void Cell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
   if(m_configuration->GetDebugmode())
     {
       if(!m_isHidden)
-	{
-	  wxASSERT(m_width >= 0);
-	  wxASSERT(m_height >= 0);
-	  wxASSERT(m_center >= 0);
-	}
+        {
+          wxASSERT(m_width >= 0);
+          wxASSERT(m_height >= 0);
+          wxASSERT(m_center >= 0);
+        }
     }
   m_configuration->NotifyOfCellRedraw(this);
 
@@ -348,9 +389,9 @@ void Cell::AddToolTip(const wxString &tip) {
 
 void Cell::SetAltCopyText(const wxString &text) {
   wxASSERT_MSG(
-	       text.empty(),
-	       wxString::Format(_("Bug: AltCopyTexts not implemented for %s cell"),
-				GetInfo().GetName()));
+               text.empty(),
+               wxString::Format(_("Bug: AltCopyTexts not implemented for %s cell"),
+                                GetInfo().GetName()));
 }
 
 void Cell::SetIsExponentList() {
@@ -373,7 +414,8 @@ void Cell::RecalculateList(AFontSize fontsize) {
 
 void Cell::ResetSizeList() {
   for (Cell &tmp : OnList(this))
-    tmp.ResetSize();
+    for (Cell &cell : OnInner(&tmp))
+      cell.ResetSize();
 }
 
 void Cell::Recalculate(AFontSize fontsize) {
@@ -442,11 +484,18 @@ bool Cell::InUpdateRegion() const {
     // scrolled by the user, or when maxima is updating it.
     wxRect cellRect;
     cellRect.SetPosition(m_currentPoint);
-    cellRect.SetWidth(m_configuration->GetCanvasSize().x - m_currentPoint.x);
-    if (m_next && m_next->HasValidPosition())
-      cellRect.SetHeight(m_next->m_currentPoint.y - m_currentPoint.y);
+    cellRect.SetWidth(m_configuration->GetCanvasSize().x);
+    if(GetHeight() > 0)
+      {
+        cellRect.SetHeight(GetHeight());
+      }
     else
-      cellRect.SetHeight(1);
+      {
+        if (m_next && m_next->HasValidPosition())
+          cellRect.SetHeight(m_next->m_currentPoint.y - m_currentPoint.y);
+        else
+          cellRect.SetHeight(1);
+      }
     return m_configuration->InUpdateRegion(cellRect);
   }
   return false;
@@ -589,7 +638,7 @@ wxString Cell::ListToMathML(bool startofline) const {
     // Handle linebreaks
     if ((&tmp != this) && (tmp.HasHardLineBreak()))
       retval +=
-	wxS("</mtd></mlabeledtr>\n<mlabeledtr columnalign=\"left\"><mtd>");
+        wxS("</mtd></mlabeledtr>\n<mlabeledtr columnalign=\"left\"><mtd>");
 
     // If a linebreak isn't followed by a label we need to introduce an empty
     // one.
@@ -636,7 +685,7 @@ wxString Cell::OMML2RTF(wxXmlNode *node) {
       while (attributes != NULL) {
         wxString ommlatt = attributes->GetName();
         result += wxS("{\\m") + ommlatt.Right(ommlatt.Length() - 2) + wxS(" ") +
-	  attributes->GetValue() + wxS("}");
+          attributes->GetValue() + wxS("}");
         attributes = attributes->GetNext();
       }
 
@@ -696,9 +745,9 @@ wxString Cell::RTFescape(wxString input, bool MarkDown) {
   // Encode unicode characters in a rather mind-boggling way
   wxString output;
   for (size_t i = 0; i < input.Length(); i++) {
-    wxChar ch = input[i];
+    wxChar ch = input.at(i);
     if (ch == wxS('\n')) {
-      if (((i > 0) && (input[i - 1] == wxS('\n'))) || !MarkDown)
+      if (((i > 0) && (input.at(i - 1) == wxS('\n'))) || !MarkDown)
         output += wxS("\\par}\n{\\pard ");
       else
         output += wxS("\n");
@@ -707,9 +756,9 @@ wxString Cell::RTFescape(wxString input, bool MarkDown) {
         output += ch;
       } else {
         if (ch < 32768) {
-          output += wxString::Format("\\u%i?", static_cast<int>(ch));
+          output += wxString::Format("\\u%li?", static_cast<long>(ch));
         } else {
-          output += wxString::Format("\\u%i?", static_cast<int>(ch) - 65536);
+          output += wxString::Format("\\u%li?", static_cast<long>(ch) - 65536);
         }
       }
     }
@@ -756,13 +805,13 @@ wxString Cell::ListToRTF(bool startofline) const {
     if (!rtf.empty()) {
       if ((GetTextStyle() == TS_LABEL) || ((GetTextStyle() == TS_USERLABEL))) {
         retval +=
-	  wxS("\\par}\n{\\pard\\s22\\li1105\\lin1105\\fi-1105\\f0\\fs24 ") +
-	  rtf + wxS("\\tab");
+          wxS("\\par}\n{\\pard\\s22\\li1105\\lin1105\\fi-1105\\f0\\fs24 ") +
+          rtf + wxS("\\tab");
         startofline = false;
       } else {
         if (startofline)
           retval += wxS("\\par}\n{\\pard\\s21\\li1105\\lin1105\\f0\\fs24 ") +
-	    rtf + wxS("\\n");
+            rtf + wxS("\\n");
         startofline = true;
       }
       tmp = tmp->GetNext();
@@ -901,7 +950,7 @@ void Cell::ResetDataList() {
 void Cell::ResetCellListSizesList() {
   for (const Cell &cell : OnList(this)) {
     cell.ResetCellListSizes();
-    for (const Cell &tmp : OnList(&cell))
+    for (const Cell &tmp : OnInner(&cell))
       tmp.ResetCellListSizes();
   }
 }
@@ -963,8 +1012,8 @@ void Cell::Unbreak() {
     // Unbreak the inner cells, too
     for (Cell &cell : OnInner(this))
       cell.UnbreakList();
-    SetNextToDraw(m_next);
   }
+  SetNextToDraw(GetNext());
 }
 
 void Cell::UnbreakList() {
@@ -976,7 +1025,7 @@ wxColour Cell::GetForegroundColor() const {
   wxColour color;
   if (m_highlight)
     color = m_configuration->GetColor(TS_HIGHLIGHT);
-  else 
+  else
     color = m_configuration->GetColor(GetTextStyle());
 
   return color;
@@ -987,13 +1036,13 @@ wxColour Cell::GetForegroundColor() const {
 // Set the pen in device context according to the style of the cell.
 void Cell::SetPen(wxDC *dc, double lineWidth) const {
   wxPen pen = *(wxThePenList->FindOrCreatePen(
-					      GetForegroundColor(),
-					      lineWidth * m_configuration->GetDefaultLineWidth(),
-					      wxPENSTYLE_SOLID));
+                                              GetForegroundColor(),
+                                              lineWidth * m_configuration->GetDefaultLineWidth(),
+                                              wxPENSTYLE_SOLID));
   dc->SetPen(pen);
 }
 
-void Cell::SetBrush(wxDC *dc) const {  
+void Cell::SetBrush(wxDC *dc) const {
   wxBrush brush = *(wxTheBrushList->FindOrCreateBrush(GetForegroundColor()));
   dc->SetBrush(brush);
 }
@@ -1057,20 +1106,33 @@ wxAccStatus Cell::GetDescription(int childId, wxString *description) const {
   if (GetChild(childId, &childCell) == wxACC_OK && childCell)
     return childCell->GetDescription(0, description);
 
-  return (description->clear()), wxACC_FAIL;
+  description->clear();
+  return wxACC_FAIL;
 }
 
 wxAccStatus CellAccessible::GetParent(wxAccessible **parent) {
+  if(!parent)
+    return wxACC_FAIL;
+
   Cell *parentCell = nullptr;
   auto rc = m_cell->GetParent(&parentCell);
   if (rc == wxACC_OK) {
     if (!parentCell && m_cell->GetConfiguration()->GetWorkSheet())
-      return (*parent =
-	      m_cell->GetConfiguration()->GetWorkSheet()->GetAccessible()),
-	wxACC_OK;
-
-    return parentCell ? (*parent = parentCell->GetAccessible()),
-      wxACC_OK   : wxACC_FAIL;
+      {
+        *parent =
+          m_cell->GetConfiguration()->GetWorkSheet()->GetAccessible();
+        return wxACC_OK;
+      }
+    if(parentCell)
+      {
+        *parent = parentCell->GetAccessible();
+        return wxACC_OK;
+      }
+    else
+      {
+        *parent = NULL;
+        return wxACC_OK;
+      }
   }
   return rc;
 }
@@ -1080,7 +1142,10 @@ wxAccStatus Cell::GetParent(Cell **parent) const {
     return wxACC_FAIL;
 
   if (*parent != this)
-    return (*parent = GetGroup()), wxACC_OK;
+    {
+      *parent = GetGroup();
+      return wxACC_OK;
+    }
 
   *parent = nullptr; // This means the worksheet
   return wxACC_OK;
@@ -1096,9 +1161,13 @@ wxAccStatus Cell::GetValue(int childId, wxString *strValue) const {
 
   Cell *childCell = nullptr;
   if (GetChild(childId, &childCell) == wxACC_OK)
-    return (*strValue = childCell->ToString()), wxACC_OK;
+    {
+      *strValue = childCell->ToString();
+      return wxACC_OK;
+    }
 
-  return (strValue->clear()), wxACC_FAIL;
+  strValue->clear();
+  return wxACC_FAIL;
 }
 
 wxAccStatus CellAccessible::GetChildCount(int *childCount) {
@@ -1109,7 +1178,8 @@ wxAccStatus CellAccessible::GetChildCount(int *childCount) {
   for (const Cell &cell : OnInner(m_cell))
     ++count;
 
-  return (*childCount = count), wxACC_OK;
+  *childCount = count;
+  return wxACC_OK;
 }
 
 static wxAccStatus ReturnCell(wxAccStatus rc, Cell *cell,
@@ -1131,8 +1201,13 @@ wxAccStatus Cell::HitTest(const wxPoint &pt, int *childId, Cell **child) {
   GetLocation(rect, 0);
   // If this cell doesn't contain the point none of the sub-cells does.
   if (!rect.Contains(pt))
-    return (childId && (*childId = 0)), (child && (*child = NULL)), //-V560
-      wxACC_FAIL;
+    {
+      if(childId)
+        *childId = 0;
+      if(child)
+        *child = NULL;
+      return wxACC_FAIL;
+    }
 
   int id = 0; // Child #0 is this very cell
   for (Cell &cell : OnInner(this)) {
@@ -1144,11 +1219,19 @@ wxAccStatus Cell::HitTest(const wxPoint &pt, int *childId, Cell **child) {
 
     cell.GetLocation(rect, 0);
     if (rect.Contains(pt))
-      return (childId && (*childId = id)), (child && (*child = &cell)),
-	wxACC_OK;
+      {
+        if(childId)
+          *childId = id;
+        if(child)
+          *child = &cell;
+        return wxACC_OK;
+      }
   }
-  return (childId && (*childId = 0)), (child && (*child = this)), //-V560
-    wxACC_OK;
+  if(childId)
+    *childId = 0;
+  if(child)
+    *child = this;
+  return wxACC_OK;
 }
 
 wxAccStatus CellAccessible::GetChild(int childId, wxAccessible **child) {
@@ -1162,12 +1245,18 @@ wxAccStatus Cell::GetChild(int childId, Cell **child) const {
     return wxACC_FAIL;
 
   if (childId == 0)
-    return (*child = const_cast<Cell *>(this)), wxACC_OK;
+    {
+      *child = const_cast<Cell *>(this);
+      return wxACC_OK;
+    }
 
   if (childId > 0)
     for (Cell &cell : OnInner(this))
       if (--childId == 0)
-        return (*child = &cell), wxACC_OK;
+        {
+          *child = &cell;
+          return wxACC_OK;
+        }
 
   return wxACC_FAIL;
 }
@@ -1185,12 +1274,20 @@ wxAccStatus Cell::GetFocus(int *childId, Cell **child) const {
 
     int dummy;
     if (cell.GetFocus(&dummy, child) == wxACC_OK)
-      return (childId && (*childId = id)), (child && (*child = &cell)),
-	wxACC_OK;
+      {
+        if(childId)
+          *childId = id;
+        if(child)
+          *child = &cell;
+        return wxACC_OK;
+      }
   }
 
-  return (childId && (*childId = 0)), (child && (*child = nullptr)), //-V560
-    wxACC_FAIL;
+  if (childId)
+    *childId = 0;
+  if(child)
+    *child = nullptr;
+  return wxACC_FAIL;
 }
 
 wxAccStatus CellAccessible::GetDefaultAction(int childId,
@@ -1203,7 +1300,10 @@ wxAccStatus Cell::GetDefaultAction(int childId, wxString *actionName) const {
     return wxACC_FAIL;
 
   if (childId == 0)
-    return actionName->Clear(), wxACC_OK;
+    {
+      actionName->Clear();
+      return wxACC_OK;
+    }
 
   Cell *childCell = nullptr;
   if (GetChild(childId, &childCell) == wxACC_OK && childCell)
@@ -1220,9 +1320,9 @@ wxAccStatus CellAccessible::GetLocation(wxRect &rect, int elementId) {
 wxAccStatus Cell::GetLocation(wxRect &rect, int elementId) {
   if (elementId == 0) {
     rect = wxRect(GetRect().GetTopLeft() +
-		  m_configuration->GetVisibleRegion().GetTopLeft(),
+                  m_configuration->GetVisibleRegion().GetTopLeft(),
                   GetRect().GetBottomRight() +
-		  m_configuration->GetVisibleRegion().GetTopLeft());
+                  m_configuration->GetVisibleRegion().GetTopLeft());
     if (rect.GetTop() < 0)
       rect.SetTop(0);
     if (rect.GetLeft() < 0)
@@ -1233,7 +1333,7 @@ wxAccStatus Cell::GetLocation(wxRect &rect, int elementId) {
       rect.SetRight(m_configuration->GetVisibleRegion().GetHeight());
     rect =
       wxRect(rect.GetTopLeft() + m_configuration->GetWorksheetPosition(),
-	     rect.GetBottomRight() + m_configuration->GetWorksheetPosition());
+             rect.GetBottomRight() + m_configuration->GetWorksheetPosition());
     return wxACC_OK;
   }
 
@@ -1257,11 +1357,37 @@ wxAccStatus Cell::GetRole(int WXUNUSED(childId), wxAccRole *role) const {
 
 #endif
 
-int Cell::GetInnerCellCount() const { return 0; }
+size_t Cell::GetInnerCellCount() const { return 0; }
 
-Cell *Cell::GetInnerCell(int) const {
+Cell *Cell::GetInnerCell(size_t) const {
   // This method should never have been called since there are no inner cells
   // in this class.
   wxASSERT_MSG(false, "Invalid use of GetInnerCell with no inner cells");
   return nullptr;
 }
+
+std::ostream& operator<<(std::ostream& out, const CellType celltype){
+  std::string result;
+  switch(celltype){
+  case MC_TYPE_DEFAULT: result = "MC_TYPE_DEFAULT"; break;
+  case MC_TYPE_MAIN_PROMPT: result = "MC_TYPE_MAIN_PROMPT"; break;
+  case MC_TYPE_PROMPT: result = "MC_TYPE_PROMPT"; break;
+  case MC_TYPE_LABEL: result = "MC_TYPE_LABEL"; break;
+  case   MC_TYPE_INPUT: result = "MC_TYPE_INPUT"; break;
+  case MC_TYPE_WARNING: result = "MC_TYPE_WARNING"; break;
+  case MC_TYPE_ERROR: result = "MC_TYPE_ERROR"; break;
+  case MC_TYPE_TEXT: result = "MC_TYPE_TEXT"; break;
+  case MC_TYPE_ASCIIMATHS: result = "MC_TYPE_ASCIIMATHS"; break;
+  case MC_TYPE_SUBSECTION: result = "MC_TYPE_SUBSECTION"; break;
+  case MC_TYPE_SUBSUBSECTION: result = "MC_TYPE_SUBSUBSECTION"; break;
+  case MC_TYPE_HEADING5: result = "MC_TYPE_HEADING5"; break;
+  case MC_TYPE_HEADING6: result = "MC_TYPE_HEADING6"; break;
+  case MC_TYPE_SECTION: result = "MC_TYPE_SECTION"; break;
+  case MC_TYPE_TITLE: result = "MC_TYPE_TITLE"; break;
+  case MC_TYPE_IMAGE: result = "MC_TYPE_IMAGE"; break;
+  case MC_TYPE_SLIDE: result = "MC_TYPE_SLIDE"; break;
+  case MC_TYPE_GROUP: result = "MC_TYPE_GROUP"; break;
+  default: result = "!!!Bug: Unknown cell type!!!";
+  }
+  return out << result;
+}
