@@ -35,7 +35,7 @@
 ConjugateCell::ConjugateCell(GroupCell *group, Configuration *config,
                              std::unique_ptr<Cell> &&inner)
   : Cell(group, config), m_innerCell(std::move(inner)) {
-  InitBitFields();
+  InitBitFields_ConjungateCell();
   SetStyle(TS_VARIABLE);
 }
 
@@ -44,7 +44,7 @@ ConjugateCell::ConjugateCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=ConjugateCell::m_close
 ConjugateCell::ConjugateCell(GroupCell *group, const ConjugateCell &cell)
   : ConjugateCell(group, cell.m_configuration,
-		  CopyList(group, cell.m_innerCell.get())) {
+                  CopyList(group, cell.m_innerCell.get())) {
   CopyCommonData(cell);
 }
 
