@@ -42,15 +42,21 @@ DiffCell::DiffCell(GroupCell *group, Configuration *config,
     m_diffCell(std::move(diff))
 
 {
-  InitBitFields();
+  InitBitFields_DiffCell();
   SetStyle(TS_VARIABLE);
   m_diffCell->SetSuppressMultiplicationDot(true);
+  if(m_baseCell)
+    {
+      if((m_baseCell->ToString() == wxS("*")) ||
+         (m_baseCell->ToString() == wxS("\u00B7")))
+      m_baseCell->Hide(true);
+    }
 }
 
 DiffCell::DiffCell(GroupCell *group, const DiffCell &cell)
   : DiffCell(group, cell.m_configuration,
-	     CopyList(group, cell.m_baseCell.get()),
-	     CopyList(group, cell.m_diffCell.get())) {
+             CopyList(group, cell.m_baseCell.get()),
+             CopyList(group, cell.m_diffCell.get())) {
   CopyCommonData(cell);
 }
 
@@ -69,9 +75,9 @@ void DiffCell::Recalculate(AFontSize fontsize) {
   m_diffCell->RecalculateList(fontsize);
   if (!IsBrokenIntoLines()) {
     m_width = m_baseCell->GetFullWidth() + m_diffCell->GetFullWidth();
-    m_center = wxMax(m_diffCell->GetCenterList(), m_baseCell->GetCenterList());
+    m_center = std::max(m_diffCell->GetCenterList(), m_baseCell->GetCenterList());
     m_height =
-      m_center + wxMax(m_diffCell->GetMaxDrop(), m_baseCell->GetMaxDrop());
+      m_center + std::max(m_diffCell->GetMaxDrop(), m_baseCell->GetMaxDrop());
   } else {
     m_width = m_center = m_height = 0;
     m_open->RecalculateList(fontsize);
