@@ -37,16 +37,16 @@
 */
 
 /*! This class defines what the user sees as input cell
-  
+
   This class handles input cells including:
   - The per-cell undo buffer
   - The handling of key presses when this cell is active
-  
-  Since Unicode doesn't provide us with a "soft linebreak" letter we 
+
+  Since Unicode doesn't provide us with a "soft linebreak" letter we
   use <code>\\r</code> as a marker that this line has to be broken here if we
   don't want it to extend beyond the right margin of the screen.
 
-  In a few places we use wxString::const_iterator instead of accessing individual 
+  In a few places we use wxString::const_iterator instead of accessing individual
   letters within the string using the [] operator. This might look overly
   complicated. But in UTF-8 all non-standard-ASCII-characters use more than one
   byte making iterating over every single char of the string the only way of
@@ -68,15 +68,33 @@ private:
 
 public:
   //! The constructor
-  EditorCell(GroupCell *group, Configuration *config, const wxString &text = {});
+  EditorCell(GroupCell *group, Configuration *config, wxString text = {});
   EditorCell(GroupCell *group, const EditorCell &cell);
-//  std::unique_ptr<Cell> Copy(GroupCell *group) const override;
+  void UpdateSelectionString();
+  void SetSelection(size_t start, size_t end){m_selectionStart = start; m_selectionEnd = end;UpdateSelectionString();}
+  bool SelectionActive() const {return m_selectionStart != m_selectionEnd;}
+  void ClearSelection() {SelectionEnd(SelectionEnd());}
+  void SelectionStart(size_t start) {m_selectionStart = start; UpdateSelectionString();}
+  void SelectionEnd(size_t end) {m_selectionEnd = end; UpdateSelectionString();}
+  size_t SelectionStart() const {return std::min(m_selectionStart, m_text.Length());}
+  size_t SelectionEnd() const {return std::min(m_selectionEnd, m_text.Length());}
+  size_t SelectionLeft() const {return std::min(SelectionStart(), SelectionEnd());}
+  size_t SelectionRight() const {return std::max(SelectionStart(), SelectionEnd());}
+  size_t SelectionLength() const {return(SelectionEnd()-SelectionStart());}
+  void  SelectionLength(size_t length) {SelectionEnd(SelectionStart() + length);  UpdateSelectionString();}
+  void CursorMove(long long increment) {m_selectionEnd += increment;
+    m_selectionStart = m_selectionEnd; UpdateSelectionString();}
+  size_t CursorPosition() const {return std::min(m_selectionEnd, m_text.Length());}
+  void CursorPosition(size_t pos) {m_selectionStart = pos;
+    m_selectionEnd = pos; UpdateSelectionString();}
   const CellTypeInfo &GetInfo() override;
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
 
   //! Get the previous EditorCell in the list
+  // cppcheck-suppress duplInheritedMember
   EditorCell *GetPrevious() const { return dynamic_cast<EditorCell*>(Cell::GetPrevious()); }
   //! Get the next EditorCell in the list.
+  // cppcheck-suppress duplInheritedMember
   EditorCell *GetNext() const { return dynamic_cast<EditorCell*>(Cell::GetNext()); }
 
   //! Insert the symbol that corresponds to the ESC command txt
@@ -97,7 +115,7 @@ public:
 
     \param index The index of the character the search was started at.
   */
-  void SearchStartedHere(int index) const;
+  void SearchStartedHere(size_t index) const;
   //! Remember that this is the cell the search was started in.
   void SearchStartedHere() const;
   //! Remember that this is the cell the mouse selection was started in.
@@ -114,7 +132,7 @@ public:
     \param posInLine The number of characters that come before the input in the same line
     \todo Implement the actual TAB expansion
   */
-  static wxString TabExpand(const wxString &input_, long posInLine);
+  static wxString TabExpand(const wxString &input_, size_t posInLine);
 
   //! Escape all chars that cannot be used in HTML otherwise
   static wxString EscapeHTMLChars(wxString input);
@@ -130,7 +148,7 @@ public:
   wxString ToHTML() const;
   wxString ToMatlab() const override;
   /*! Convert the current cell to a string
-  
+
     \param dontLimitToSelection
     - false: If text is selected return only the selected text
     - true:  Always return all text in this text cell
@@ -157,7 +175,7 @@ public:
   void SetForeground(wxDC *dc);
 
   /*! Sets the text that is to be displayed.
-    
+
     Automatically calls StyleText().
   */
   void SetValue(const wxString &text) override;
@@ -187,7 +205,7 @@ public:
   void ProcessEvent(wxKeyEvent &event) override;
 
   /*! Activate the blinking cursor in this cell
-    
+
     Automatically calls DeactivateCursor on an eventual cell the cursor currently is in.
     Normally Mathctrl::SetActiveCell() is used in order to get this function called.
 
@@ -199,22 +217,23 @@ public:
   void DeactivateCursor();
 
   //! Return the index of the 1st char of the line containing the letter pos.
-  size_t BeginningOfLine(long pos) const;
+  size_t BeginningOfLine(size_t pos) const;
 
   //! Return the index of the last char of the line containing the letter \#pos,
-  size_t EndOfLine(long pos);
+  size_t EndOfLine(size_t pos);
 
   //! Adds a ";" to the end of the last command in this cell in case that it doesn't end in $ or ;
   bool AddEnding() override;
 
   //! Determines which line and column the pos'th char is at.
-  void PositionToXY(int position, unsigned int *x, unsigned int *y);
+  void PositionToXY(size_t position,  size_t *x, size_t *y);
 
   //! Determines which index the char at the position "x chars left, y chars down" is at.
-  int XYToPosition(int x, int y);
+  size_t XYToPosition(size_t x, size_t y);
 
   //! The screen coordinates of the cursor
-  wxPoint PositionToPoint(int pos = -1) override;
+  wxPoint PositionToPoint(size_t pos) override;
+  wxPoint PositionToPoint() override {return PositionToPoint(CursorPosition());}
 
   //! Sets the cursor to the screen coordinate point
   void SelectPointText(wxPoint point) override;
@@ -236,48 +255,42 @@ public:
   void PasteFromClipboard(bool primary = false) override;
 
   //! Get the character position the selection has been started with
-  int GetSelectionStart() const
-    { return m_selectionStart; }
+  size_t GetSelectionStart() const
+    { return SelectionStart(); }
 
   //! Get the character position the selection has been ended with
-  int GetSelectionEnd() const
-    { return m_selectionEnd; }
+  long GetSelectionEnd() const
+    { return SelectionEnd(); }
 
   //! Select the whole text contained in this Cell
   void SelectAll() override
     {
-      m_selectionStart = 0;
-      m_selectionEnd = m_positionOfCaret = m_text.Length();
+      SetSelection(0, m_text.Length());
     }
 
   //! Does the selection currently span the whole cell?
   bool AllSelected() const
     {
-      return (m_selectionStart == 0) && (m_selectionEnd == (long) m_text.Length());
+      return (SelectionStart() == 0) && (SelectionEnd() == m_text.Length());
     }
 
   //! Unselect everything.
   void SelectNone()
     {
-      m_selectionStart = m_selectionEnd = 0;
+      ClearSelection();
     }
 
-  //! Is there any text selected right now?
-  bool SelectionActive() const
-    {
-      return (m_selectionStart >= 0) && (m_selectionEnd >= 0);
-    }
 
   bool CanCopy() const override
     {
-      return m_selectionStart != -1;
+      return SelectionActive();
     }
 
   bool FindMatchingQuotes();
 
   void FindMatchingParens();
 
-  int GetLineWidth(unsigned int line, int pos);
+  wxCoord GetLineWidth(size_t line, size_t pos);
 
   //! true, if this cell's width has to be recalculated.
   bool IsDirty() const override
@@ -296,50 +309,79 @@ public:
       m_hasFocus = focus;
     }
 
-  void SetFirstLineOnly(bool show = true)
-    {
-      if (m_firstLineOnly != show)
-      {
-        m_width = m_height = -1;
-        m_firstLineOnly = show;
-      }
-      // Style the text anew.
-      StyleText();
-    }
-
   bool IsActive() const override;
 
   //! Is the cursor at the start of this cell?
   bool CaretAtStart() const
-    { return m_positionOfCaret == 0; }
+    { return CursorPosition() == 0; }
 
   //! Move the cursor to the start of this cell
   void CaretToStart();
 
   //! Is the cursor at the end of this cell?
   bool CaretAtEnd() const
-    { return m_positionOfCaret == (long) m_text.Length(); }
+    { return CursorPosition() == m_text.Length(); }
 
   //! Move the cursor to the end of this cell
   void CaretToEnd();
 
   //! Move the cursor to a certain position in the cell
-  void CaretToPosition(int pos);
+  void CaretToPosition(size_t pos);
 
   //! True, if there is undo information for this cell
-  bool CanUndo() const;
+  bool CanUndo() const {return m_history.CanUndo();}
 
   //! Issue an undo command
   void Undo();
 
   //! True, if a redo can be done for this cell.
-  bool CanRedo() const;
+  bool CanRedo() const {return m_history.CanRedo();}
 
   //! Issu a redo command
   void Redo();
 
+    //! The undo history of this cell
+  class History
+  {
+  public:
+    enum Action : uintptr_t {
+      any = 0,
+      removeChar  = 1,
+      addChar = 2
+    };
+
+    //! How an entry to the undo history looks like
+    class HistoryEntry // 64 bytes
+    {
+    public:
+      HistoryEntry(){};
+      HistoryEntry(const wxString &text, long long selStart, long long selEnd) :
+        m_text(text), m_selStart(selStart), m_selEnd(selEnd) {}
+      long long SelectionStart() const {return m_selStart;}
+      long long SelectionEnd() const {return m_selEnd;}
+      wxString GetText() const {return m_text;}
+    private:
+      wxString m_text;
+      long long m_selStart = -1;
+      long long m_selEnd = -1;
+    };
+    bool AddState(HistoryEntry entry, Action action = any);
+    bool AddState(wxString text, long long selStart, long long selEnd, Action action = any);
+    bool Undo();
+    bool Redo();
+    bool CanUndo() const;
+    bool CanRedo() const;
+    void ClearUndoBuffer();
+    HistoryEntry GetState() const;
+  private:
+    std::vector<HistoryEntry> m_history;
+    //! Where in the undo history are we?
+    size_t m_historyPosition = 0;
+    Action m_lastAction = any;
+  };
+
   //! Save the current contents of this cell in the undo buffer.
-  void SaveValue();
+  void SaveValue(History::Action action = History::Action::any);
 
   /*! DivideAtCaret
     Returns the string from caret to end and
@@ -351,8 +393,6 @@ public:
 
   void CommentSelection();
 
-  void ClearUndo();
-
   //! Query if this cell needs to be re-evaluated by maxima
   bool ContainsChanges() const
     { return m_containsChanges; }
@@ -365,13 +405,13 @@ public:
 
   /*! Replaces all occurrences of a given string
    */
-  int ReplaceAll(wxString oldString, const wxString &newString, bool ignoreCase);
-  int ReplaceAll_RegEx(wxString oldString, const wxString &newString);
+  size_t ReplaceAll(wxString oldString, const wxString &newString, bool ignoreCase);
+  size_t ReplaceAll_RegEx(wxString oldString, const wxString &newString);
 
   /*! Finds the next occurrences of a string
 
     \param str The string to search for
-    \param down 
+    \param down
     - true: search downwards
     - false: search upwards
     \param ignoreCase
@@ -383,12 +423,10 @@ public:
 
   bool IsSelectionChanged() const { return m_selectionChanged; }
 
-  void SetSelection(int start, int end);
-
-  void GetSelection(int *start, int *end) const
+  void GetSelection(size_t *start, size_t *end) const
     {
-      *start = m_selectionStart;
-      *end = m_selectionEnd;
+      *start = SelectionStart();
+      *end   = SelectionEnd();
     }
 
   /*! Replace the current selection with a string
@@ -396,7 +434,7 @@ public:
     \param oldStr The old string in the selection. If this string doesn't match
     the selection this function doesn't replace it.
     \param newString The new string oldStr has to be replaced by
-    \param keepSelected 
+    \param keepSelected
     - true = we want the new string to be selected afterwards
     - false = the selection is cleared after replacing the string
     and moving the cursor to its end.
@@ -419,35 +457,28 @@ public:
 
   //! Get the command the cursor is in the arguments for.
   wxString GetCurrentCommand();
-  
-  //! Unselect everything
-  void ClearSelection();
 
   //! Sets the index the error is at
-  void SetErrorIndex(int index){m_errorIndex = index;}
+  void SetErrorIndex(size_t index){m_errorIndex = index; m_errorIndexSet = true;}
+  //! Clears the index the error is at
+  void ClearErrorIndex(){m_errorIndexSet = false;}
 
-  bool ErrorIndexSet() const {return m_errorIndex >= 0;}
+  bool ErrorIndexSet() const {return m_errorIndexSet;}
 
-  void GotoError(){SetCaretPosition(m_errorIndex); ActivateCursor();}
+  void GotoError(){SetCaretPosition(m_errorIndex); ActivateCursor(); ClearErrorIndex();}
 
   //! Start a new line and optionally auto-indent it.
   void ProcessNewline(bool keepCursorAtStartOfLine = true);
 
   //! Get the cursor's current position inside the cell.
-  int GetCaretPosition() const
-    { return m_positionOfCaret; }
+  size_t GetCaretPosition() const
+    { return CursorPosition(); }
 
   //! Convert a number to unicode chars.
   void ConvertNumToUNicodeChar();
 
   //! Set the cursor's current position inside the cell.
-  void SetCaretPosition(int pos)
-    { m_positionOfCaret = pos;
-      if(m_positionOfCaret < -1)
-        m_positionOfCaret = -1;
-      if(m_positionOfCaret > (signed long)m_text.Length())
-        m_positionOfCaret = m_text.Length();
-    }
+  void SetCaretPosition(size_t pos){CursorPosition(pos);}
 
   bool FindNextTemplate(bool left = false);
 
@@ -455,7 +486,7 @@ public:
 
   wxString TextInFrontOfSelection() const
     {
-      return GetValue().Mid(1, m_selectionStart);
+      return GetValue().Mid(1, SelectionLeft());
     }
 
   //! Return to the selection after the cell has been left upwards
@@ -481,6 +512,9 @@ public:
   const MaximaTokenizer::TokenList &GetAllTokens();
 
 private:
+  size_t m_selectionStart = 0;
+  size_t m_selectionEnd = 0;
+  size_t m_lastSelectionStart = 0;
   //! Did the zoom factor change since the last recalculation?
   bool IsZoomFactorChanged() const;
   //! The zoom factor we had the last time we recalculated this cell.
@@ -493,7 +527,7 @@ private:
     - '\n'
     - whitespace
     - '\\r' indicating a soft line break optionally equipped with indentation
-    and a character that marks a continued quote or similar 
+    and a character that marks a continued quote or similar
   */
   class StyledText
   {
@@ -504,9 +538,9 @@ private:
     //! Chars that mark continued indentation
     wxString m_indentChar;
     //! The cached width of this piece of text
-    int m_width = -1;
+    wxCoord m_width = -1;
     //! By How many pixels we want to indent this line?
-    int m_indentPixels = 0;
+    wxCoord m_indentPixels = 0;
     //! The color of this text portion
     TextStyle m_style = TS_CODE_DEFAULT;
     //! Do we really want to style this text portion different than the default?
@@ -517,26 +551,26 @@ private:
       : m_text(text), m_style(style), m_styleThisText(true) {}
 
     //! Defines a piece of text with the default style that possibly is indented
-    explicit StyledText(const wxString &text, int indentPixels = 0,
+    explicit StyledText(const wxString &text, wxCoord indentPixels = 0,
                         const wxString &indentChar = {})
       : m_text(text), m_indentChar(indentChar), m_indentPixels(indentPixels)  {}
 
-    void SetWidth(int width){m_width = width;}
+    void SetWidth(wxCoord width){m_width = width;}
     void ResetSize(){SetWidth(-1);}
-    int GetWidth() const {return m_width;}
+    wxCoord GetWidth() const {return m_width;}
     bool SizeKnown() const {return GetWidth() >= 0;}
     //! Returns the piece of text
     const wxString &GetText() const { return m_text; }
     //! Changes the piece of text kept in this token
     void SetText(const wxString &text) { m_text = text; }
     //! Changes the indentation level of this token
-    void SetIndentation(int indentPixels, const wxString &indentString = {})
+    void SetIndentation(wxCoord indentPixels, const wxString &indentString = {})
       {
         m_indentPixels = indentPixels;
         m_indentChar = indentString;
       }
     //! By how many pixels do we need to indent this line due to a bullet list or similar?
-    int GetIndentPixels() const { return m_indentPixels; }
+    wxCoord GetIndentPixels() const { return m_indentPixels; }
     const wxString &GetIndentChar() const { return m_indentChar; }
     //! If IsStyleSet() is true this function returns the style of this text
     //! portion
@@ -560,19 +594,19 @@ private:
 
   /*! Adds soft line breaks to code cells, if needed.
 
-    \todo: We could do an incremental indentation calculation that starts at the last word: 
-    The current behavior is O(n^2) (scanning the text needs linear time and for each word 
+    \todo: We could do an incremental indentation calculation that starts at the last word:
+    The current behavior is O(n^2) (scanning the text needs linear time and for each word
     the indentation algorithm scans the text again) which is unfortunate.
   */
-  void HandleSoftLineBreaks_Code(StyledText *&lastSpace, int &lineWidth, const wxString &token, unsigned int charInCell,
-                                 wxString &text, const size_t &lastSpacePos, int &indentationPixels);
+  void HandleSoftLineBreaks_Code(StyledText *&lastSpace, wxCoord &lineWidth, const wxString &token, size_t charInCell,
+                                 wxString &text, const size_t &lastSpacePos, wxCoord &indentationPixels);
 
   /*! How many chars do we need to indent text at the position the caret is currently at?
 
     \todo We should provide an alternative function that allows to resume the calculation
     for the next word/line - which would provide an additional speedup.
   */
-  int GetIndentDepth(wxString text, int positionOfCaret);
+  size_t GetIndentDepth(wxString text, size_t  positionOfCaret);
 
   /*! Handle ESC shortcuts for special characters
 
@@ -583,25 +617,16 @@ private:
   static wxString InterpretEscapeString(const wxString &txt);
 
   //! Draw a box that marks the current selection
-  void MarkSelection(wxDC *dc, long start, long end, TextStyle style);
+  void MarkSelection(wxDC *dc, size_t start, size_t end, TextStyle style);
 
   //! Determines the size of a text snippet
   wxSize GetTextSize(const wxString &text);
 
-  struct HistoryEntry // 64 bytes
-  {
-    wxString text;
-    int caretPosition = -1;
-    int selStart = -1;
-    int selEnd = -1;
-    HistoryEntry() = default;
-    HistoryEntry(const wxString &text, int caretPosition, int selStart, int selEnd) :
-      text(text), caretPosition(caretPosition), selStart(selStart), selEnd(selEnd) {}
-  };
+  //! The memory for the undo history
+  History m_history;  
   //! Set the editor's state from a history entry
-  void SetState(const HistoryEntry &state);
-  //! Append the editor's state to the history
-  void AppendStateToHistory();
+  void SetState(const History::HistoryEntry &state);
+  //! Get the styled text
   std::vector<StyledText> &GetStyledText();
 
 //** Large fields
@@ -618,7 +643,7 @@ private:
   std::vector<wxString> m_wordList;
 
   //! The individual commands, parenthesis, strings and whitespaces a code cell consists of
-   MaximaTokenizer::TokenList m_tokens;
+  MaximaTokenizer::TokenList m_tokens;
   //! The individual commands, parenthesis, strings and whitespaces including hidden lines
   MaximaTokenizer::TokenList m_tokens_including_hidden;
 
@@ -627,47 +652,16 @@ private:
   wxString m_text;
   std::vector<StyledText> m_styledText;
 
-  std::vector<HistoryEntry> m_history;
-
 //** 8/4 bytes
 //**
   CellPointers *const m_cellPointers = GetCellPointers();
 
 //** 4 bytes
 //**
-  int m_errorIndex = 1;
-  unsigned int m_numberOfLines = 1;
-  //! Where in the undo history are we?
-  int m_historyPosition = -1;
-
-  /*! The start of the current selection.
-
-    - >0: the position of the cursors in characters from start
-    - -1: Currently no selection is active
-
-    If the selection has been done from right to left m_selectionStart>m_selectionEnd.
-  */
-  long m_selectionStart = -1;
-  /*! The end of the current selection.
-
-    - >0: the position of the cursors in characters from start
-    - -1: Currently no selection is active
-
-    If the selection has been done from right to left m_selectionStart>m_selectionEnd.
-  */
-  long m_selectionEnd = -1;
-  long m_oldSelectionStart = -1;
-  long m_oldSelectionEnd = -1;
-  long m_lastSelectionStart = -1;
-
-  int m_charHeight = 12;
-  int m_paren1 = -1, m_paren2 = -1;
-
-  //! Where inside this cell is the cursor?
-  int m_positionOfCaret = 0;
-  //! Which column the cursor would be if the current line were long enough?
-  //! Used when moving up/down between lines
-  int m_caretColumn = -1;
+  size_t m_errorIndex = 1;
+  size_t m_numberOfLines = 1;
+  wxCoord m_charHeight = 12;
+  long m_paren1 = -1, m_paren2 = -1;
 
 //** 2 bytes
 //**
@@ -683,35 +677,33 @@ private:
 
 //** Bitfield objects (2 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_EditorCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_autoAnswer = false;
       m_containsChanges = false;
       m_containsChangesCheck = false;
       m_displayCaret = false;
-      m_firstLineOnly = false;
       m_hasFocus = false;
       m_isDirty = false;
-      m_saveValue = false;
       m_selectionChanged = false;
       m_underlined = false;
+      m_errorIndexSet = false;
     }
 
   //! Mark this cell as "Automatically answer questions".
-  bool m_autoAnswer : 1 /* InitBitFields */;
+  bool m_autoAnswer : 1 /* InitBitFields_EditorCell */;
   //! true, if this function has changed since the last evaluation by maxima
-  bool m_containsChanges : 1 /* InitBitFields */;
-  bool m_containsChangesCheck : 1 /* InitBitFields */;
-  bool m_displayCaret : 1 /* InitBitFields */;
-  bool m_firstLineOnly : 1 /* InitBitFields */;
-  bool m_hasFocus : 1 /* InitBitFields */;
-  bool m_isDirty : 1 /* InitBitFields */;
-  bool m_saveValue :1 /* InitBitFields */;
+  bool m_containsChanges : 1 /* InitBitFields_EditorCell */;
+  bool m_containsChangesCheck : 1 /* InitBitFields_EditorCell */;
+  bool m_displayCaret : 1 /* InitBitFields_EditorCell */;
+  bool m_hasFocus : 1 /* InitBitFields_EditorCell */;
+  bool m_isDirty : 1 /* InitBitFields_EditorCell */;
+  bool m_errorIndexSet : 1 /* InitBitFields_EditorCell */;
   //! Has the selection changed since the last draw event?
-  bool m_selectionChanged : 1 /* InitBitFields */;
+  bool m_selectionChanged : 1 /* InitBitFields_EditorCell */;
   //! Does this cell's size have to be recalculated?
-  bool m_underlined : 1 /* InitBitFields */;
+  bool m_underlined : 1 /* InitBitFields_EditorCell */;
 };
 
 #endif // EDITORCELL_H
