@@ -38,14 +38,14 @@ ExptCell::ExptCell(GroupCell *group, Configuration *config,
                    std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&expt)
   : Cell(group, config), m_baseCell(std::move(base)),
     m_exptCell(std::move(expt)) {
-  InitBitFields();
+  InitBitFields_ExptCell();
   SetStyle(TS_VARIABLE);
 }
 
 ExptCell::ExptCell(GroupCell *group, const ExptCell &cell)
   : ExptCell(group, cell.m_configuration,
-	     CopyList(group, cell.m_baseCell.get()),
-	     CopyList(group, cell.m_exptCell.get())) {
+             CopyList(group, cell.m_baseCell.get()),
+             CopyList(group, cell.m_exptCell.get())) {
   CopyCommonData(cell);
   m_altCopyText = cell.m_altCopyText;
 }
