@@ -37,17 +37,17 @@
 FracCell::FracCell(GroupCell *group, Configuration *config,
                    std::unique_ptr<Cell> &&num, std::unique_ptr<Cell> &&denom)
   : Cell(group, config), m_numParenthesis(std::make_unique<ParenCell>(
-								      group, m_configuration, std::move(num))),
+                                                                      group, m_configuration, std::move(num))),
     m_denomParenthesis(std::make_unique<ParenCell>(group, m_configuration,
-						   std::move(denom))) {
-  InitBitFields();
+                                                   std::move(denom))) {
+  InitBitFields_FracCell();
   SetStyle(TS_VARIABLE);
   SetupBreakUps();
 }
 
 FracCell::FracCell(GroupCell *group, const FracCell &cell)
   : FracCell(group, cell.m_configuration, CopyList(group, cell.Num()),
-	     CopyList(group, cell.Denom())) {
+             CopyList(group, cell.Denom())) {
   CopyCommonData(cell);
   m_fracStyle = cell.m_fracStyle;
   SetupBreakUps();
@@ -57,6 +57,24 @@ FracCell::FracCell(GroupCell *group, const FracCell &cell)
 
 DEFINE_CELL(FracCell)
 
+void FracCell::SetFracStyle(FracType style)
+{ m_fracStyle = style;
+  if(style == FC_DIFF)
+    {
+      Cell *multsign = Denom();
+      if(multsign)
+        multsign = multsign->GetNext();
+      if(multsign)
+        {
+          if ((multsign->GetValue() == wxS("\u00B7")) || (multsign->GetValue() == wxS("*")))
+            multsign->Hide(true);
+          else
+            wxLogMessage(_("diff(): Cannot find the multiplication sign I should hide"));
+        }
+    }
+}
+
+
 void FracCell::MakeDivideCell() {
   if (m_divideOwner)
     return;
@@ -83,10 +101,10 @@ void FracCell::Recalculate(AFontSize fontsize) {
     if (m_inExponent) {
       m_protrusion = m_horizontalGapLeft = m_horizontalGapRight = 0;
       m_width = Num()->GetWidth() + Denom()->GetWidth() + m_divide->GetWidth();
-      m_height = wxMax(Num()->GetHeightList(), Denom()->GetHeightList()) +
-	Scale_Px(6.5);
+      m_height = std::max(Num()->GetHeightList(), Denom()->GetHeightList()) +
+        Scale_Px(6.5);
       m_center =
-	wxMax(Num()->GetCenterList(), Denom()->GetCenterList()) + Scale_Px(3);
+        std::max(Num()->GetCenterList(), Denom()->GetCenterList()) + Scale_Px(3);
     } else {
       m_protrusion = Scale_Px(m_configuration->GetMathFontSize() / 2);
 
@@ -103,11 +121,11 @@ void FracCell::Recalculate(AFontSize fontsize) {
       else
         m_horizontalGapRight = 0;
 
-      m_width = wxMax(m_displayedNum->GetFullWidth(),
+      m_width = std::max(m_displayedNum->GetFullWidth(),
                       m_displayedDenom->GetFullWidth()) +
-	2 * m_protrusion + m_horizontalGapLeft + m_horizontalGapRight;
+        2 * m_protrusion + m_horizontalGapLeft + m_horizontalGapRight;
       m_height =
-	Num()->GetHeightList() + Denom()->GetHeightList() + Scale_Px(6.5);
+        Num()->GetHeightList() + Denom()->GetHeightList() + Scale_Px(6.5);
       m_center = Num()->GetHeightList() + Scale_Px(3);
     }
   }
@@ -135,29 +153,29 @@ void FracCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
       m_displayedDenom->DrawList(denom, dc, antialiassingDC);
     } else {
       num.x = point.x + m_horizontalGapLeft +
-	(m_width - m_horizontalGapLeft - m_horizontalGapRight -
-	 m_displayedNum->GetFullWidth()) /
-	2;
+        (m_width - m_horizontalGapLeft - m_horizontalGapRight -
+         m_displayedNum->GetFullWidth()) /
+        2;
       num.y = point.y - m_displayedNum->GetHeightList() +
-	m_displayedNum->GetCenterList();
+        m_displayedNum->GetCenterList();
       m_displayedNum->DrawList(num, dc, antialiassingDC);
 
       denom.x = point.x + m_horizontalGapLeft +
-	(m_width - m_horizontalGapLeft - m_horizontalGapRight -
-	 m_displayedDenom->GetFullWidth()) /
-	2;
+        (m_width - m_horizontalGapLeft - m_horizontalGapRight -
+         m_displayedDenom->GetFullWidth()) /
+        2;
       denom.y = point.y + m_displayedDenom->GetCenterList() + Scale_Px(4);
       m_displayedDenom->DrawList(denom, dc, antialiassingDC);
       if (m_fracStyle != FC_CHOOSE)
-	{
-	  SetPen(antialiassingDC, 1.2);
-	  antialiassingDC->DrawLine(point.x + m_horizontalGapLeft +
-				    m_configuration->GetDefaultLineWidth() / 2,
-				    point.y + Scale_Px(2),
-				    point.x + m_width - m_horizontalGapRight -
-				    m_configuration->GetDefaultLineWidth() / 2,
-				    point.y + Scale_Px(2));
-	}
+        {
+          SetPen(antialiassingDC, 1.2);
+          antialiassingDC->DrawLine(point.x + m_horizontalGapLeft +
+                                    m_configuration->GetDefaultLineWidth() / 2,
+                                    point.y + Scale_Px(2),
+                                    point.x + m_width - m_horizontalGapRight -
+                                    m_configuration->GetDefaultLineWidth() / 2,
+                                    point.y + Scale_Px(2));
+        }
     }
   }
 }
@@ -176,7 +194,7 @@ wxString FracCell::ToString() const {
         s += Denom()->ListToString();
     } else if (m_fracStyle == FC_CHOOSE) {
       s = wxS("binomial(") + Num()->ListToString() + wxS(",") +
-	Denom()->ListToString() + wxS(")");
+        Denom()->ListToString() + wxS(")");
     } else {
       Cell *tmp = Denom();
       while (tmp != NULL) {
@@ -211,7 +229,7 @@ wxString FracCell::ToMatlab() const {
         s += Denom()->ListToMatlab();
     } else if (m_fracStyle == FC_CHOOSE) {
       s = wxS("binomial(") + Num()->ListToMatlab() + wxS(",") +
-	Denom()->ListToMatlab() + wxS(")");
+        Denom()->ListToMatlab() + wxS(")");
     } else {
       for (Cell *tmp = Denom(); tmp; tmp = tmp->GetNext()) {
         tmp = tmp->GetNext(); // Skip the d
@@ -235,10 +253,10 @@ wxString FracCell::ToTeX() const {
   if (!IsBrokenIntoLines()) {
     if (m_fracStyle == FC_CHOOSE) {
       s = wxS("\\begin{pmatrix}") + Num()->ListToTeX() + wxS("\\\\\n") +
-	Denom()->ListToTeX() + wxS("\\end{pmatrix}");
+        Denom()->ListToTeX() + wxS("\\end{pmatrix}");
     } else {
       s = wxS("\\frac{") + Num()->ListToTeX() + wxS("}{") +
-	Denom()->ListToTeX() + wxS("}");
+        Denom()->ListToTeX() + wxS("}");
     }
   }
   return s;
