@@ -48,6 +48,7 @@
 #include <wx/log.h>
 #include <wx/string.h>
 #include <wx/config.h>
+#include <clocale>
 
 #ifdef __WINDOWS__
 constexpr bool TEMPORARY_WINDOWS_PERFORMANCE_HACK = true;
@@ -113,7 +114,7 @@ private:
 GroupCell::GroupCell(Configuration *config, GroupType groupType,
                      const wxString &initString)
   : Cell(this, config), m_groupType(groupType) {
-  InitBitFields();
+  InitBitFields_GroupCell();
   m_mathFontSize = m_configuration->GetMathFontSize();
   ForceBreakLine();
   m_type = MC_TYPE_GROUP;
@@ -122,7 +123,7 @@ GroupCell::GroupCell(Configuration *config, GroupType groupType,
   if (groupType != GC_TYPE_PAGEBREAK) {
     if (groupType == GC_TYPE_CODE)
       m_inputLabel =
-	std::make_unique<LabelCell>(this, m_configuration, EMPTY_INPUT_LABEL);
+        std::make_unique<LabelCell>(this, m_configuration, EMPTY_INPUT_LABEL);
     else
       m_inputLabel = std::make_unique<TextCell>(this, m_configuration, wxS(""));
 
@@ -130,10 +131,7 @@ GroupCell::GroupCell(Configuration *config, GroupType groupType,
   }
 
   std::unique_ptr<EditorCell> editor =
-    std::make_unique<EditorCell>(this, m_configuration);
-
-  if (!initString.empty())
-    editor->SetValue(initString);
+    std::make_unique<EditorCell>(this, m_configuration, initString);
   AppendInput(std::move(editor));
 
   SetGroupType(groupType);
@@ -143,10 +141,9 @@ GroupCell::GroupCell(Configuration *config, GroupType groupType,
   if ((groupType == GC_TYPE_IMAGE) && (initString.Length() > 0)) {
     std::unique_ptr<Cell> ic;
     if (wxImage::GetImageCount(initString) < 2) {
-      std::shared_ptr<wxFileSystem> fs;
       ic = std::make_unique<ImgCell>(
-				     this, m_configuration, initString,
-				     fs, false);
+                                     this, m_configuration, initString,
+                                     wxEmptyString, false);
 
       // Since this is the (only?) place where an ImgCell is constructed when
       // the user manually inserts an image file (not loaded from zip or gnuplot
@@ -228,10 +225,10 @@ std::unique_ptr<GroupCell> GroupCell::CopyList() const {
 
 bool GroupCell::Empty() const {
   return (
-	  // No next cell
-	  (!GetNext()) &&
-	  // This cell at maximum contains a prompt.
-	  (ToString().Length() < 6));
+          // No next cell
+          (!GetNext()) &&
+          // This cell at maximum contains a prompt.
+          (ToString().Length() < 6));
 }
 
 void GroupCell::ResetInputLabel() {
@@ -260,11 +257,11 @@ bool GroupCell::IsFoldable() const {
 
 GroupCell::~GroupCell() {}
 
-const wxString &GroupCell::GetAnswer(int answer) const {
+const wxString &GroupCell::GetAnswer(size_t answer) const {
   if ((!m_autoAnswer) && (!m_configuration->OfferKnownAnswers()))
     return wxm::emptyString;
 
-  wxString const question = wxString::Format(wxS("Question #%i"), answer);
+  wxString const question = wxString::Format(wxS("Question #%li"), static_cast<long>(answer));
   auto it = m_knownAnswers.find(question);
   return (it != m_knownAnswers.end()) ? it->second : wxm::emptyString;
 }
@@ -354,8 +351,6 @@ void GroupCell::RemoveOutput() {
   m_cellPointers->m_errorList.Remove(this);
   // Calculate the new cell height.
 
-  Cell::Hide(false);
-
   m_height = m_inputHeight;
   if (m_inputLabel)
     m_width = m_inputLabel->GetFullWidth();
@@ -400,8 +395,8 @@ void GroupCell::UpdateConfusableCharWarnings() {
 
   if (GetEditable())
     for (auto const &tok :
-	   MaximaTokenizer(output, m_configuration, GetEditable()->GetAllTokens())
-	   .PopTokens())
+           MaximaTokenizer(output, m_configuration, GetEditable()->GetAllTokens())
+           .PopTokens())
       if ((tok.GetTextStyle() == TS_CODE_VARIABLE) ||
           (tok.GetTextStyle() == TS_CODE_FUNCTION))
         cmdsAndVariables[tok.GetText()] = 1;
@@ -442,21 +437,22 @@ void GroupCell::UpdateConfusableCharWarnings() {
 
 bool GroupCell::Recalculate() {
   bool retval = NeedsRecalculation(EditorFontSize());
-  
+
   if (retval == true) {
-    // Recalculating pagebreaks is simple
     if (m_groupType == GC_TYPE_PAGEBREAK) {
+      // Recalculating pagebreak cells is simple
       retval = NeedsRecalculation(EditorFontSize());
       m_width = m_configuration->GetCellBracketWidth();
       m_height = Scale_Px(2);
       m_center = Scale_Px(1);
     }
     else {
+      // This cell is no page break cell
       m_mathFontSize = m_configuration->GetMathFontSize();
-      
+
       if (m_inputLabel != NULL)
-	RecalculateInput();
-      
+        RecalculateInput();
+
       RecalculateOutput();
       m_height = m_outputRect.GetHeight() + m_inputHeight;
     }
@@ -483,7 +479,7 @@ void GroupCell::InputHeightChanged() {
   if (m_output != NULL) {
     m_height += m_outputRect.GetHeight();
     m_outputRect.y = m_currentPoint.y + m_center;
-    m_width = wxMax(m_width, m_output->GetLineWidth());
+    m_width = std::max(m_width, m_output->GetLineWidth());
   }
   UpdateYPositionList();
 }
@@ -570,7 +566,7 @@ void GroupCell::RecalculateOutput() {
   // Recalculate size of all output cells
   for (Cell &tmp : OnList(m_output.get())) {
     tmp.Recalculate(tmp.IsMath() ? m_configuration->GetMathFontSize()
-		    : m_configuration->GetDefaultFontSize());
+                    : m_configuration->GetDefaultFontSize());
   }
 
   // Breakup cells and break lines
@@ -580,7 +576,7 @@ void GroupCell::RecalculateOutput() {
   // breaking lines
   for (Cell &tmp : OnList(m_output.get())) {
     tmp.Recalculate(tmp.IsMath() ? m_configuration->GetMathFontSize()
-		    : m_configuration->GetDefaultFontSize());
+                    : m_configuration->GetDefaultFontSize());
   }
 
   // Calculate the height of the output
@@ -588,8 +584,8 @@ void GroupCell::RecalculateOutput() {
     if (tmp.BreakLineHere()) {
       tmp.ResetCellListSizes();
       int height_Delta = tmp.GetHeightList();
-      m_width = wxMax(m_width, tmp.GetLineWidth());
-      m_outputRect.width = wxMax(m_outputRect.width, m_width);
+      m_width = std::max(m_width, tmp.GetLineWidth());
+      m_outputRect.width = std::max(m_outputRect.width, m_width);
       m_outputRect.height += height_Delta;
 
       if (tmp.GetPrevious() &&
@@ -616,7 +612,7 @@ void GroupCell::UpdateYPositionList() {
 }
 
 void GroupCell::UpdateYPosition() {
-  auto *const previous = GetPrevious();
+  const Cell *const previous = GetPrevious();
 
   wxPoint point(m_configuration->GetIndent(), GetCenter());
   if (!previous) {
@@ -647,9 +643,9 @@ int GroupCell::GetInputIndent() {
   if (m_inputLabel != NULL) {
     if (m_inputLabel->GetWidth() >= 0)
       labelWidth =
-	wxMax(m_inputLabel->GetWidth() + MC_TEXT_PADDING, labelWidth);
+        std::max(m_inputLabel->GetWidth() + MC_TEXT_PADDING, labelWidth);
     else
-      labelWidth = wxMax(m_labelWidth_cached, labelWidth);
+      labelWidth = std::max(m_labelWidth_cached, labelWidth);
   }
 
   m_labelWidth_cached = labelWidth;
@@ -726,32 +722,32 @@ void GroupCell::Draw(wxPoint const point, wxDC *dc, wxDC *antialiassingDC) {
       m_outputRect.SetPosition(in);
 
       if((!m_configuration->ClipToDrawRegion()) ||
-	 (m_configuration->GetUpdateRegion().Intersects(m_outputRect)))
-	{
-	  bool isFirst = true;
-	  int drop = 0;
-	  for (Cell &tmp : OnDrawList(m_output.get())) {
-	    if (isFirst || tmp.BreakLineHere()) {
-	      if (!isFirst && tmp.HasBigSkip())
-		in.y += MC_LINE_SKIP;
-	      
-	      in.x = point.x + GetLineIndent(&tmp);
-	      in.y += drop + tmp.GetCenterList();
-	      drop = tmp.GetMaxDrop();
-	    }
-	    tmp.Draw(in, dc, antialiassingDC);
-	    in.x += tmp.GetWidth();
-	    isFirst = false;
-	  }
-	}
+         (m_configuration->GetUpdateRegion().Intersects(m_outputRect)))
+        {
+          bool isFirst = true;
+          int drop = 0;
+          for (Cell &tmp : OnDrawList(m_output.get())) {
+            if (isFirst || tmp.BreakLineHere()) {
+              if (!isFirst && tmp.HasBigSkip())
+                in.y += MC_LINE_SKIP;
+
+              in.x = point.x + GetLineIndent(&tmp);
+              in.y += drop + tmp.GetCenterList();
+              drop = tmp.GetMaxDrop();
+            }
+            tmp.Draw(in, dc, antialiassingDC);
+            in.x += tmp.GetWidth();
+            isFirst = false;
+          }
+        }
     }
     if ((m_configuration->ShowCodeCells()) || (m_groupType != GC_TYPE_CODE)) {
       m_configuration->Outdated(false);
-      
+
       EditorCell *input = GetEditable();
       if (input)
         input->Draw(CalculateInputPosition(), dc, antialiassingDC);
-      
+
       if (GetPrompt())
         GetPrompt()->Draw(point, dc, antialiassingDC);
 
@@ -819,12 +815,12 @@ void GroupCell::DrawBracket(wxDC *dc, wxDC *antialiassingDC) {
   // will add brackets in
   if ((m_currentPoint.y >= selectionStart_px) &&
       (m_currentPoint.y <= selectionEnd_px)) {
-      dc->SetPen(*(wxThePenList->FindOrCreatePen(
-						 m_configuration->GetColor(TS_SELECTION),
-						 m_configuration->GetDefaultLineWidth(), wxPENSTYLE_SOLID)));
+    dc->SetPen(*(wxThePenList->FindOrCreatePen(
+                                               m_configuration->GetColor(TS_SELECTION),
+                                               m_configuration->GetDefaultLineWidth(), wxPENSTYLE_SOLID)));
     // window linux, set a pen
-      dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
-						       m_configuration->GetColor(TS_SELECTION))));
+    dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
+                                                     m_configuration->GetColor(TS_SELECTION))));
     drawBracket = true;
   } else if (m_cellPointers->m_errorList.Contains(this)) {
     dc->SetPen(*wxRED_PEN);
@@ -839,13 +835,13 @@ void GroupCell::DrawBracket(wxDC *dc, wxDC *antialiassingDC) {
     } else {
       dc->SetBrush(m_configuration->GetBackgroundBrush());
       dc->SetPen(*(wxThePenList->FindOrCreatePen(
-						 m_configuration->DefaultBackgroundColor(),
-						 m_configuration->GetDefaultLineWidth(), wxPENSTYLE_SOLID)));
+                                                 m_configuration->DefaultBackgroundColor(),
+                                                 m_configuration->GetDefaultLineWidth(), wxPENSTYLE_SOLID)));
     }
   }
   wxRect rect = GetRect();
   rect = wxRect(m_configuration->GetIndent() -
-		m_configuration->GetCellBracketWidth(),
+                m_configuration->GetCellBracketWidth(),
                 rect.GetTop() - 2, m_configuration->GetCellBracketWidth(),
                 rect.GetHeight() + 5);
   if (m_configuration->InUpdateRegion(rect))
@@ -859,20 +855,20 @@ void GroupCell::DrawBracket(wxDC *dc, wxDC *antialiassingDC) {
     dc->SetBrush(*wxTRANSPARENT_BRUSH);
     if (m_lastInEvaluationQueue)
       {
-	dc->SetPen(*(wxThePenList->FindOrCreatePen(
-						 m_configuration->GetColor(TS_CELL_BRACKET),
-						 2 * m_configuration->GetDefaultLineWidth(), wxPENSTYLE_SOLID)));
+        dc->SetPen(*(wxThePenList->FindOrCreatePen(
+                                                   m_configuration->GetColor(TS_CELL_BRACKET),
+                                                   2 * m_configuration->GetDefaultLineWidth(), wxPENSTYLE_SOLID)));
       }
     else
       {
-	dc->SetPen(*(wxThePenList->FindOrCreatePen(
-						   m_configuration->GetColor(TS_CELL_BRACKET),
-						   m_configuration->GetDefaultLineWidth(), wxPENSTYLE_SOLID)));
+        dc->SetPen(*(wxThePenList->FindOrCreatePen(
+                                                   m_configuration->GetColor(TS_CELL_BRACKET),
+                                                   m_configuration->GetDefaultLineWidth(), wxPENSTYLE_SOLID)));
       }
     wxRect bracketRect = wxRect(
-				m_configuration->GetIndent() - m_configuration->GetCellBracketWidth(),
-				rect.GetTop() - 2, m_configuration->GetCellBracketWidth(),
-				rect.GetHeight() + 5);
+                                m_configuration->GetIndent() - m_configuration->GetCellBracketWidth(),
+                                rect.GetTop() - 2, m_configuration->GetCellBracketWidth(),
+                                rect.GetHeight() + 5);
     if (m_configuration->InUpdateRegion(bracketRect))
       dc->DrawRectangle(bracketRect);
   }
@@ -881,18 +877,18 @@ void GroupCell::DrawBracket(wxDC *dc, wxDC *antialiassingDC) {
   if (editable != NULL && editable->IsActive()) {
     drawBracket = true;
     antialiassingDC->SetPen(*(wxThePenList->FindOrCreatePen(
-						m_configuration->GetColor(TS_ACTIVE_CELL_BRACKET),
-						2 * m_configuration->GetDefaultLineWidth(),
-						wxPENSTYLE_SOLID))); // window linux, set a pen
+                                                            m_configuration->GetColor(TS_ACTIVE_CELL_BRACKET),
+                                                            2 * m_configuration->GetDefaultLineWidth(),
+                                                            wxPENSTYLE_SOLID))); // window linux, set a pen
     dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
-						     m_configuration->GetColor(TS_ACTIVE_CELL_BRACKET)))); // highlight c.
+                                                     m_configuration->GetColor(TS_ACTIVE_CELL_BRACKET)))); // highlight c.
   } else {
     antialiassingDC->SetPen(*(wxThePenList->FindOrCreatePen(
-						m_configuration->GetColor(TS_CELL_BRACKET),
-						m_configuration->GetDefaultLineWidth(),
-						wxPENSTYLE_SOLID))); // window linux, set a pen
+                                                            m_configuration->GetColor(TS_CELL_BRACKET),
+                                                            m_configuration->GetDefaultLineWidth(),
+                                                            wxPENSTYLE_SOLID))); // window linux, set a pen
     dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
-						     m_configuration->GetColor(TS_CELL_BRACKET)))); // highlight c.
+                                                     m_configuration->GetColor(TS_CELL_BRACKET)))); // highlight c.
   }
 
   if ((!IsHidden()) && (!m_hiddenTree)) {
@@ -907,13 +903,13 @@ void GroupCell::DrawBracket(wxDC *dc, wxDC *antialiassingDC) {
     int lineWidth = m_configuration->GetDefaultLineWidth();
     int lineWidth_2 = m_configuration->GetDefaultLineWidth() / 2.0;
     if (IsFoldable()) { // draw the square that allows hiding and unhiding the
-                        // cell
+      // cell
       const wxPoint points[4] = {{-bracketWidth, 0},
                                  {-bracketWidth, bracketWidth},
                                  {-lineWidth, bracketWidth},
                                  {-lineWidth, 0}};
       antialiassingDC->DrawPolygon(4, points, m_currentPoint.x,
-                       m_currentPoint.y - m_center);
+                                   m_currentPoint.y - m_center);
     } else {
       int n = 0;
       wxPoint points[9];
@@ -926,11 +922,11 @@ void GroupCell::DrawBracket(wxDC *dc, wxDC *antialiassingDC) {
       if (m_configuration->ShowCodeCells() && m_groupType == GC_TYPE_CODE &&
           m_output && !IsHidden()) {
         points[n++] = {-bracketWidth + lineWidth_2,
-	  m_inputLabel->GetHeightList()};
+                       m_inputLabel->GetHeightList()};
         points[n++] = {-bracketWidth / 2 + lineWidth_2,
-	  m_inputLabel->GetHeightList()};
+                       m_inputLabel->GetHeightList()};
         points[n++] = {-bracketWidth + lineWidth_2,
-	  m_inputLabel->GetHeightList()};
+                       m_inputLabel->GetHeightList()};
       }
 
       // The remaining part of the vertical line at the back
@@ -941,20 +937,20 @@ void GroupCell::DrawBracket(wxDC *dc, wxDC *antialiassingDC) {
 
       wxASSERT(n <= (std::end(points) - std::begin(points)));
       antialiassingDC->DrawPolygon(n, points, m_currentPoint.x,
-                       m_currentPoint.y - m_center);
+                                   m_currentPoint.y - m_center);
     }
   }
 }
 
 wxRect GroupCell::HideRect() {
   return wxRect(m_currentPoint.x - m_configuration->GetCellBracketWidth() -
-		m_configuration->GetDefaultLineWidth() / 2,
+                m_configuration->GetDefaultLineWidth() / 2,
                 m_currentPoint.y - m_center -
-		m_configuration->GetDefaultLineWidth() / 2,
+                m_configuration->GetDefaultLineWidth() / 2,
                 m_configuration->GetCellBracketWidth() +
-		m_configuration->GetDefaultLineWidth(),
+                m_configuration->GetDefaultLineWidth(),
                 m_configuration->GetCellBracketWidth() +
-		m_configuration->GetDefaultLineWidth());
+                m_configuration->GetDefaultLineWidth());
 }
 
 wxString GroupCell::ToString() const {
@@ -998,7 +994,7 @@ wxString GroupCell::ToRTF() const {
     if (m_inputLabel && m_configuration->ShowCodeCells()) {
       if (GetPrevious())
         retval =
-	  wxS("\\par}{\\pard\\s22\\li1105\\lin1105\\fi-1105\\f0\\fs24 \n");
+          wxS("\\par}{\\pard\\s22\\li1105\\lin1105\\fi-1105\\f0\\fs24 \n");
       else
         retval += wxS("\\pard\\s22\\li1105\\lin1105\\fi-1105\\f0\\fs24 ");
       retval += RTFescape(m_inputLabel->ToString());
@@ -1040,8 +1036,9 @@ wxString GroupCell::ToTeX(wxString imgDir, wxString filename,
       auto *const imgCopy = dynamic_cast<ImgCell *>(copy.get());
       (*imgCounter)++;
       wxString image = filename + wxString::Format(wxS("_%d"), *imgCounter);
-      wxString file =
-	imgDir + wxS("/") + image + wxS(".") + imgCopy->GetExtension();
+      wxString file;
+      if(imgCopy)
+        file = imgDir + wxS("/") + image + wxS(".") + imgCopy->GetExtension();
 
       if (!wxDirExists(imgDir))
         wxMkdir(imgDir);
@@ -1114,19 +1111,23 @@ wxString GroupCell::ToTeXCodeCell(wxString imgDir, wxString filename,
   if (m_configuration->ShowCodeCells()) {
     // For LaTeX export we must use a dot as decimal separator
     // Save LC_NUMERIC, set it to "C", print out the float and then restore it.
-    const std::string saved_lc_numeric{
-      setlocale(LC_NUMERIC, NULL)}; // get current LC_NUMERIC locale
-    setlocale(LC_NUMERIC, "C");
+    char *old_lc_numeric;
+    wxString saved_lc_numeric("C");
+    old_lc_numeric =
+      std::setlocale(LC_NUMERIC, NULL); // get current LC_NUMERIC locale
+    if (old_lc_numeric)
+      saved_lc_numeric = wxString::FromUTF8(old_lc_numeric);
+    std::setlocale(LC_NUMERIC, "C");
     str += wxString::Format(
-			    "\n\n\\noindent\n%%%%%%%%%%%%%%%%\n%%%% "
-			    "INPUT:\n\\begin{minipage}[t]{%fem}\\color{red}\\bfseries\n",
-			    static_cast<double>(m_configuration->GetLabelWidth() / 14)) +
+                            "\n\n\\noindent\n%%%%%%%%%%%%%%%%\n%%%% "
+                            "INPUT:\n\\begin{minipage}[t]{%fem}\\color{red}\\bfseries\n",
+                            static_cast<double>(m_configuration->GetLabelWidth() / 14)) +
       m_inputLabel->ToTeX() + wxString("\n\\end{minipage}");
-    setlocale(LC_NUMERIC, saved_lc_numeric.c_str());
+    std::setlocale(LC_NUMERIC, saved_lc_numeric.c_str());
 
     if (m_inputLabel->GetNext()) {
       str += wxS("\n\\begin{minipage}[t]{\\textwidth}\\color{blue}\n") +
-	m_inputLabel->GetNext()->ToTeX() + "\n\\end{minipage}";
+        m_inputLabel->GetNext()->ToTeX() + "\n\\end{minipage}";
     }
   }
 
@@ -1212,7 +1213,7 @@ wxString GroupCell::ToTeXImage(const Cell *tmp, wxString imgDir, wxString filena
     if (imgCopy->ToImageFile(file).x >= 0)
       str += wxS("\\includegraphics[width=.95\\linewidth,height=."
                  "80\\textheight,keepaspectratio]{") +
-	filename + wxS("_img/") + image + wxS("}");
+        filename + wxS("_img/") + image + wxS("}");
     else
       str << wxS("\n\\verb|<<GRAPHICS>>|\n");
   }
@@ -1227,7 +1228,7 @@ wxString GroupCell::ToXML() const {
   switch (m_groupType) {
   case GC_TYPE_CODE: {
     str += wxS(" type=\"code\"");
-    int i = 0;
+    size_t i = 0;
     for (StringHash::const_iterator it = m_knownAnswers.begin();
          it != m_knownAnswers.end(); ++it) {
       i++;
@@ -1238,8 +1239,10 @@ wxString GroupCell::ToXML() const {
       question.Replace(wxS("\n"), wxS("&#10;"));
       wxString answer = Cell::XMLescape(it->second);
       answer.Replace(wxS("\n"), wxS("&#10;"));
-      str += wxString::Format(wxS(" question%i=\""), i) + question + wxS("\"");
-      str += wxString::Format(wxS(" answer%i=\""), i) + answer + wxS("\"");
+      str += wxString::Format(wxS(" question%li=\""), static_cast<long>(i)) +
+        question + wxS("\"");
+      str += wxString::Format(wxS(" answer%li=\""), static_cast<long>(i)) +
+        answer + wxS("\"");
     }
 
     if (m_autoAnswer)
@@ -1371,6 +1374,8 @@ Cell::Range GroupCell::GetCellsInOutputRect(const wxRect &rect,
     return {};
 
   wxASSERT(r.last);
+  if (!r.last)
+    return {};
 
   // If selection is on multiple lines, we need to correct it
   if (r.first->GetCurrentY() != r.last->GetCurrentY()) {
@@ -1416,7 +1421,16 @@ const wxString &GroupCell::GetToolTip(const wxPoint point) const {
   if (IsHidden())
     return *retval;
 
+  for (auto &tmp : OnList(m_inputLabel.get())) {
+    if (tmp.ContainsPoint(point))
+      m_cellPointers->m_cellUnderPointer = &tmp;
+  }
+
+  // TODO: Handle the case that m_cellUnderPointer should be a cell inside a cell
   for (auto &tmp : OnList(m_output.get())) {
+    if (tmp.ContainsPoint(point))
+      m_cellPointers->m_cellUnderPointer = &tmp;
+
     // If a cell contains a cell containing a tooltip, the tooltip of the
     // containing cell will be overridden.
     // TODO: Why do we keep iterating? Is there a reason to return the
@@ -1545,7 +1559,7 @@ bool GroupCell::BreakUpCells(Cell *cell) const {
   // Reduce the number of steps involved in layouting big equations
   if (m_cellsInGroup > showLength) {
     wxLogMessage(
-		 _("Resolving to 1D layout for one cell in order to save time"));
+                 _("Resolving to 1D layout for one cell in order to save time"));
     return false;
   } else {
     bool lineHeightsChanged = false;
@@ -1596,8 +1610,12 @@ bool GroupCell::UnBreakUpCells(Cell *cell) const {
   return retval;
 }
 
-// support for hiding text, code cells
+bool GroupCell::FirstLineOnlyEditor()
+{
+  return(IsHidden() && (!IsHeading()));
+}
 
+// support for hiding text, code cells
 void GroupCell::Hide(bool hide) {
   if (IsFoldable())
     return;
@@ -1605,9 +1623,10 @@ void GroupCell::Hide(bool hide) {
   if (IsHidden() == hide)
     return;
 
+  if(GetEditable())
+    GetEditable()->StyleText();
+
   Cell::Hide(hide);
-  if ((m_groupType == GC_TYPE_TEXT) || (m_groupType == GC_TYPE_CODE))
-    GetEditable()->SetFirstLineOnly(hide);
 
   // Don't keep cached versions of scaled images around if they aren't visible
   // at all.
@@ -1628,17 +1647,17 @@ bool GroupCell::HideTree(std::unique_ptr<GroupCell> &&tree) {
   if (m_hiddenTree)
     return false;
   if(tree) {
-        m_hiddenTree = std::move(tree);
-	m_hiddenTree->SetHiddenTreeParent(this);
-      
-	// Clear cached images from cells that are hidden
-	for (auto &tmp : OnList(m_hiddenTree.get())) {
-	  if (tmp.GetLabel())
-	    tmp.GetLabel()->ClearCacheList();
-	}
-	
-	m_cellsAppended = true;
-  return true;
+    m_hiddenTree = std::move(tree);
+    m_hiddenTree->SetHiddenTreeParent(this);
+
+    // Clear cached images from cells that are hidden
+    for (auto &tmp : OnList(m_hiddenTree.get())) {
+      if (tmp.GetLabel())
+        tmp.GetLabel()->ClearCacheList();
+    }
+
+    m_cellsAppended = true;
+    return true;
   }
   else
     return false;
@@ -1922,9 +1941,9 @@ wxAccStatus GroupCell::GetDescription(int childId,
 wxAccStatus GroupCell::GetLocation(wxRect &rect, int elementId) {
   if (elementId == 0) {
     rect = wxRect(GetRect().GetTopLeft() +
-		  m_configuration->GetVisibleRegion().GetTopLeft(),
+                  m_configuration->GetVisibleRegion().GetTopLeft(),
                   GetRect().GetBottomRight() +
-		  m_configuration->GetVisibleRegion().GetTopLeft());
+                  m_configuration->GetVisibleRegion().GetTopLeft());
 
     // Our GroupCell handles the hcaret below the cell, as well as its contents
     rect.SetBottom(rect.GetBottom() + m_configuration->GetGroupSkip());
@@ -1944,7 +1963,7 @@ wxAccStatus GroupCell::GetLocation(wxRect &rect, int elementId) {
       rect.SetRight(m_configuration->GetVisibleRegion().GetHeight());
     rect =
       wxRect(rect.GetTopLeft() + m_configuration->GetWorksheetPosition(),
-	     rect.GetBottomRight() + m_configuration->GetWorksheetPosition());
+             rect.GetBottomRight() + m_configuration->GetWorksheetPosition());
     return wxACC_OK;
   } else {
     Cell *childCell = nullptr;
@@ -1967,43 +1986,64 @@ void CellList::Check(const GroupCell *c) {
 }
 
 wxString GroupCell::m_lookalikeChars(
-				     wxS("µ") wxS("\u03bc") wxS("\u2126") wxS("\u03a9") wxS("C") wxS(
-												     "\u03F2") wxS("C") wxS("\u0421") wxS("\u03F2") wxS("\u0421") wxS("A")
-				     wxS("\u0391") wxS("A") wxS("\u0410") wxS("\u0391") wxS("\u0410") wxS(
-													  "M") wxS("\u0392") wxS("E") wxS("\u0395") wxS("E") wxS("\u0415")
-				     wxS("\u0415") wxS("\u0395") wxS("Z") wxS("\u0396") wxS("H") wxS(
-												     "\u0397") wxS("H") wxS("\u041D") wxS("\u0397") wxS("\u041D")
-				     wxS("I") wxS("\u0399") wxS("I") wxS("\u0406") wxS("l") wxS(
-												"\u0406") wxS("K") wxS("\u039A")
-				     wxS("K") wxS("\u041A") wxS("\u039A") wxS("\u041A") wxS("\u212a") wxS(
-													  "\u041A") wxS("K") wxS("\u212A") wxS("M") wxS("\u041c") wxS("\u039C")
-				     wxS("\u041c") wxS("M") wxS("\u039C") wxS("N") wxS("\u039D") wxS("O") wxS(
-													      "\u039F") wxS("O") wxS("\u041E") wxS("\u039F") wxS("\u041E") wxS("\u039F")
-				     wxS("\u041E") wxS("P") wxS("\u03A1") wxS("X") wxS("\u0425") wxS("e") wxS(
-													      "\u0435") wxS("p") wxS("\u0440") wxS("x") wxS("\u0445") wxS("y")
-				     wxS("\u0443") wxS("P") wxS("\u0420") wxS("\u03A1") wxS(
-											    "\u0420") wxS("T") wxS("\u03A4") wxS("T") wxS("\u0422") wxS("\u03A4")
-				     wxS("\u0422") wxS("Y") wxS("\u03A5") wxS("\u212a") wxS(
-											    "\u039A") wxS("l") wxS("I") wxS("B")
-				     wxS("\u0392") wxS("S") wxS("\u0405") wxS("\u0392") wxS(
-											    "\u0412") wxS("B") wxS("\u0412") wxS("J")
-				     wxS("\u0408") wxS("a") wxS("\u0430") wxS(
-									      "o") wxS("\u03bf") wxS("\u03a3") wxS("\u2211")
-				     wxS("o") wxS("\u043e") wxS("\u03bf") wxS(
-									      "\u043e") wxS("c") wxS("\u0441") wxS("s")
-				     wxS("\u0455") wxS("t") wxS("\u03c4") wxS(
-									      "u") wxS("\u03c5") wxS("x") wxS("\u03c7")
-				     wxS("ü") wxS("\u03cb") wxS("\u0460") wxS(
-									      "\u03c9") wxS("\u0472") wxS("\u0398")
-				     wxS("У") wxS("Y") wxS("У") wxS(
-								    "y") wxS("ѡ") wxS("ω")
-				     wxS("Ѳ") wxS("Θ") wxS(
-							   "θ") wxS("ѳ") wxS("ø")
-				     wxS("⌀") wxS("∅") wxS(
-							   "⊘") wxS("∅")
-				     wxS("⌀") wxS(
-						  "ø") wxS("⊘")
-				     wxS("ø") wxS(
-						  "∅")
-				     wxS("⌀") wxS(
-						  "⊘"));
+                                     wxS("µ") wxS("\u03bc") wxS("\u2126") wxS("\u03a9") wxS("C") wxS(
+                                                                                                     "\u03F2") wxS("C") wxS("\u0421") wxS("\u03F2") wxS("\u0421") wxS("A")
+                                     wxS("\u0391") wxS("A") wxS("\u0410") wxS("\u0391") wxS("\u0410") wxS(
+                                                                                                          "M") wxS("\u0392") wxS("E") wxS("\u0395") wxS("E") wxS("\u0415")
+                                     wxS("\u0415") wxS("\u0395") wxS("Z") wxS("\u0396") wxS("H") wxS(
+                                                                                                     "\u0397") wxS("H") wxS("\u041D") wxS("\u0397") wxS("\u041D")
+                                     wxS("I") wxS("\u0399") wxS("I") wxS("\u0406") wxS("l") wxS(
+                                                                                                "\u0406") wxS("K") wxS("\u039A")
+                                     wxS("K") wxS("\u041A") wxS("\u039A") wxS("\u041A") wxS("\u212a") wxS(
+                                                                                                          "\u041A") wxS("K") wxS("\u212A") wxS("M") wxS("\u041c") wxS("\u039C")
+                                     wxS("\u041c") wxS("M") wxS("\u039C") wxS("N") wxS("\u039D") wxS("O") wxS(
+                                                                                                              "\u039F") wxS("O") wxS("\u041E") wxS("\u039F") wxS("\u041E") wxS("\u039F")
+                                     wxS("\u041E") wxS("P") wxS("\u03A1") wxS("X") wxS("\u0425") wxS("e") wxS(
+                                                                                                              "\u0435") wxS("p") wxS("\u0440") wxS("x") wxS("\u0445") wxS("y")
+                                     wxS("\u0443") wxS("P") wxS("\u0420") wxS("\u03A1") wxS(
+                                                                                            "\u0420") wxS("T") wxS("\u03A4") wxS("T") wxS("\u0422") wxS("\u03A4")
+                                     wxS("\u0422") wxS("Y") wxS("\u03A5") wxS("\u212a") wxS(
+                                                                                            "\u039A") wxS("l") wxS("I") wxS("B")
+                                     wxS("\u0392") wxS("S") wxS("\u0405") wxS("\u0392") wxS(
+                                                                                            "\u0412") wxS("B") wxS("\u0412") wxS("J")
+                                     wxS("\u0408") wxS("a") wxS("\u0430") wxS(
+                                                                              "o") wxS("\u03bf") wxS("\u03a3") wxS("\u2211")
+                                     wxS("o") wxS("\u043e") wxS("\u03bf") wxS(
+                                                                              "\u043e") wxS("c") wxS("\u0441") wxS("s")
+                                     wxS("\u0455") wxS("t") wxS("\u03c4") wxS(
+                                                                              "u") wxS("\u03c5") wxS("x") wxS("\u03c7")
+                                     wxS("ü") wxS("\u03cb") wxS("\u0460") wxS(
+                                                                              "\u03c9") wxS("\u0472") wxS("\u0398")
+                                     wxS("У") wxS("Y") wxS("У") wxS(
+                                                                    "y") wxS("ѡ") wxS("ω")
+                                     wxS("Ѳ") wxS("Θ") wxS(
+                                                           "θ") wxS("ѳ") wxS("ø")
+                                     wxS("⌀") wxS("∅") wxS(
+                                                           "⊘") wxS("∅")
+                                     wxS("⌀") wxS(
+                                                  "ø") wxS("⊘")
+                                     wxS("ø") wxS(
+                                                  "∅")
+                                     wxS("⌀") wxS(
+                                                  "⊘"));
+
+std::ostream& operator<<(std::ostream& out, const GroupType grouptype){
+  std::string result;
+  switch(grouptype){
+  case GC_TYPE_INVALID: result = "GC_TYPE_INVALID"; break;
+  case GC_TYPE_CODE: result = "GC_TYPE_CODE"; break;
+  case GC_TYPE_TITLE: result = "GC_TYPE_TITLE"; break;
+  case GC_TYPE_SECTION: result = "GC_TYPE_SECTION"; break;
+  case GC_TYPE_SUBSECTION: result = "GC_TYPE_SUBSECTION"; break;
+  case GC_TYPE_SUBSUBSECTION: result = "GC_TYPE_SUBSUBSECTION"; break;
+  case GC_TYPE_HEADING5: result = "GC_TYPE_HEADING5"; break;
+  case GC_TYPE_HEADING6: result = "GC_TYPE_HEADING6"; break;
+  case GC_TYPE_TEXT: result = "GC_TYPE_TEXT"; break;
+  case GC_TYPE_IMAGE: result = "GC_TYPE_IMAGE"; break;
+  case GC_TYPE_PAGEBREAK: result = "GC_TYPE_PAGEBREAK"; break;
+  default: result = "!!!Bug: Unknown GroupCell type!!!";
+  }
+  return out << result;
+}
+
+    
