@@ -52,6 +52,8 @@ enum GroupType : int8_t
   GC_TYPE_IMAGE,
   GC_TYPE_PAGEBREAK
 };
+//! Allow Standard c++ streams to print out our enum values as text.
+std::ostream& operator<<(std::ostream& out, const GroupType grouptype);
 
 /*! A cell grouping input (and, if there is one, also the output) cell to a foldable item
 
@@ -80,10 +82,12 @@ public:
   std::unique_ptr<GroupCell> CopyList() const;
   ~GroupCell();
 
+  // cppcheck-suppress duplInheritedMember
   GroupCell *first() const { return dynamic_cast<GroupCell*>(Cell::first()); }
+  // cppcheck-suppress duplInheritedMember
   GroupCell *last() const { return dynamic_cast<GroupCell*>(Cell::last()); }
 
-  const wxString &GetAnswer(int answer) const;
+  const wxString &GetAnswer(size_t answer) const;
   const wxString &GetAnswer(const wxString &question) const;
   //! Does this GroupCell know the answer to any of maxima's questions?
   bool ContainsSavedAnswers() { return !m_knownAnswers.empty(); }
@@ -94,9 +98,9 @@ public:
   //! Add a new answer to the cell
   void SetAnswer(const wxString &question, const wxString &answer);
 
-  int GetInnerCellCount() const override { return (m_groupType == GC_TYPE_PAGEBREAK) ? 0 : 2; }
+  size_t GetInnerCellCount() const override { return (m_groupType == GC_TYPE_PAGEBREAK) ? 0 : 2; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_inputLabel)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_inputLabel)[index].get(); }
 
   /*! Which GroupCell was the last maxima was working on?
 
@@ -171,7 +175,7 @@ public:
   wxString ToXML() const override;
 
   void Hide(bool hide) override;
-
+  virtual bool FirstLineOnlyEditor() override;
   void SwitchHide();
 
   wxRect HideRect();
@@ -184,8 +188,11 @@ public:
   void AppendInput(std::unique_ptr<Cell> &&cell);
 
   //! Get the previous GroupCell in the list
+  // cppcheck-suppress duplInheritedMember
   GroupCell *GetPrevious() const { return dynamic_cast<GroupCell *>(Cell::GetPrevious()); }
+
   //! Get the next GroupCell in the list.
+  // cppcheck-suppress duplInheritedMember
   GroupCell *GetNext() const { return dynamic_cast<GroupCell *>(Cell::GetNext()); }
 
   static wxString TexEscapeOutputCell(wxString Input);
@@ -232,7 +239,7 @@ public:
   void RecalculateOutput();
 
   /*! Attempt to split math objects that are wider than the screen into multiple lines.
-    
+
     \retval true, if this action has changed the height of cells.
   */
   bool BreakUpCells(Cell *cell) const;
@@ -322,7 +329,7 @@ public:
   bool SectioningCanMoveOut() const {return IsHeading() && (GetGroupType() != GC_TYPE_TITLE);}
   //! Get the end of this section/subsection/...
   GroupCell *SectioningUnitGetEndOf() const;
-  
+
   //!  Return this cell's section- or image number.
   void Number(int &section, int &subsection, int &subsubsection, int &heading5, int &heading6, int &image) const;
 
@@ -441,7 +448,7 @@ protected:
 
 //** Bitfield objects (1 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_GroupCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_autoAnswer = false;
@@ -453,13 +460,13 @@ protected:
     }
 
   //! Does this GroupCell automatically fill in the answer to questions?
-  bool m_autoAnswer : 1 /* InitBitFields */;
-  bool m_inEvaluationQueue : 1 /* InitBitFields */;
-  bool m_lastInEvaluationQueue : 1 /* InitBitFields */;
-  bool m_updateConfusableCharWarnings : 1 /* InitBitFields */;
+  bool m_autoAnswer : 1 /* InitBitFields_GroupCell */;
+  bool m_inEvaluationQueue : 1 /* InitBitFields_GroupCell */;
+  bool m_lastInEvaluationQueue : 1 /* InitBitFields_GroupCell */;
+  bool m_updateConfusableCharWarnings : 1 /* InitBitFields_GroupCell */;
   //! Suppress the yellow ToolTip marker?
-  bool m_suppressTooltipMarker : 1 /* InitBitFields */;
-  bool m_cellsAppended : 1; /* InitBitFields */
+  bool m_suppressTooltipMarker : 1 /* InitBitFields_GroupCell */;
+  bool m_cellsAppended : 1; /* InitBitFields_GroupCell */
 
   static wxString m_lookalikeChars;
 };
