@@ -40,13 +40,12 @@
 #include <wx/clipbrd.h>
 #include <wx/file.h>
 #include <wx/filename.h>
-#include <wx/filesys.h>
 #include <wx/fs_mem.h>
 #include <wx/mstream.h>
 
 ImgCell::ImgCell(GroupCell *group, Configuration *config)
   : ImgCellBase(group, config), m_imageBorderWidth(1) {
-  InitBitFields();
+  InitBitFields_ImgCell();
   m_type = MC_TYPE_IMAGE;
 }
 
@@ -54,7 +53,7 @@ ImgCell::ImgCell(GroupCell *group, Configuration *config,
                  const wxMemoryBuffer &image, const wxString &type)
   : ImgCellBase(group, config),
     m_image(new Image(m_configuration, image, type)), m_imageBorderWidth(1) {
-  InitBitFields();
+  InitBitFields_ImgCell();
   m_type = MC_TYPE_IMAGE;
 }
 
@@ -62,7 +61,7 @@ ImgCell::ImgCell(GroupCell *group, Configuration *config,
                  const wxBitmap &bitmap)
   : ImgCellBase(group, config), m_image(new Image(m_configuration, bitmap)),
     m_imageBorderWidth(1) {
-  InitBitFields();
+  InitBitFields_ImgCell();
   m_type = MC_TYPE_IMAGE;
 }
 
@@ -70,13 +69,13 @@ int ImgCell::s_counter = 0;
 
 // constructor which load image
 ImgCell::ImgCell(GroupCell *group, Configuration *config, const wxString &image,
-                 std::shared_ptr<wxFileSystem> &filesystem, bool remove)
+                 const wxString &wxmFile, bool remove)
   : ImgCellBase(group, config), m_imageBorderWidth(1) {
-  InitBitFields();
+  InitBitFields_ImgCell();
   m_type = MC_TYPE_IMAGE;
   if (image != wxEmptyString) {
     m_image =
-      std::make_shared<Image>(m_configuration, image, filesystem, remove);
+      std::make_shared<Image>(m_configuration, image, wxmFile, remove);
   } else
     m_image = std::make_shared<Image>(m_configuration);
   m_drawBoundingBox = false;
@@ -89,7 +88,7 @@ void ImgCell::SetConfiguration(Configuration *config) {
 
 ImgCell::ImgCell(GroupCell *group, const ImgCell &cell)
   : ImgCellBase(group, cell.m_configuration), m_imageBorderWidth(1) {
-  InitBitFields();
+  InitBitFields_ImgCell();
   m_type = MC_TYPE_IMAGE;
   m_image = std::make_shared<Image>(cell.m_configuration, *cell.m_image);
   m_drawBoundingBox = cell.m_drawBoundingBox;
@@ -98,13 +97,13 @@ ImgCell::ImgCell(GroupCell *group, const ImgCell &cell)
 DEFINE_CELL(ImgCell)
 
 void ImgCell::ReloadImage(const wxString &image,
-                          std::shared_ptr<wxFileSystem> &filesystem) {
+                          const wxString &wxmFile) {
   // Store old size limits
   double width = m_image->GetMaxWidth();
   double height = m_image->GetHeightList();
 
   // Load new image
-  m_image = std::make_shared<Image>(m_configuration, image, filesystem, false);
+  m_image = std::make_shared<Image>(m_configuration, image, wxmFile, false);
 
   // Restore size limits
   m_image->SetMaxHeight(height);
@@ -112,7 +111,7 @@ void ImgCell::ReloadImage(const wxString &image,
 }
 
 void ImgCell::LoadImage(wxString image, bool remove) {
-  m_image = std::make_shared<Image>(m_configuration, remove, image);
+  m_image = std::make_shared<Image>(m_configuration, image, wxEmptyString, remove);
 }
 
 void ImgCell::SetBitmap(const wxBitmap &bitmap) {
@@ -123,7 +122,7 @@ void ImgCell::SetBitmap(const wxBitmap &bitmap) {
 // ImgCell::ImgCell(GroupCell *group, const ImgCell &cell):
 //     ImgImgCellBase(group, cell.m_configuration
 // {
-//   InitBitFields();
+//   InitBitFields_ImgCell();
 //   CopyCommonData(cell);
 //   m_drawRectangle = cell.m_drawRectangle;
 //   m_drawBoundingBox = false;
@@ -137,8 +136,6 @@ const wxString &ImgCell::GetToolTip(const wxPoint point) const {
     return wxm::emptyString;
 
   m_cellPointers->m_cellUnderPointer = const_cast<ImgCell *>(this);
-  if (!m_image->IsOk())
-    return Image::GetBadImageToolTip();
 
   return GetLocalToolTip();
 }
@@ -156,12 +153,6 @@ void ImgCell::Recalculate(AFontSize fontsize) {
     } else
       m_image->Recalculate();
     m_width = m_image->m_width + 2 * m_imageBorderWidth;
-    if (m_configuration->GetPrinting()) {
-      m_image->Recalculate(m_configuration->GetZoomFactor() *
-                           PRINT_SIZE_MULTIPLIER);
-      m_imageBorderWidth = Scale_Px(1);
-    } else
-      m_image->Recalculate();
     m_height = m_image->m_height + 2 * m_imageBorderWidth;
     m_center = m_height / 2;
   }
@@ -177,8 +168,8 @@ void ImgCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     wxMemoryDC bitmapDC;
 
     if (m_drawBoundingBox)
-	dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
-							 m_configuration->GetColor(TS_SELECTION))));
+      dc->SetBrush(*(wxTheBrushList->FindOrCreateBrush(
+                                                       m_configuration->GetColor(TS_SELECTION))));
     else
       SetPen(dc);
 
@@ -213,7 +204,7 @@ void ImgCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     {
       // The cell isn't drawn => No need to keep it's image cache for now.
       if(!GetRect().Intersects(m_configuration->GetVisibleRegion()))
-	ClearCache();
+        ClearCache();
     }
 
   // The next time we need to draw a bounding box we will be informed again.
@@ -295,7 +286,7 @@ wxString ImgCell::ToXML() const {
   // add the file to memory
   if (m_image) {
     m_configuration->PushFileToSave(basename + m_image->GetExtension(),
-				    m_image->GetCompressedImage());
+                                    m_image->GetCompressedImage());
   }
 
   wxString flags;
@@ -303,7 +294,7 @@ wxString ImgCell::ToXML() const {
     flags += wxS(" breakline=\"true\"");
 
   if (m_image)
-    flags += wxString::Format(wxS(" ppi=\"%i\""), m_image->GetPPI());
+    flags += wxString::Format(wxS(" ppi=\"%li\""), static_cast<long>(m_image->GetPPI()));
 
   if (!m_drawRectangle)
     flags += wxS(" rect=\"false\"");
@@ -311,12 +302,12 @@ wxString ImgCell::ToXML() const {
   if (m_image)
     {
       if (m_image->GetMaxWidth() > 0)
-	flags += wxString::Format(wxS(" maxWidth=\"%f\""), m_image->GetMaxWidth());
+        flags += wxString::Format(wxS(" maxWidth=\"%f\""), m_image->GetMaxWidth());
       if (m_image->GetHeightList() > 0)
-	flags +=
-	  wxString::Format(wxS(" maxHeight=\"%f\""), m_image->GetHeightList());
+        flags +=
+          wxString::Format(wxS(" maxHeight=\"%f\""), m_image->GetHeightList());
     }
-  
+
   if (m_origImageFile != wxEmptyString) {
     if (m_configuration->SaveImgFileName()) {
       flags += wxString::Format(wxS(" origImageFile=\"%s\""),
@@ -330,25 +321,25 @@ wxString ImgCell::ToXML() const {
       wxFileName gnuplotDataFile(m_image->GnuplotData());
       wxString gnuplotData = gnuplotDataFile.GetFullName() + wxS(".gz");
       m_configuration->PushFileToSave(gnuplotData,
-				      m_image->GetCompressedGnuplotData());
+                                      m_image->GetCompressedGnuplotData());
       flags += wxS(" gnuplotdata_gz=\"") + gnuplotData + wxS("\"");
     }
     if (m_image->GnuplotSource() != wxEmptyString) {
       wxFileName gnuplotSourceFile(m_image->GnuplotSource());
       wxString gnuplotSource = gnuplotSourceFile.GetFullName() + wxS(".gz");
       m_configuration->PushFileToSave(gnuplotSource,
-				      m_image->GetCompressedGnuplotSource());
+                                      m_image->GetCompressedGnuplotSource());
       flags += wxS(" gnuplotsource_gz=\"") + gnuplotSource + wxS("\"");
     }
 
     wxString extension;
     extension = m_image->GetExtension();
     return (wxS("<img") + flags + wxS(">") + basename + extension +
-	    wxS("</img>"));
+            wxS("</img>"));
   }
   else
     return  (wxS("<img") + flags + wxS(">") +
-          wxS("</img>"));
+             wxS("</img>"));
 }
 
 void ImgCell::DrawBoundingBox(wxDC &WXUNUSED(dc), bool WXUNUSED(all)) {
@@ -360,7 +351,7 @@ bool ImgCell::CopyToClipboard() const {
                _("Bug: The clipboard is already opened"));
   if (wxTheClipboard->Open()) {
     bool res = wxTheClipboard->SetData(
-				       new wxBitmapDataObject(m_image->GetUnscaledBitmap()));
+                                       new wxBitmapDataObject(m_image->GetUnscaledBitmap()));
     wxTheClipboard->Close();
     return res;
   }
