@@ -2,7 +2,8 @@
 // nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2018 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2023 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C)      2023 Wolfgang Dautermann
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -32,7 +33,9 @@
 #include "CellImpl.h"
 #include "TextCell.h"
 #include <memory>
+#include <algorithm>
 #include <utility>
+#include "intSign_svg.h"
 
 #if defined __WXMSW__
 #define INTEGRAL_TOP "\xF3"
@@ -41,20 +44,21 @@
 static constexpr AFontSize INTEGRAL_FONT_SIZE{12.0f};
 #endif
 
+
 IntCell::IntCell(GroupCell *group, Configuration *config,
-                 std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&under,
-                 std::unique_ptr<Cell> &&over, std::unique_ptr<Cell> &&var)
+                 std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&lowerLimit,
+                 std::unique_ptr<Cell> &&upperLimit, std::unique_ptr<Cell> &&var)
   : Cell(group, config), m_base(std::move(base)), m_var(std::move(var)),
-    m_under(std::move(under)), m_over(std::move(over)) {
-  InitBitFields();
+    m_lowerLimit(std::move(lowerLimit)), m_upperLimit(std::move(upperLimit)) {
+  InitBitFields_IntCell();
   SetStyle(TS_VARIABLE);
 }
 
 IntCell::IntCell(GroupCell *group, Configuration *config,
                  std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&var)
   : IntCell(group, config, std::move(base),
-	    std::make_unique<TextCell>(group, config),
-	    std::make_unique<TextCell>(group, config), std::move(var)) {}
+            std::make_unique<TextCell>(group, config),
+            std::make_unique<TextCell>(group, config), std::move(var)) {}
 
 // Old cppcheck bugs:
 // cppcheck-suppress uninitMemberVar symbolName=IntCell::m_signHeight
@@ -64,9 +68,9 @@ IntCell::IntCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=IntCell::m_charWidth
 IntCell::IntCell(GroupCell *group, const IntCell &cell)
   : IntCell(group, cell.m_configuration, CopyList(group, cell.m_base.get()),
-	    CopyList(group, cell.m_under.get()),
-	    CopyList(group, cell.m_over.get()),
-	    CopyList(group, cell.m_var.get())) {
+            CopyList(group, cell.m_lowerLimit.get()),
+            CopyList(group, cell.m_upperLimit.get()),
+            CopyList(group, cell.m_var.get())) {
   CopyCommonData(cell);
   m_intStyle = cell.m_intStyle;
 }
@@ -84,97 +88,87 @@ void IntCell::MakeBreakUpCells() {
 }
 
 void IntCell::Recalculate(AFontSize fontsize) {
-  wxASSERT(fontsize.IsValid());
+  if (NeedsRecalculation(fontsize)) {
+    wxASSERT(fontsize.IsValid());
 
-  m_signHeight = Scale_Px(35);
-  m_signWidth = Scale_Px(18);
-  if (m_signWidth < 4)
-    m_signWidth = 4;
-
-  m_base->RecalculateList(fontsize);
-  m_var->RecalculateList(fontsize);
-  if (IsBrokenIntoLines()) {
-    m_open->RecalculateList(fontsize);
-    m_comma1->RecalculateList(fontsize);
-    m_comma2->RecalculateList(fontsize);
-    m_under->RecalculateList(fontsize);
-    m_comma3->RecalculateList(fontsize);
-    m_over->RecalculateList(fontsize);
-    m_close->RecalculateList(fontsize);
-  } else {
-    m_under->RecalculateList({MC_MIN_SIZE, fontsize - 5});
-    m_over->RecalculateList({MC_MIN_SIZE, fontsize - 5});
-    if (m_intStyle == INT_DEF) {
-      m_signHeight = Scale_Px(35) + m_over->GetHeightList() + m_under->GetHeightList();
-    }
-  }
-
-  if (IsBrokenIntoLines()) {
-    m_center = 0;
-    m_height = 0;
-    m_width = 0;
-  } else {
-    m_width = m_signWidth + m_base->GetFullWidth() +
-      wxMax(m_over->GetFullWidth(), m_under->GetFullWidth()) +
-      m_var->GetFullWidth() + Scale_Px(4);
-    // cppcheck-suppress duplicateBranch
-    if (m_intStyle == INT_DEF) {
-      m_center = wxMax(m_signHeight / 2,
-                       m_base->GetCenterList());
-      m_height = m_center + wxMax(m_signHeight / 2,
-                                  m_base->GetMaxDrop());
+    m_base->RecalculateList(fontsize);
+    m_var->RecalculateList(fontsize);
+    if (IsBrokenIntoLines()) {
+      // Cell is being displayed in its linear form. That means: All of its components
+      // are printed in the current font size and the 2D object this cell can print
+      // isn't displayed at all.
+      m_open->RecalculateList(fontsize);
+      m_comma1->RecalculateList(fontsize);
+      m_comma2->RecalculateList(fontsize);
+      m_comma3->RecalculateList(fontsize);
+      m_close->RecalculateList(fontsize);
+      m_upperLimit->RecalculateList(fontsize);
+      m_lowerLimit->RecalculateList(fontsize);
+      m_center = 0;
+      m_height = 0;
+      m_width = 0;
     } else {
-      m_center = wxMax(m_signHeight / 2, m_base->GetCenterList());
-      m_height = m_center + wxMax(m_signHeight / 2, m_base->GetMaxDrop());
+      // Make the font used for the limits a bit smaller than the font used for the
+      // contents  
+      m_lowerLimit->RecalculateList({MC_MIN_SIZE, fontsize - 5});
+      m_upperLimit->RecalculateList({MC_MIN_SIZE, fontsize - 5});
+      // The integral sign is displayed as an SVG graphics. As line thickness scales
+      // with the sign we need to make it a constant height.
+      m_signHeight = Scale_Px(40.0);
+      if (m_signHeight < 6)
+        m_signHeight = 6;
+      // The sign width in this case is defined by the sign height and the sign's aspect
+      // ratio
+      m_signWidth = m_signHeight * 19.879 / 51.781;
+      m_width = m_signWidth + m_base->GetFullWidth() +
+        std::max(m_upperLimit->GetFullWidth(), m_lowerLimit->GetFullWidth()) +
+        m_var->GetFullWidth() + Scale_Px(4);
+      if (HasLimits()) {
+
+        m_center = std::max(std::max(m_signHeight / 2,
+                                     m_base->GetCenterList()),
+                            m_upperLimit->GetHeightList() + IntSignLimitYoffset()
+                            );
+        m_height = m_center + std::max(std::max(m_signHeight / 2,
+                                                m_base->GetMaxDrop()),
+                                       m_lowerLimit->GetHeightList() + IntSignLimitYoffset()
+                                       );
+      } else {
+        m_center = std::max(m_signHeight / 2, m_base->GetCenterList());
+        m_height = m_center + std::max(m_signHeight / 2, m_base->GetMaxDrop());
+      }
     }
   }
+  Cell::Recalculate(fontsize);
 }
 
 void IntCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
   Cell::Draw(point, dc, antialiassingDC);
   if (DrawThisCell(point)) {
-    wxPoint base(point), under(point), over(point), var(point), sign(point);
+    wxPoint base(point), lowerLimit(point), upperLimit(point), var(point), sign(point);
+    base.x += m_signWidth;
+    base.x += std::max(m_upperLimit->GetFullWidth(), m_lowerLimit->GetFullWidth());
 
     SetPen(antialiassingDC, 1.5);
-    // top decoration
-    int m_signWCenter = m_signWidth / 2;
-    wxPoint points[7] = {
-      {sign.x + m_signWCenter + 2 * (m_signWidth / 4),
-       sign.y - (m_signHeight - Scale_Px(1)) / 2 + m_signWidth / 4},
-      {sign.x + m_signWCenter + m_signWidth / 4,
-       sign.y - (m_signHeight - Scale_Px(1)) / 2},
-      {sign.x + m_signWCenter, sign.y - (m_signHeight - Scale_Px(1)) / 2 +
-       2 * (m_signWidth / 4) + Scale_Px(.35)},
 
-      // The line
-      {sign.x + m_signWCenter + Scale_Px(.5), sign.y},
-
-      // Bottom Decoration
-      {sign.x + m_signWCenter, sign.y + (m_signHeight - Scale_Px(1)) / 2 -
-       2 * (m_signWidth / 4) + Scale_Px(.35)},
-      {sign.x + m_signWCenter - m_signWidth / 4,
-       sign.y + (m_signHeight - Scale_Px(1)) / 2},
-      {sign.x + m_signWCenter - 2 * (m_signWidth / 4),
-       sign.y + (m_signHeight - Scale_Px(1)) / 2 - m_signWidth / 4}};
-
-    antialiassingDC->DrawSpline(7, points);
-    // line
-
-    if (m_intStyle == INT_DEF) {
-      under.x += m_signWidth;
-      under.y = point.y + m_signHeight / 2 - m_under->GetMaxDrop();
-      m_under->DrawList(under, dc, antialiassingDC);
-
-      over.x += m_signWidth;
+    sign.y -= .5 * m_signHeight;
+    dc->DrawBitmap(BitmapFromSVG(m_svgIntegralSign, wxSize(m_signWidth, m_signHeight)),
+                   sign.x, sign.y, true);
+  
+    if (HasLimits()) {
+      lowerLimit.x += m_signWidth;
+      upperLimit.x += m_signWidth;
+ 
+      upperLimit.y -= IntSignLimitYoffset();
+      upperLimit.y -= m_upperLimit->GetMaxDrop();
+      lowerLimit.y += IntSignLimitYoffset();
+      lowerLimit.y += m_lowerLimit->GetCenterList();
       
-      over.y = point.y - m_signHeight / 2 + m_over->GetHeightList() - m_over->GetCenterList();
-      m_over->DrawList(over, dc, antialiassingDC);
-
-      base.x += m_signWidth +
-	wxMax(m_over->GetFullWidth(), m_under->GetFullWidth());
+      m_upperLimit->DrawList(upperLimit, dc, antialiassingDC);
+      m_lowerLimit->DrawList(lowerLimit, dc, antialiassingDC);
+      
+      base.x += std::max(m_upperLimit->GetFullWidth(), m_lowerLimit->GetFullWidth());
     }
-    else
-      base.x += m_signWidth;
 
     m_base->DrawList(base, dc, antialiassingDC);
 
@@ -195,11 +189,11 @@ wxString IntCell::ToString() const {
     var = tmp->ListToString();
   }
 
-  wxString to = m_over->ListToString();
-  wxString from = m_under->ListToString();
+  wxString to = m_upperLimit->ListToString();
+  wxString from = m_lowerLimit->ListToString();
 
   s += wxS(",") + var;
-  if (m_intStyle == INT_DEF)
+  if (HasLimits())
     s += wxS(",") + from + wxS(",") + to;
 
   s += wxS(")");
@@ -217,11 +211,11 @@ wxString IntCell::ToMatlab() const {
   if (tmp != NULL)
     var = tmp->ListToMatlab();
 
-  wxString to = m_over->ListToMatlab();
-  wxString from = m_under->ListToMatlab();
+  wxString to = m_upperLimit->ListToMatlab();
+  wxString from = m_lowerLimit->ListToMatlab();
 
   s += wxS(",") + var;
-  if (m_intStyle == INT_DEF)
+  if (HasLimits())
     s += wxS(",") + from + wxS(",") + to;
 
   s += wxS(")");
@@ -231,18 +225,18 @@ wxString IntCell::ToMatlab() const {
 wxString IntCell::ToTeX() const {
   wxString s = wxS("\\int");
 
-  wxString to = m_over->ListToTeX();
-  wxString from = m_under->ListToTeX();
+  wxString to = m_upperLimit->ListToTeX();
+  wxString from = m_lowerLimit->ListToTeX();
 
-  if (m_intStyle == INT_DEF)
+  if (HasLimits())
     s += wxS("_{") + from + wxS("}^{") + to + wxS("}");
   else
     s += wxS(" ");
 
-  s += wxS("{\\left. ");
   s += m_base->ListToTeX();
+  s += wxS("{\\, ");
   s += m_var->ListToTeX();
-  s += wxS("\\right.}");
+  s += wxS("}");
 
   return s;
 }
@@ -255,12 +249,12 @@ wxString IntCell::ToMathML() const {
     var = m_var->ListToMathML();
 
   wxString from;
-  if (m_under)
-    from = m_under->ListToMathML();
+  if (m_lowerLimit)
+    from = m_lowerLimit->ListToMathML();
 
   wxString to;
-  if (m_over)
-    to = m_over->ListToMathML();
+  if (m_upperLimit)
+    to = m_upperLimit->ListToMathML();
 
   wxString retval;
   if (from.IsEmpty() && to.IsEmpty())
@@ -286,12 +280,12 @@ wxString IntCell::ToOMML() const {
     var = m_var->ListToOMML();
 
   wxString from;
-  if (m_under)
-    from = m_under->ListToOMML();
+  if (m_lowerLimit)
+    from = m_lowerLimit->ListToOMML();
 
   wxString to;
-  if (m_over)
-    to = m_over->ListToOMML();
+  if (m_upperLimit)
+    to = m_upperLimit->ListToOMML();
 
   wxString retval;
 
@@ -307,13 +301,13 @@ wxString IntCell::ToOMML() const {
 
 wxString IntCell::ToXML() const {
   wxString from;
-  if (m_under != NULL)
-    from = m_under->ListToXML();
+  if (m_lowerLimit != NULL)
+    from = m_lowerLimit->ListToXML();
   from = wxS("<r>") + from + wxS("</r>");
 
   wxString to;
-  if (m_over != NULL)
-    to = m_over->ListToXML();
+  if (m_upperLimit != NULL)
+    to = m_upperLimit->ListToXML();
   to = wxS("<r>") + to + wxS("</r>");
 
   wxString base;
@@ -330,7 +324,7 @@ wxString IntCell::ToXML() const {
   if (HasHardLineBreak())
     flags += wxS(" breakline=\"true\"");
 
-  if (m_intStyle != INT_DEF) {
+  if (HasLimits()) {
     flags += wxS(" def=\"false\">");
     return wxS("<in") + flags + wxS(">") + base + var + wxS("</in>");
   } else
@@ -353,14 +347,14 @@ bool IntCell::BreakUp() {
     m_comma1->last()->SetNextToDraw(m_var->GetNext());
   else
     m_comma1->last()->SetNextToDraw(m_var);
-  if (m_intStyle != INT_DEF)
+  if (HasLimits())
     m_var->last()->SetNextToDraw(m_close);
   else {
     m_var->last()->SetNextToDraw(m_comma2);
-    m_comma2->last()->SetNextToDraw(m_under);
-    m_under->last()->SetNextToDraw(m_comma3);
-    m_comma3->last()->SetNextToDraw(m_over);
-    m_over->last()->SetNextToDraw(m_close);
+    m_comma2->last()->SetNextToDraw(m_lowerLimit);
+    m_lowerLimit->last()->SetNextToDraw(m_comma3);
+    m_comma3->last()->SetNextToDraw(m_upperLimit);
+    m_upperLimit->last()->SetNextToDraw(m_close);
   }
   ResetCellListSizes();
   m_height = 0;
@@ -374,3 +368,5 @@ void IntCell::SetNextToDraw(Cell *next) {
   else
     m_nextToDraw = next;
 }
+
+const wxString IntCell::m_svgIntegralSign(reinterpret_cast<const char*>(INTSIGN));
