@@ -40,7 +40,7 @@ LimitCell::LimitCell(GroupCell *group, Configuration *config,
                      std::unique_ptr<Cell> &&name)
   : Cell(group, config), m_name(std::move(name)), m_base(std::move(base)),
     m_under(std::move(under)) {
-  InitBitFields();
+  InitBitFields_LimitCell();
   SetStyle(TS_VARIABLE);
 }
 
@@ -49,8 +49,8 @@ LimitCell::LimitCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=LimitCell::m_close
 LimitCell::LimitCell(GroupCell *group, const LimitCell &cell)
   : LimitCell(group, cell.m_configuration, CopyList(group, cell.m_base.get()),
-	      CopyList(group, cell.m_under.get()),
-	      CopyList(group, cell.m_name.get())) {
+              CopyList(group, cell.m_under.get()),
+              CopyList(group, cell.m_name.get())) {
   CopyCommonData(cell);
 }
 
@@ -70,13 +70,13 @@ void LimitCell::MakeBreakUpCells() {
 void LimitCell::Recalculate(AFontSize fontsize) {
   m_base->RecalculateList(fontsize);
   m_under->RecalculateList(
-			   {MIN_LIMIT_FONT_SIZE, fontsize - LIMIT_FONT_SIZE_DECREASE});
+                           {MIN_LIMIT_FONT_SIZE, fontsize - LIMIT_FONT_SIZE_DECREASE});
   m_name->RecalculateList(fontsize);
   if (!IsBrokenIntoLines()) {
-    m_width = wxMax(m_name->GetFullWidth(), m_under->GetFullWidth()) +
+    m_width = std::max(m_name->GetFullWidth(), m_under->GetFullWidth()) +
       m_base->GetFullWidth();
-    m_center = wxMax(m_base->GetCenterList(), m_name->GetCenterList());
-    m_height = m_center + wxMax(m_name->GetMaxDrop() + m_under->GetHeightList(),
+    m_center = std::max(m_base->GetCenterList(), m_name->GetCenterList());
+    m_height = m_center + std::max(m_name->GetMaxDrop() + m_under->GetHeightList(),
                                 m_base->GetMaxDrop());
   } else {
     m_width = m_height = m_center = 0;
@@ -94,18 +94,18 @@ void LimitCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     wxPoint base(point), under(point), name(point);
 
     name.x = point.x +
-      wxMax(m_name->GetFullWidth(), m_under->GetFullWidth()) / 2 -
+      std::max(m_name->GetFullWidth(), m_under->GetFullWidth()) / 2 -
       m_name->GetFullWidth() / 2;
     m_name->DrawList(name, dc, antialiassingDC);
 
     under.x = point.x +
-      wxMax(m_name->GetFullWidth(), m_under->GetFullWidth()) / 2 -
+      std::max(m_name->GetFullWidth(), m_under->GetFullWidth()) / 2 -
       m_under->GetFullWidth() / 2;
 
     under.y = point.y + m_name->GetMaxDrop() + m_under->GetCenterList();
     m_under->DrawList(under, dc, antialiassingDC);
 
-    base.x += wxMax(m_name->GetFullWidth(), m_under->GetFullWidth());
+    base.x += std::max(m_name->GetFullWidth(), m_under->GetFullWidth());
     m_base->DrawList(base, dc, antialiassingDC);
   }
 }
@@ -114,8 +114,14 @@ wxString LimitCell::ToString() const {
   wxString s(wxS("limit"));
   wxString under = m_under->ListToString();
   wxString base = m_base->ListToString();
-  wxString var = under.SubString(0, under.Find(wxS("->")) - 1);
-  wxString to = under.SubString(under.Find(wxS("->")) + 2, under.Length() - 1);
+  auto arrowpos = under.Find(wxS("->"));
+  wxString var;
+  wxString to;
+  if(arrowpos >= 0)
+    {
+      var = under.SubString(0, static_cast<size_t>(arrowpos) - 1);
+      to = under.SubString(static_cast<size_t>(arrowpos) + 2, under.Length() - 1);
+    }
   if (to.Right(1) == wxS("+"))
     to = to.Left(to.Length() - 1) + wxS(",plus");
   if (to.Right(1) == wxS("-"))
@@ -129,8 +135,14 @@ wxString LimitCell::ToMatlab() const {
   wxString s(wxS("limit"));
   wxString under = m_under->ListToMatlab();
   wxString base = m_base->ListToMatlab();
-  wxString var = under.SubString(0, under.Find(wxS("->")) - 1);
-  wxString to = under.SubString(under.Find(wxS("->")) + 2, under.Length() - 1);
+  wxString var;
+  wxString to;
+  auto arrowpos = under.Find(wxS("->"));
+  if(arrowpos >= 0)
+    {
+      var = under.SubString(0, static_cast<size_t>(arrowpos) - 1);
+      to = under.SubString(static_cast<size_t>(arrowpos) + 2, under.Length() - 1);
+    }
   if (to.Right(1) == wxS("+"))
     to = to.Left(to.Length() - 1) + wxS(",plus");
   if (to.Right(1) == wxS("-"))
@@ -143,7 +155,7 @@ wxString LimitCell::ToMatlab() const {
 wxString LimitCell::ToTeX() const {
   wxString under = m_under->ListToTeX();
   wxString base = m_base->ListToTeX();
-  int varEnd = under.Find(wxS("->"));
+  auto varEnd = under.Find(wxS("->"));
   int toStart = 0;
   wxString var;
   wxString to;
@@ -152,14 +164,14 @@ wxString LimitCell::ToTeX() const {
     if (varEnd != wxNOT_FOUND) {
       toStart = varEnd + 19;
       if(varEnd > 0)
-	varEnd -= 1;
+        varEnd -= 1;
     }
   } else {
     toStart = varEnd + 2;
     if(varEnd > 0)
       varEnd -= 1;
   }
-  if(varEnd >= 0)  
+  if(varEnd >= 0)
     var = under.SubString(0, varEnd);
   if(toStart >= 0)
     to = under.SubString(toStart, under.Length() - 1);
