@@ -36,7 +36,7 @@ ListCell::ListCell(GroupCell *group, Configuration *config,
     m_open(std::make_unique<TextCell>(group, config, wxS("["))),
     m_innerCell(std::move(inner)),
     m_close(std::make_unique<TextCell>(group, config, wxS("]"))) {
-  InitBitFields();
+  InitBitFields_ListCell();
   SetStyle(TS_VARIABLE);
 
   // It is valid to construct this cell this with a null inner cell
@@ -65,7 +65,7 @@ ListCell::ListCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=ListCell::m_extendHeight
 ListCell::ListCell(GroupCell *group, const ListCell &cell)
   : ListCell(group, cell.m_configuration,
-	     CopyList(group, cell.m_innerCell.get())) {
+             CopyList(group, cell.m_innerCell.get())) {
   CopyCommonData(cell);
 }
 
@@ -94,7 +94,7 @@ void ListCell::Recalculate(AFontSize fontsize) {
     m_center = 0;
   } else {
     m_width = m_innerCell->GetFullWidth() + m_signWidth * 2;
-    m_height = wxMax(m_signHeight, m_innerCell->GetHeightList()) + Scale_Px(4);
+    m_height = std::max(m_signHeight, m_innerCell->GetHeightList()) + Scale_Px(4);
     m_center = m_height / 2;
   }
   Cell::Recalculate(fontsize);
@@ -109,11 +109,11 @@ void ListCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
       innerCellPos.x += m_open->GetWidth();
       m_open->DrawList(point, dc, antialiassingDC);
       m_close->DrawList(wxPoint(
-				point.x + m_open->GetWidth() + m_innerCell->GetFullWidth(),
-				point.y), dc, antialiassingDC);
+                                point.x + m_open->GetWidth() + m_innerCell->GetFullWidth(),
+                                point.y), dc, antialiassingDC);
     } else {
       innerCellPos.y +=
-	(m_innerCell->GetCenterList() - m_innerCell->GetHeightList() / 2);
+        (m_innerCell->GetCenterList() - m_innerCell->GetHeightList() / 2);
       SetPen(antialiassingDC, 1.5);
 
       int signWidth = m_signWidth - Scale_Px(2);
@@ -121,21 +121,21 @@ void ListCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
 
       // Left bracket
       const wxPoint pointsL[4] = {
-	{point.x - Scale_Px(1) + signWidth, point.y - m_center + Scale_Px(4)},
-	{point.x + Scale_Px(1), point.y - m_center + Scale_Px(4)},
-	{point.x + Scale_Px(1), point.y + m_center - Scale_Px(4)},
-	{point.x - Scale_Px(1) + signWidth,
-	 point.y + m_center - Scale_Px(4)}};
+        {point.x - Scale_Px(1) + signWidth, point.y - m_center + Scale_Px(4)},
+        {point.x + Scale_Px(1), point.y - m_center + Scale_Px(4)},
+        {point.x + Scale_Px(1), point.y + m_center - Scale_Px(4)},
+        {point.x - Scale_Px(1) + signWidth,
+         point.y + m_center - Scale_Px(4)}};
       antialiassingDC->DrawLines(4, pointsL);
 
       // Right bracket
       const wxPoint pointsR[4] = {
-	{point.x + m_width + Scale_Px(1) - signWidth,
-	 point.y - m_center + Scale_Px(4)},
-	{point.x + m_width - Scale_Px(1), point.y - m_center + Scale_Px(4)},
-	{point.x + m_width - Scale_Px(1), point.y + m_center - Scale_Px(4)},
-	{point.x + m_width + Scale_Px(1) - signWidth,
-	 point.y + m_center - Scale_Px(4)}};
+        {point.x + m_width + Scale_Px(1) - signWidth,
+         point.y - m_center + Scale_Px(4)},
+        {point.x + m_width - Scale_Px(1), point.y - m_center + Scale_Px(4)},
+        {point.x + m_width - Scale_Px(1), point.y + m_center - Scale_Px(4)},
+        {point.x + m_width + Scale_Px(1) - signWidth,
+         point.y + m_center - Scale_Px(4)}};
       antialiassingDC->DrawLines(4, pointsR);
     }
 
