@@ -37,7 +37,7 @@
 LongNumberCell::LongNumberCell(GroupCell *group, Configuration *config,
                                const wxString &number)
   : TextCell(group, config, number, TS_NUMBER) {
-  InitBitFields();
+  InitBitFields_LongNumberCell();
 }
 
 // cppcheck-suppress uninitMemberVar symbolName=LongNumberCell::m_alt
@@ -56,8 +56,8 @@ void LongNumberCell::UpdateDisplayedText() {
     if (left > 30)
       left = 30;
     m_numStart = m_displayedText.Left(left);
-    m_ellipsis = wxString::Format(_("[%i digits]"),
-                                  (int)m_displayedText.Length() - 2 * left);
+    m_ellipsis = wxString::Format(_("[%li digits]"),
+                                  static_cast<long>(m_displayedText.Length()) - 2 * left);
     m_numEnd = m_displayedText.Right(left);
   } else {
     m_numStart.clear();
@@ -76,7 +76,7 @@ bool LongNumberCell::NeedsRecalculation(AFontSize fontSize) const {
      m_configuration->LineBreaksInLongNums());
 }
 
-Cell *LongNumberCell::GetInnerCell(int index) const
+Cell *LongNumberCell::GetInnerCell(size_t index) const
 {
   if(index != 0)
     return NULL;
@@ -117,8 +117,8 @@ void LongNumberCell::Recalculate(AFontSize fontsize) {
         m_ellipsisWidth = ellipsisSize.GetWidth();
         m_width = m_numStartWidth + m_ellipsisWidth + numEndSize.GetWidth();
         m_height =
-	  wxMax(wxMax(numStartSize.GetHeight(), ellipsisSize.GetHeight()),
-		numEndSize.GetHeight());
+          std::max(std::max(numStartSize.GetHeight(), ellipsisSize.GetHeight()),
+                numEndSize.GetHeight());
         m_center = m_height / 2;
       }
     }
@@ -144,14 +144,14 @@ void LongNumberCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
                    point.y - m_center + MC_TEXT_PADDING);
       dc->DrawText(m_numEnd,
                    point.x + MC_TEXT_PADDING + m_numStartWidth +
-		   m_ellipsisWidth,
+                   m_ellipsisWidth,
                    point.y - m_center + MC_TEXT_PADDING);
       wxColor textColor = dc->GetTextForeground();
       wxColor backgroundColor = dc->GetTextBackground();
       dc->SetTextForeground(
-			    wxColor((textColor.Red() + backgroundColor.Red()) / 2,
-				    (textColor.Green() + backgroundColor.Green()) / 2,
-				    (textColor.Blue() + backgroundColor.Blue()) / 2));
+                            wxColor((textColor.Red() + backgroundColor.Red()) / 2,
+                                    (textColor.Green() + backgroundColor.Green()) / 2,
+                                    (textColor.Blue() + backgroundColor.Blue()) / 2));
       dc->DrawText(m_ellipsis, point.x + MC_TEXT_PADDING + m_numStartWidth,
                    point.y - m_center + MC_TEXT_PADDING);
     }
