@@ -33,7 +33,7 @@
 
 MatrCell::MatrCell(GroupCell *group, Configuration *config)
   : Cell(group, config) {
-  InitBitFields();
+  InitBitFields_MatrCell();
 }
 
 MatrCell::MatrCell(GroupCell *group, const MatrCell &cell)
@@ -46,14 +46,14 @@ MatrCell::MatrCell(GroupCell *group, const MatrCell &cell)
   m_colNames = cell.m_colNames;
   m_matWidth = cell.m_matWidth;
   m_matHeight = cell.m_matHeight;
-  for (unsigned int i = 0; i < cell.m_matWidth * cell.m_matHeight; i++)
+  for (size_t i = 0; i < cell.m_matWidth * cell.m_matHeight; i++)
     if (i < cell.m_cells.size())
       m_cells.emplace_back(cell.m_cells[i]->CopyList(group));
 
-  for (unsigned int i = 0; i < m_matHeight; i++)
+  for (size_t i = 0; i < m_matHeight; i++)
     m_dropCenters.emplace_back(-1, -1);
 
-  for (unsigned int i = 0; i < m_matWidth; i++)
+  for (size_t i = 0; i < m_matWidth; i++)
     m_widths.emplace_back(-1);
 }
 
@@ -61,16 +61,16 @@ DEFINE_CELL(MatrCell)
 
 void MatrCell::Recalculate(AFontSize const fontsize) {
   AFontSize const fontsize_entry{MC_MIN_SIZE, fontsize - 2};
-  for (unsigned int i = 0; i < m_cells.size(); i++)
+  for (size_t i = 0; i < m_cells.size(); i++)
     m_cells[i]->RecalculateList(fontsize_entry);
 
   m_width = 0;
   m_widths.clear();
-  for (unsigned int i = 0; i < m_matWidth; i++) {
-    int width = 0;
-    for (unsigned int j = 0; j < m_matHeight; j++) {
+  for (size_t i = 0; i < m_matWidth; i++) {
+    wxCoord width = 0;
+    for (size_t j = 0; j < m_matHeight; j++) {
       if ((m_matWidth * j + i) < m_cells.size())
-        width = wxMax(width, m_cells[m_matWidth * j + i]->GetFullWidth());
+        width = std::max(width, GetInnerCell(j, i)->GetFullWidth());
     }
     m_widths.emplace_back(width);
     m_width += (width + Scale_Px(10));
@@ -80,12 +80,12 @@ void MatrCell::Recalculate(AFontSize const fontsize) {
 
   m_height = 0;
   m_dropCenters.clear();
-  for (unsigned int i = 0; i < m_matHeight; i++) {
-    int center = 0, drop = 0;
-    for (unsigned int j = 0; j < m_matWidth; j++)
+  for (size_t i = 0; i < m_matHeight; i++) {
+    wxCoord center = 0, drop = 0;
+    for (size_t j = 0; j < m_matWidth; j++)
       if (m_matWidth * i + j < m_cells.size()) {
-        center = wxMax(center, m_cells[m_matWidth * i + j]->GetCenterList());
-        drop = wxMax(drop, m_cells[m_matWidth * i + j]->GetMaxDrop());
+        center = std::max(center, GetInnerCell(i, j)->GetCenterList());
+        drop = std::max(drop, GetInnerCell(i, j)->GetMaxDrop());
       }
     m_dropCenters.emplace_back(drop, center);
     m_height += (center + drop + Scale_Px(10));
@@ -104,16 +104,16 @@ void MatrCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     wxPoint mp;
     mp.x = point.x + Scale_Px(5);
     mp.y = point.y - m_center;
-    for (unsigned int i = 0; i < m_matWidth; i++) {
+    for (size_t i = 0; i < m_matWidth; i++) {
       mp.y = point.y - m_center + Scale_Px(5);
-      for (unsigned int j = 0; j < m_matHeight; j++) {
+      for (size_t j = 0; j < m_matHeight; j++) {
         if ((j * m_matWidth + i) < m_cells.size()) {
           mp.y += m_dropCenters[j].center;
           wxPoint mp1(mp);
           mp1.x =
-	    mp.x +
-	    (m_widths[i] - m_cells[j * m_matWidth + i]->GetFullWidth()) / 2;
-          m_cells[j * m_matWidth + i]->DrawList(mp1, dc, antialiassingDC);
+            mp.x +
+            (m_widths[i] - GetInnerCell(j, i)->GetFullWidth()) / 2;
+          GetInnerCell(j, i)->DrawList(mp1, dc, antialiassingDC);
           mp.y += (m_dropCenters[j].drop + Scale_Px(10));
         }
       }
@@ -123,50 +123,50 @@ void MatrCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     if (m_specialMatrix) {
       if (m_inferenceMatrix)
         antialiassingDC->DrawLine(point.x + Scale_Px(1), point.y - m_center + Scale_Px(2),
-                     point.x + Scale_Px(1), point.y + m_center - Scale_Px(2));
+                                  point.x + Scale_Px(1), point.y + m_center - Scale_Px(2));
       else {
         if (m_rowNames)
           antialiassingDC->DrawLine(point.x + m_widths[0] + 2 * Scale_Px(5),
-                       point.y - m_center + Scale_Px(2),
-                       point.x + m_widths[0] + 2 * Scale_Px(5),
-                       point.y + m_center - Scale_Px(2));
+                                    point.y - m_center + Scale_Px(2),
+                                    point.x + m_widths[0] + 2 * Scale_Px(5),
+                                    point.y + m_center - Scale_Px(2));
         if (m_colNames)
           antialiassingDC->DrawLine(
-		       point.x + Scale_Px(1),
-		       point.y - m_center + m_dropCenters[0].Sum() + 2 * Scale_Px(5),
-		       point.x + Scale_Px(1) + m_width,
-		       point.y - m_center + m_dropCenters[0].Sum() + 2 * Scale_Px(5));
+                                    point.x + Scale_Px(1),
+                                    point.y - m_center + m_dropCenters[0].Sum() + 2 * Scale_Px(5),
+                                    point.x + Scale_Px(1) + m_width,
+                                    point.y - m_center + m_dropCenters[0].Sum() + 2 * Scale_Px(5));
       }
     } else {
       switch (m_parenType) {
       case paren_rounded: {
         SetPen(dc, 1);
-        int signWidth = Scale_Px(4);
+        wxCoord signWidth = Scale_Px(4);
         if (m_height <= signWidth / 3)
           signWidth = m_height / 3;
 
         // Left bracket
         wxPoint pointsL[5] = {
-	  {point.x + Scale_Px(1) + signWidth, point.y - m_center},
-	  {point.x + Scale_Px(1) + signWidth / 2,
-	   point.y - m_center + signWidth / 2},
-	  {point.x + Scale_Px(1), point.y},
-	  {point.x + Scale_Px(1) + signWidth / 2,
-	   point.y + m_center - signWidth / 2},
-	  {point.x + Scale_Px(1) + signWidth, point.y + m_center}};
+          {point.x + Scale_Px(1) + signWidth, point.y - m_center},
+          {point.x + Scale_Px(1) + signWidth / 2,
+           point.y - m_center + signWidth / 2},
+          {point.x + Scale_Px(1), point.y},
+          {point.x + Scale_Px(1) + signWidth / 2,
+           point.y + m_center - signWidth / 2},
+          {point.x + Scale_Px(1) + signWidth, point.y + m_center}};
         antialiassingDC->DrawSpline(5, pointsL);
         pointsL[2] = {point.x + Scale_Px(1.5), point.y};
         antialiassingDC->DrawSpline(5, pointsL);
 
         // Right bracket
         wxPoint pointsR[5] = {
-	  {point.x + m_width - Scale_Px(1) - signWidth, point.y - m_center},
-	  {point.x + m_width - Scale_Px(1) - signWidth / 2,
-	   point.y - m_center + signWidth / 2},
-	  {point.x + m_width - Scale_Px(1.5), point.y},
-	  {point.x + m_width - Scale_Px(1) - signWidth / 2,
-	   point.y + m_center - signWidth / 2},
-	  {point.x + m_width - Scale_Px(1) - signWidth, point.y + m_center}};
+          {point.x + m_width - Scale_Px(1) - signWidth, point.y - m_center},
+          {point.x + m_width - Scale_Px(1) - signWidth / 2,
+           point.y - m_center + signWidth / 2},
+          {point.x + m_width - Scale_Px(1.5), point.y},
+          {point.x + m_width - Scale_Px(1) - signWidth / 2,
+           point.y + m_center - signWidth / 2},
+          {point.x + m_width - Scale_Px(1) - signWidth, point.y + m_center}};
         antialiassingDC->DrawSpline(5, pointsR);
         pointsR[2] = {point.x + m_width - Scale_Px(1), point.y};
         antialiassingDC->DrawSpline(5, pointsR);
@@ -174,40 +174,40 @@ void MatrCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
       }
       case paren_angled: {
         SetPen(dc, 1);
-        int signWidth = Scale_Px(4);
+        wxCoord signWidth = Scale_Px(4);
         if (m_height <= signWidth / 3)
           signWidth = m_height / 3;
 
         // Left bracket
         wxPoint pointsL[3] = {
-	  {point.x + Scale_Px(1) + signWidth, point.y - m_center},
-	  {point.x + Scale_Px(1), point.y},
-	  {point.x + Scale_Px(1) + signWidth, point.y + m_center}};
+          {point.x + Scale_Px(1) + signWidth, point.y - m_center},
+          {point.x + Scale_Px(1), point.y},
+          {point.x + Scale_Px(1) + signWidth, point.y + m_center}};
         antialiassingDC->DrawLines(3, pointsL);
 
         // Right bracket
         wxPoint pointsR[3] = {
-	  {point.x + m_width - Scale_Px(1) - signWidth, point.y - m_center},
-	  {point.x + m_width - Scale_Px(1.5), point.y},
-	  {point.x + m_width - Scale_Px(1) - signWidth, point.y + m_center}};
+          {point.x + m_width - Scale_Px(1) - signWidth, point.y - m_center},
+          {point.x + m_width - Scale_Px(1.5), point.y},
+          {point.x + m_width - Scale_Px(1) - signWidth, point.y + m_center}};
         antialiassingDC->DrawLines(3, pointsR);
         break;
       }
       case paren_straight: {
         SetPen(dc, 1);
-        int signWidth = Scale_Px(4);
+        wxCoord signWidth = Scale_Px(4);
         if (m_height <= signWidth / 3)
           signWidth = m_height / 3;
 
         // Left bracket
         wxPoint pointsL[2] = {
-	  {point.x + Scale_Px(1) + signWidth / 2, point.y - m_center},
-	  {point.x + Scale_Px(1) + signWidth / 2, point.y + m_center}};
+          {point.x + Scale_Px(1) + signWidth / 2, point.y - m_center},
+          {point.x + Scale_Px(1) + signWidth / 2, point.y + m_center}};
         antialiassingDC->DrawLines(2, pointsL);
 
         // Right bracket
         wxPoint pointsR[2] = {{point.x + m_width - Scale_Px(1) - signWidth / 2,
-	    point.y - m_center},
+                                 point.y - m_center},
                               {point.x + m_width - Scale_Px(1) - signWidth / 2,
                                point.y + m_center}};
         antialiassingDC->DrawLines(2, pointsR);
@@ -241,10 +241,10 @@ void MatrCell::AddNewCell(std::unique_ptr<Cell> &&cell) {
 
 wxString MatrCell::ToString() const {
   wxString s = wxS("matrix(\n");
-  for (unsigned int i = 0; i < m_matHeight; i++) {
+  for (size_t i = 0; i < m_matHeight; i++) {
     s += wxS("\t\t[");
-    for (unsigned int j = 0; j < m_matWidth; j++) {
-      s += m_cells[i * m_matWidth + j]->ListToString();
+    for (size_t j = 0; j < m_matWidth; j++) {
+      s += GetInnerCell(i, j)->ListToString();
       if (j < m_matWidth - 1)
         s += wxS(",\t");
     }
@@ -262,9 +262,9 @@ wxString MatrCell::ToMatlab() const {
   wxString s;
 
   s = wxS("[");
-  for (unsigned int i = 0; i < m_matHeight; i++) {
-    for (unsigned int j = 0; j < m_matWidth; j++) {
-      s += m_cells[i * m_matWidth + j]->ListToMatlab();
+  for (size_t i = 0; i < m_matHeight; i++) {
+    for (size_t j = 0; j < m_matWidth; j++) {
+      s += GetInnerCell(i, j)->ListToMatlab();
       if (j < m_matWidth - 1)
         s += wxS(", ");
     }
@@ -294,13 +294,13 @@ wxString MatrCell::ToTeX() const {
     }
   } else {
     s = wxS("\\begin{array}{");
-    for (unsigned int j = 0; j < m_matWidth; j++)
+    for (size_t j = 0; j < m_matWidth; j++)
       s += wxS("c");
     s += wxS("}");
   }
-  for (unsigned int i = 0; i < m_matHeight; i++) {
-    for (unsigned int j = 0; j < m_matWidth; j++) {
-      s += m_cells[i * m_matWidth + j]->ListToTeX();
+  for (size_t i = 0; i < m_matHeight; i++) {
+    for (size_t j = 0; j < m_matWidth; j++) {
+      s += GetInnerCell(i, j)->ListToTeX();
       if (j < m_matWidth - 1)
         s += wxS(" & ");
     }
@@ -329,11 +329,11 @@ wxString MatrCell::ToMathML() const {
     retval = wxS("<mrow><mo>(</mo><mrow>");
   retval += wxS("<mtable>");
 
-  for (unsigned int i = 0; i < m_matHeight; i++) {
+  for (size_t i = 0; i < m_matHeight; i++) {
     retval += wxS("<mtr>");
-    for (unsigned int j = 0; j < m_matWidth; j++)
-      retval += wxS("<mtd>") + m_cells[i * m_matWidth + j]->ListToMathML() +
-	wxS("</mtd>");
+    for (size_t j = 0; j < m_matWidth; j++)
+      retval += wxS("<mtd>") + GetInnerCell(i, j)->ListToMathML() +
+        wxS("</mtd>");
     retval += wxS("</mtr>");
   }
   retval += wxS("</mtable>\n");
@@ -369,11 +369,11 @@ wxString MatrCell::ToOMML() const {
 
   retval += wxS("<m:e><m:m>");
 
-  for (unsigned int i = 0; i < m_matHeight; i++) {
+  for (size_t i = 0; i < m_matHeight; i++) {
     retval += wxS("<m:mr>");
-    for (unsigned int j = 0; j < m_matWidth; j++)
-      retval += wxS("<m:e>") + m_cells[i * m_matWidth + j]->ListToOMML() +
-	wxS("</m:e>");
+    for (size_t j = 0; j < m_matWidth; j++)
+      retval += wxS("<m:e>") + GetInnerCell(i, j)->ListToOMML() +
+        wxS("</m:e>");
     retval += wxS("</m:mr>");
   }
 
@@ -404,19 +404,19 @@ wxString MatrCell::ToXML() const {
   wxString s = wxEmptyString;
   if (m_specialMatrix)
     s = wxString::Format(wxS("<tb") + flags +
-			 wxS(" special=\"true\" inference=\"%s\" "
-			     "rownames=\"%s\" colnames=\"%s\">"),
+                         wxS(" special=\"true\" inference=\"%s\" "
+                             "rownames=\"%s\" colnames=\"%s\">"),
                          m_inferenceMatrix ? "true" : "false",
                          m_rowNames ? "true" : "false",
                          m_colNames ? "true" : "false");
   else
     s = wxS("<tb") + flags + wxS(">");
 
-  for (unsigned int i = 0; i < m_matHeight; i++) {
+  for (size_t i = 0; i < m_matHeight; i++) {
     s += wxS("<mtr>");
-    for (unsigned int j = 0; j < m_matWidth; j++)
-      s += wxS("<mtd>") + m_cells[i * m_matWidth + j]->ListToXML() +
-	wxS("</mtd>");
+    for (size_t j = 0; j < m_matWidth; j++)
+      s += wxS("<mtd>") + GetInnerCell(i, j)->ListToXML() +
+        wxS("</mtd>");
     s += wxS("</mtr>");
   }
   s += wxS("</tb>");
