@@ -35,8 +35,10 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return m_cells.size(); }
-  Cell *GetInnerCell(int index) const override { return m_cells[index].get(); }
+  size_t GetInnerCellCount() const override { return m_cells.size(); }
+  Cell *GetInnerCell(size_t index) const override { return m_cells[index].get(); }
+  Cell *GetInnerCell(long x, long y) const {
+    return m_cells[static_cast<size_t>(x) * m_matWidth + y].get(); }
 
   void Recalculate(AFontSize fontsize) override;
 
@@ -81,11 +83,11 @@ private:
   //! Collection of pointers to inner cells.
   std::vector<std::unique_ptr<Cell>> m_cells;
 
-  std::vector<int> m_widths;
+  std::vector<wxCoord> m_widths;
   std::vector<DropCenter> m_dropCenters;
 
-  unsigned int m_matWidth = 0;
-  unsigned int m_matHeight = 0;
+  size_t m_matWidth = 0;
+  size_t m_matHeight = 0;
 
   enum parenType : int8_t
   {
@@ -96,7 +98,7 @@ private:
   };
 //** Bitfield objects (1 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_MatrCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_parenType = paren_rounded;
@@ -105,11 +107,11 @@ private:
       m_rowNames = false;
       m_colNames = false;
     }
-  uint8_t m_parenType : 2 /* InitBitFields */;
-  bool m_specialMatrix : 1 /* InitBitFields */;
-  bool m_inferenceMatrix : 1 /* InitBitFields */;
-  bool m_rowNames : 1 /* InitBitFields */;
-  bool m_colNames : 1 /* InitBitFields */;
+  uint8_t m_parenType : 2 /* InitBitFields_MatrCell */;
+  bool m_specialMatrix : 1 /* InitBitFields_MatrCell */;
+  bool m_inferenceMatrix : 1 /* InitBitFields_MatrCell */;
+  bool m_rowNames : 1 /* InitBitFields_MatrCell */;
+  bool m_colNames : 1 /* InitBitFields_MatrCell */;
 };
 
 #endif // MATRCELL_H
