@@ -33,13 +33,13 @@
 #include "CellImpl.h"
 
 NamedBoxCell::NamedBoxCell(GroupCell *group, Configuration *config,
-			   std::unique_ptr<Cell> &&inner,
-			   wxString name)
+                           std::unique_ptr<Cell> &&inner,
+                           wxString name)
   : Cell(group, config),
     m_innerCell(std::move(inner)),
     m_boxname(std::make_unique<TextCell>(m_group, m_configuration, name, TS_STRING))
 {
-  InitBitFields();
+  InitBitFields_NamedBoxCell();
   SetStyle(TS_VARIABLE);
 }
 
@@ -48,8 +48,8 @@ NamedBoxCell::NamedBoxCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=NamedBoxCell::m_close
 NamedBoxCell::NamedBoxCell(GroupCell *group, const NamedBoxCell &cell)
   : NamedBoxCell(group, cell.m_configuration,
-		 CopyList(group, cell.m_innerCell.get()),
-		 cell.m_boxname->GetValue()) {
+                 CopyList(group, cell.m_innerCell.get()),
+                 cell.m_boxname->GetValue()) {
   CopyCommonData(cell);
 }
 
@@ -76,7 +76,7 @@ void NamedBoxCell::Recalculate(AFontSize fontsize) {
   m_nameHeight = m_boxname->GetHeightList();
 
   if (!IsBrokenIntoLines()) {
-    m_width = wxMax(m_innerCellWidth, m_nameWidth) + Scale_Px(8);
+    m_width = std::max(m_innerCellWidth, m_nameWidth) + Scale_Px(8);
     m_height = m_innerCellHeight + m_nameHeight + Scale_Px(16);
     m_center = m_innerCell->GetCenterList() + m_nameHeight + Scale_Px(8);
   } else {
@@ -108,47 +108,47 @@ void NamedBoxCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     m_boxname->DrawList(namepos, dc, antialiassingDC);
 
     // dc->DrawLine(
-    // 		 point.x + Scale_Px(2),
-    // 		 point.y - m_center + innerCellHeight + Scale_Px(2),
+    //               point.x + Scale_Px(2),
+    //               point.y - m_center + innerCellHeight + Scale_Px(2),
     //              point.x + m_width - Scale_Px(2) - 1,
     //              point.y - m_center + innerCellHeight + Scale_Px(2)
-    // 		 );
+    //               );
 
     // The top left line of the box
     dc->DrawLine(
-		 point.x + Scale_Px(2),
-		 point.y - m_center + Scale_Px(2) + m_boxname->GetCenterList(),
+                 point.x + Scale_Px(2),
+                 point.y - m_center + Scale_Px(2) + m_boxname->GetCenterList(),
                  point.x + (m_width - m_nameWidth) / 2,
                  point.y - m_center + Scale_Px(2) + m_boxname->GetCenterList()
-		 );
+                 );
     // The top right line of the box
     dc->DrawLine(
-		 point.x + m_width - Scale_Px(2),
-		 point.y - m_center + Scale_Px(2) + m_boxname->GetCenterList(),
+                 point.x + m_width - Scale_Px(2),
+                 point.y - m_center + Scale_Px(2) + m_boxname->GetCenterList(),
                  point.x + m_width - ((m_width - m_nameWidth) / 2),
                  point.y - m_center + Scale_Px(2) + m_boxname->GetCenterList()
-		 );
+                 );
     // The left line of the box
     dc->DrawLine(
-		 point.x + Scale_Px(2),
-		 point.y - m_center + m_height - Scale_Px(2),
-		 point.x + Scale_Px(2),
+                 point.x + Scale_Px(2),
+                 point.y - m_center + m_height - Scale_Px(2),
+                 point.x + Scale_Px(2),
                  point.y - m_center + Scale_Px(2) + m_nameHeight / 2
-		 );
+                 );
     // The right line of the box
     dc->DrawLine(
                  point.x + m_width - Scale_Px(2),
-		 point.y - m_center + Scale_Px(2) + m_nameHeight / 2,
+                 point.y - m_center + Scale_Px(2) + m_nameHeight / 2,
                  point.x + m_width - Scale_Px(2),
                  point.y - m_center + m_height - Scale_Px(2)
-		 );
+                 );
     // The bottom line of the box
     dc->DrawLine(
                  point.x + Scale_Px(2),
                  point.y - m_center + m_height - Scale_Px(2),
                  point.x + m_width - Scale_Px(2),
                  point.y - m_center + m_height - Scale_Px(2)
-		 );
+                 );
   }
 }
 
@@ -176,15 +176,15 @@ wxString NamedBoxCell::ToTeX() const {
 }
 
 wxString NamedBoxCell::ToMathML() const {
-   return wxS("<apply><box/><ci>") + m_innerCell->ListToMathML() +
-     wxS("</ci><ci>") +
-     m_boxname->ListToMathML() +
-     wxS("</apply>");
+  return wxS("<apply><box/><ci>") + m_innerCell->ListToMathML() +
+    wxS("</ci><ci>") +
+    m_boxname->ListToMathML() +
+    wxS("</apply>");
 }
 
 wxString NamedBoxCell::ToOMML() const {
   return _T("<m:func><m:fName><m:r>box</m:r></m:fName><m:e>") +
-    m_innerCell->ListToOMML() + wxS("</m:e><m:e>") + 
+    m_innerCell->ListToOMML() + wxS("</m:e><m:e>") +
     m_boxname->ListToOMML() +
     _T("</m:e></m:func>");
 }
