@@ -38,7 +38,7 @@ ParenCell::ParenCell(GroupCell *group, Configuration *config,
     m_open(std::make_unique<TextCell>(group, config, wxS("("))),
     m_innerCell(std::move(inner)),
     m_close(std::make_unique<TextCell>(group, config, wxS(")"))) {
-  InitBitFields();
+  InitBitFields_ParenCell();
   // If there is a contents it doesn't need to start with a multiplication
   // dot.
   if(m_innerCell)
@@ -61,7 +61,7 @@ ParenCell::ParenCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=ParenCell::m_extendHeight
 ParenCell::ParenCell(GroupCell *group, const ParenCell &cell)
   : ParenCell(group, cell.m_configuration,
-	      CopyList(group, cell.m_innerCell.get())) {
+              CopyList(group, cell.m_innerCell.get())) {
   CopyCommonData(cell);
 }
 
@@ -111,7 +111,7 @@ void ParenCell::Recalculate(AFontSize fontsize) {
   int innerCellHeight = 0;
   if(m_innerCell)
     innerCellHeight = m_innerCell->GetHeightList();
-  m_height = wxMax(m_signHeight, innerCellHeight) + Scale_Px(2);
+  m_height = std::max(m_signHeight, innerCellHeight) + Scale_Px(2);
   m_center = m_height / 2;
 
   dc->GetTextExtent(wxS("("), &m_charWidth1, &m_charHeight1);
@@ -122,8 +122,8 @@ void ParenCell::Recalculate(AFontSize fontsize) {
     int innerCellCenter = 0;
     if(m_innerCell)
       innerCellCenter = m_innerCell->GetCenterList();
-    m_height = wxMax(innerCellHeight, m_open->GetHeightList());
-    m_center = wxMax(innerCellCenter, m_open->GetCenterList());
+    m_height = std::max(innerCellHeight, m_open->GetHeightList());
+    m_center = std::max(innerCellCenter, m_open->GetCenterList());
   } else {
     if (m_innerCell) {
       switch (m_bigParenType) {
@@ -134,20 +134,20 @@ void ParenCell::Recalculate(AFontSize fontsize) {
       }
       }
       m_innerCell->SetCurrentPoint(
-				   wxPoint(m_currentPoint.x + m_signWidth, m_currentPoint.y));
+                                   wxPoint(m_currentPoint.x + m_signWidth, m_currentPoint.y));
 
       // Center the argument of all big parenthesis vertically
       if (m_bigParenType != Configuration::ascii)
         m_innerCell->SetCurrentPoint(
-				     wxPoint(m_currentPoint.x + m_signWidth,
-					     m_currentPoint.y + (m_innerCell->GetCenterList() -
-								 m_innerCell->GetHeightList() / 2)));
+                                     wxPoint(m_currentPoint.x + m_signWidth,
+                                             m_currentPoint.y + (m_innerCell->GetCenterList() -
+                                                                 m_innerCell->GetHeightList() / 2)));
       else
         m_innerCell->SetCurrentPoint(
-				     wxPoint(m_currentPoint.x + m_signWidth, m_currentPoint.y));
+                                     wxPoint(m_currentPoint.x + m_signWidth, m_currentPoint.y));
 
       m_height =
-	wxMax(m_signHeight, m_innerCell->GetHeightList()) + Scale_Px(4);
+        std::max(m_signHeight, m_innerCell->GetHeightList()) + Scale_Px(4);
       m_center = m_height / 2;
     }
   }
@@ -162,22 +162,22 @@ void ParenCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     switch (m_bigParenType) {
     case Configuration::ascii:
       {
-	innerCellPos.x += m_open->GetWidth();
-	m_open->DrawList(point, dc, antialiassingDC);
-	int innerCellWidth = 0;
-	if(m_innerCell)
-	  innerCellWidth = m_innerCell->GetFullWidth();
-	
-	m_close->DrawList(wxPoint(point.x + m_open->GetWidth() + innerCellWidth,
-				  point.y), dc, antialiassingDC);
-	break;
+        innerCellPos.x += m_open->GetWidth();
+        m_open->DrawList(point, dc, antialiassingDC);
+        int innerCellWidth = 0;
+        if(m_innerCell)
+          innerCellWidth = m_innerCell->GetFullWidth();
+
+        m_close->DrawList(wxPoint(point.x + m_open->GetWidth() + innerCellWidth,
+                                  point.y), dc, antialiassingDC);
+        break;
       }
     default: {
       if(m_innerCell)
-	{
-	  innerCellPos.y +=
-	    (m_innerCell->GetCenterList() - m_innerCell->GetHeightList() / 2);
-	}
+        {
+          innerCellPos.y +=
+            (m_innerCell->GetCenterList() - m_innerCell->GetHeightList() / 2);
+        }
       SetPen(antialiassingDC, 1.0);
       SetBrush(antialiassingDC);
 
@@ -186,54 +186,54 @@ void ParenCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
 
       // Left bracket
       const wxPoint pointsL[10] = {
-	{point.x + Scale_Px(1) + signWidth, point.y - m_center + Scale_Px(4)},
-	{point.x + Scale_Px(1) + 3 * signWidth / 4,
-	 point.y - m_center + 3 * signWidth / 4 + Scale_Px(4)},
-	{point.x + Scale_Px(1), point.y},
-	{point.x + Scale_Px(1) + 3 * signWidth / 4,
-	 point.y + m_center - 3 * signWidth / 4 - Scale_Px(4)},
-	{point.x + Scale_Px(1) + signWidth, point.y + m_center - Scale_Px(4)},
-	// Appending the last point twice should allow for an abrupt 180° turn
-	{point.x + Scale_Px(1) + signWidth, point.y + m_center - Scale_Px(4)},
-	{point.x + Scale_Px(1) + 3 * signWidth / 4,
-	 point.y + m_center - 3 * signWidth / 4 - Scale_Px(4)},
-	// The middle point of the 2nd run of the parenthesis is at a
-	// different place making the parenthesis wider here
-	{point.x + Scale_Px(2), point.y},
-	{point.x + Scale_Px(1) + 3 * signWidth / 4,
-	 point.y - m_center + 3 * signWidth / 4 + Scale_Px(4)},
-	{point.x + Scale_Px(1) + signWidth,
-	 point.y - m_center + Scale_Px(4)}};
+        {point.x + Scale_Px(1) + signWidth, point.y - m_center + Scale_Px(4)},
+        {point.x + Scale_Px(1) + 3 * signWidth / 4,
+         point.y - m_center + 3 * signWidth / 4 + Scale_Px(4)},
+        {point.x + Scale_Px(1), point.y},
+        {point.x + Scale_Px(1) + 3 * signWidth / 4,
+         point.y + m_center - 3 * signWidth / 4 - Scale_Px(4)},
+        {point.x + Scale_Px(1) + signWidth, point.y + m_center - Scale_Px(4)},
+        // Appending the last point twice should allow for an abrupt 180° turn
+        {point.x + Scale_Px(1) + signWidth, point.y + m_center - Scale_Px(4)},
+        {point.x + Scale_Px(1) + 3 * signWidth / 4,
+         point.y + m_center - 3 * signWidth / 4 - Scale_Px(4)},
+        // The middle point of the 2nd run of the parenthesis is at a
+        // different place making the parenthesis wider here
+        {point.x + Scale_Px(2), point.y},
+        {point.x + Scale_Px(1) + 3 * signWidth / 4,
+         point.y - m_center + 3 * signWidth / 4 + Scale_Px(4)},
+        {point.x + Scale_Px(1) + signWidth,
+         point.y - m_center + Scale_Px(4)}};
       antialiassingDC->DrawSpline(10, pointsL);
 
       // Right bracket
       const wxPoint pointsR[10] = {
-	{point.x + m_width - Scale_Px(1) - signWidth,
-	 point.y - m_center + Scale_Px(4)},
-	{point.x + m_width - Scale_Px(1) - signWidth / 2,
-	 point.y - m_center + signWidth / 2 + Scale_Px(4)},
-	{point.x + m_width - Scale_Px(1), point.y},
-	{point.x + m_width - Scale_Px(1) - signWidth / 2,
-	 point.y + m_center - signWidth / 2 - Scale_Px(4)},
-	{point.x + m_width - Scale_Px(1) - signWidth,
-	 point.y + m_center - Scale_Px(4)},
-	{point.x + m_width - Scale_Px(1) - signWidth,
-	 point.y + m_center - Scale_Px(4)},
-	{point.x + m_width - Scale_Px(1) - signWidth / 2,
-	 point.y + m_center - signWidth / 2 - Scale_Px(4)},
-	{point.x + m_width - Scale_Px(2), point.y},
-	{point.x + m_width - Scale_Px(1) - signWidth / 2,
-	 point.y - m_center + signWidth / 2 + Scale_Px(4)},
-	{point.x + m_width - Scale_Px(1) - signWidth,
-	 point.y - m_center + Scale_Px(4)}};
+        {point.x + m_width - Scale_Px(1) - signWidth,
+         point.y - m_center + Scale_Px(4)},
+        {point.x + m_width - Scale_Px(1) - signWidth / 2,
+         point.y - m_center + signWidth / 2 + Scale_Px(4)},
+        {point.x + m_width - Scale_Px(1), point.y},
+        {point.x + m_width - Scale_Px(1) - signWidth / 2,
+         point.y + m_center - signWidth / 2 - Scale_Px(4)},
+        {point.x + m_width - Scale_Px(1) - signWidth,
+         point.y + m_center - Scale_Px(4)},
+        {point.x + m_width - Scale_Px(1) - signWidth,
+         point.y + m_center - Scale_Px(4)},
+        {point.x + m_width - Scale_Px(1) - signWidth / 2,
+         point.y + m_center - signWidth / 2 - Scale_Px(4)},
+        {point.x + m_width - Scale_Px(2), point.y},
+        {point.x + m_width - Scale_Px(1) - signWidth / 2,
+         point.y - m_center + signWidth / 2 + Scale_Px(4)},
+        {point.x + m_width - Scale_Px(1) - signWidth,
+         point.y - m_center + Scale_Px(4)}};
       antialiassingDC->DrawSpline(10, pointsR);
     } break;
     }
 
     if (!IsBrokenIntoLines())
       {
-	if(m_innerCell)
-	  m_innerCell->DrawList(innerCellPos, dc, antialiassingDC);
+        if(m_innerCell)
+          m_innerCell->DrawList(innerCellPos, dc, antialiassingDC);
       }
   }
 }
@@ -314,7 +314,7 @@ wxString ParenCell::ToMathML() const {
   wxString innerCellContents;
   if(m_innerCell)
     innerCellContents = m_innerCell->ListToMathML();
-  
+
   return (wxS("<mrow><mo>") + XMLescape(open) + wxS("</mo>") +
           innerCellContents + wxS("<mo>") + XMLescape(close) +
           wxS("</mo></mrow>\n"));
@@ -341,7 +341,7 @@ bool ParenCell::BreakUp() {
     {
       m_open->SetNextToDraw(m_innerCell);
       m_innerCell->last()->SetNextToDraw(m_close);
-    }					 
+    }
   else
     m_open->SetNextToDraw(m_close);
   m_close->SetNextToDraw(m_nextToDraw);
