@@ -35,7 +35,7 @@
 SqrtCell::SqrtCell(GroupCell *group, Configuration *config,
                    std::unique_ptr<Cell> &&inner)
   : Cell(group, config), m_innerCell(std::move(inner)) {
-  InitBitFields();
+  InitBitFields_SqrtCell();
   SetStyle(TS_VARIABLE);
 }
 
@@ -48,7 +48,7 @@ SqrtCell::SqrtCell(GroupCell *group, Configuration *config,
 // cppcheck-suppress uninitMemberVar symbolName=SqrtCell::m_signFontScale
 SqrtCell::SqrtCell(GroupCell *group, const SqrtCell &cell)
   : SqrtCell(group, cell.m_configuration,
-	     CopyList(group, cell.m_innerCell.get())) {
+             CopyList(group, cell.m_innerCell.get())) {
   CopyCommonData(cell);
 }
 
@@ -70,8 +70,8 @@ void SqrtCell::Recalculate(AFontSize fontsize) {
   if (!IsBrokenIntoLines()) {
     auto openHeight = 0; // m_open->GetHeightList();
     auto openCenter = 0; // m_open->GetCenterList();
-    m_height = wxMax(m_innerCell->GetHeightList(), openHeight) + Scale_Px(3);
-    m_center = wxMax(m_innerCell->GetCenterList(), openCenter) + Scale_Px(3);
+    m_height = std::max(m_innerCell->GetHeightList(), openHeight) + Scale_Px(3);
+    m_center = std::max(m_innerCell->GetCenterList(), openCenter) + Scale_Px(3);
   } else {
     m_height = m_center = m_width = 0;
     m_open->Recalculate(fontsize);
@@ -90,22 +90,22 @@ void SqrtCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
       SetPen(antialiassingDC, 1.2);
 
       const wxPoint points[12] = {
-	{0, 0},
-	{Scale_Px(3), -Scale_Px(1)},
-	//  A wider line
-	{Scale_Px(3), -Scale_Px(1)},
-	{Scale_Px(7), m_height - m_center - Scale_Px(4)},
-	{Scale_Px(7.5), m_height - m_center - Scale_Px(4)},
-	{Scale_Px(3.5), -Scale_Px(1)},
-	{Scale_Px(3.5), -Scale_Px(1)},
-	{Scale_Px(3), -Scale_Px(1)},
-	{Scale_Px(8), m_height - m_center - Scale_Px(4)},
-	// The upwards line
-	{Scale_Px(10), -m_center + Scale_Px(2)},
-	// The horizontal line
-	{m_width - Scale_Px(1), -m_center + Scale_Px(2)},
-	// The serif at the end of the root
-	{m_width - Scale_Px(1), -m_center + Scale_Px(6)}};
+        {0, 0},
+        {Scale_Px(3), -Scale_Px(1)},
+        //  A wider line
+        {Scale_Px(3), -Scale_Px(1)},
+        {Scale_Px(7), m_height - m_center - Scale_Px(4)},
+        {Scale_Px(7.5), m_height - m_center - Scale_Px(4)},
+        {Scale_Px(3.5), -Scale_Px(1)},
+        {Scale_Px(3.5), -Scale_Px(1)},
+        {Scale_Px(3), -Scale_Px(1)},
+        {Scale_Px(8), m_height - m_center - Scale_Px(4)},
+        // The upwards line
+        {Scale_Px(10), -m_center + Scale_Px(2)},
+        // The horizontal line
+        {m_width - Scale_Px(1), -m_center + Scale_Px(2)},
+        // The serif at the end of the root
+        {m_width - Scale_Px(1), -m_center + Scale_Px(6)}};
       antialiassingDC->DrawLines(12, points, point.x, point.y);
     }
 
