@@ -36,14 +36,14 @@ SubCell::SubCell(GroupCell *group, Configuration *config,
                  std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&index)
   : Cell(group, config), m_baseCell(std::move(base)),
     m_indexCell(std::move(index)) {
-  InitBitFields();
+  InitBitFields_SubCell();
   SetStyle(TS_VARIABLE);
 }
 
 SubCell::SubCell(GroupCell *group, const SubCell &cell)
   : SubCell(group, cell.m_configuration,
-	    CopyList(group, cell.m_baseCell.get()),
-	    CopyList(group, cell.m_indexCell.get())) {
+            CopyList(group, cell.m_baseCell.get()),
+            CopyList(group, cell.m_indexCell.get())) {
   CopyCommonData(cell);
   m_altCopyText = cell.m_altCopyText;
 }
