@@ -38,12 +38,12 @@
 SubSupCell::SubSupCell(GroupCell *group, Configuration *config,
                        std::unique_ptr<Cell> &&base)
   : Cell(group, config), m_baseCell(std::move(base)) {
-  InitBitFields();
+  InitBitFields_SubSubCell();
 }
 
 SubSupCell::SubSupCell(GroupCell *group, const SubSupCell &cell)
   : SubSupCell(group, cell.m_configuration,
-	       CopyList(group, cell.m_baseCell.get())) {
+               CopyList(group, cell.m_baseCell.get())) {
   CopyCommonData(cell);
   m_altCopyText = cell.m_altCopyText;
   SetIndex(CopyList(group, cell.m_postSubCell.get()));
@@ -110,10 +110,10 @@ void SubSupCell::Recalculate(AFontSize const fontsize) {
 
   m_baseCell->RecalculateList(fontsize);
 
-  int preWidth = 0;
-  int postWidth = 0;
-  int subHeight = 0;
-  int supHeight = 0;
+  wxCoord preWidth = 0;
+  wxCoord postWidth = 0;
+  wxCoord subHeight = 0;
+  wxCoord supHeight = 0;
   if (m_postSubCell) {
     m_postSubCell->RecalculateList(smallerFontSize);
     postWidth = m_postSubCell->GetFullWidth();
@@ -121,27 +121,27 @@ void SubSupCell::Recalculate(AFontSize const fontsize) {
   }
   if (m_postSupCell) {
     m_postSupCell->RecalculateList(smallerFontSize);
-    postWidth = wxMax(postWidth, m_postSupCell->GetFullWidth());
+    postWidth = std::max(postWidth, m_postSupCell->GetFullWidth());
     supHeight = m_postSupCell->GetHeightList();
   }
   if (m_preSubCell) {
     m_preSubCell->RecalculateList(smallerFontSize);
     preWidth = m_preSubCell->GetFullWidth();
-    subHeight = wxMax(subHeight, m_preSubCell->GetHeightList());
+    subHeight = std::max(subHeight, m_preSubCell->GetHeightList());
   }
   if (m_preSupCell) {
     m_preSupCell->RecalculateList(smallerFontSize);
-    preWidth = wxMax(preWidth, m_preSupCell->GetFullWidth());
-    supHeight = wxMax(subHeight, m_preSupCell->GetHeightList());
+    preWidth = std::max(preWidth, m_preSupCell->GetFullWidth());
+    supHeight = std::max(subHeight, m_preSupCell->GetHeightList());
   }
 
   m_width = preWidth + m_baseCell->GetFullWidth() + postWidth;
 
   m_height = m_baseCell->GetHeightList() + subHeight + supHeight -
-    2 * Scale_Px(.8 * fontsize + MC_EXP_INDENT);
+    2 * Scale_Px(.8 * fontsize.Get() + MC_EXP_INDENT);
 
   m_center = supHeight + m_baseCell->GetCenterList() -
-    Scale_Px(.8 * fontsize + MC_EXP_INDENT);
+    Scale_Px(.8 * fontsize.Get() + MC_EXP_INDENT);
   Cell::Recalculate(fontsize);
 }
 
@@ -150,18 +150,18 @@ void SubSupCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
   if (DrawThisCell(point)) {
     wxPoint in;
 
-    int preWidth = 0;
+    wxCoord preWidth = 0;
 
     if (m_preSubCell)
       preWidth = m_preSubCell->GetFullWidth();
     if (m_preSupCell)
-      preWidth = wxMax(preWidth, m_preSupCell->GetFullWidth());
+      preWidth = std::max(preWidth, m_preSupCell->GetFullWidth());
 
     if (m_preSubCell) {
       wxPoint presub = point;
       presub.x += preWidth - m_preSubCell->GetFullWidth();
       presub.y += m_baseCell->GetMaxDrop() + m_preSubCell->GetCenterList() -
-	.8 * m_fontSize_Scaled + MC_EXP_INDENT;
+        static_cast<wxCoord>(.8 * m_fontSize_Scaled.Get()) + MC_EXP_INDENT;
       m_preSubCell->DrawList(presub, dc, antialiassingDC);
     }
 
@@ -169,8 +169,8 @@ void SubSupCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
       wxPoint presup = point;
       presup.x += preWidth - m_preSupCell->GetFullWidth();
       presup.y -= m_baseCell->GetCenterList() + m_preSupCell->GetHeightList() -
-	m_preSupCell->GetCenterList() - .8 * m_fontSize_Scaled +
-	MC_EXP_INDENT;
+        m_preSupCell->GetCenterList() - static_cast<wxCoord>(.8 * m_fontSize_Scaled.Get()) +
+        MC_EXP_INDENT;
       m_preSupCell->DrawList(presup, dc, antialiassingDC);
     }
 
@@ -180,14 +180,14 @@ void SubSupCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
     in.x = point.x + m_baseCell->GetFullWidth() - Scale_Px(2);
     if (m_postSubCell) {
       in.y = point.y + m_baseCell->GetMaxDrop() +
-	m_postSubCell->GetCenterList() - .8 * m_fontSize_Scaled +
-	MC_EXP_INDENT;
+        m_postSubCell->GetCenterList() - .8 * m_fontSize_Scaled.Get() +
+        MC_EXP_INDENT;
       m_postSubCell->DrawList(in, dc, antialiassingDC);
     }
     if (m_postSupCell) {
       in.y = point.y - m_baseCell->GetCenterList() -
-	m_postSupCell->GetHeightList() + m_postSupCell->GetCenterList() +
-	.8 * m_fontSize_Scaled + MC_EXP_INDENT;
+        m_postSupCell->GetHeightList() + m_postSupCell->GetCenterList() +
+        .8 * m_fontSize_Scaled.Get() + MC_EXP_INDENT;
       m_postSupCell->DrawList(in, dc, antialiassingDC);
     }
   }
@@ -211,7 +211,7 @@ wxString SubSupCell::ToString() const {
     if (m_postSupCell->IsCompound())
       s += ")";
   } else {
-    for (const auto &cell : m_scriptCells)
+    for (const Cell * const &cell : m_scriptCells)
       s += "[" + cell->ListToString() + "]";
   }
   return s;
@@ -235,7 +235,7 @@ wxString SubSupCell::ToMatlab() const {
     s += "[";
     bool first = false;
 
-    for (const auto &cell : m_scriptCells) {
+    for (const Cell * const &cell : m_scriptCells) {
       if (!first)
         s += ";";
       first = true;
@@ -396,7 +396,7 @@ wxString SubSupCell::GetDiffPart() const {
     s += ",";
     s += m_postSupCell->ListToString();
   } else {
-    for (const auto &cell : m_scriptCells)
+    for (const Cell * const &cell : m_scriptCells)
       s += "[" + cell->ListToString() + "]";
     s += ",1";
   }
