@@ -23,8 +23,8 @@
 /*! \file
   This file declares the class SumCell
 
-  SumCell is the Cell type that represents maxima's <code>sum()</code>, 
-  <code>lsum</code> and <code>product()</code> 
+  SumCell is the Cell type that represents maxima's <code>sum()</code>,
+  <code>lsum</code> and <code>product()</code>
   commands.
 */
 
@@ -43,6 +43,7 @@ enum sumStyle : int8_t
   SM_PROD
 };
 
+//cppcheck-suppress ctuOneDefinitionRuleViolation
 class SumCell final : public Cell
 {
 public:
@@ -53,10 +54,10 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 10; }
+  size_t GetInnerCellCount() const override { return 10; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_open)[index].get(); }
-  
+  Cell *GetInnerCell(size_t index) const override { return (&m_open)[index].get(); }
+
   void Recalculate(AFontSize fontsize) override;
 
   void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
@@ -78,6 +79,8 @@ public:
 private:
   std::unique_ptr<Cell> MakeStart(Cell *under) const;
   void MakeBreakUpCells();
+  const static wxString m_svgSumSign;
+  const static wxString m_svgProdSign;
 
   ParenCell *Paren() const;
   //! The base cell owned by the paren (it's without the paren)
@@ -103,21 +106,20 @@ private:
   std::unique_ptr<Cell> m_under;
   // The pointers above point to inner cells and must be kept contiguous.
 
-  float m_signWidth = 30.0f;
-  int m_signHeight = 50;
-  int m_signWCenter = 15;
+  wxCoord m_signWidth = 30.0f;
+  wxCoord m_signHeight = 50;
   sumStyle m_sumStyle = SM_SUM;
 
 //** Bitfield objects (1 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_SumCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_displayParen = true;
     }
 
   //! Display m_paren if true, or Base() if false
-  bool m_displayParen : 1 /* InitBitFields */;
+  bool m_displayParen : 1 /* InitBitFields_SumCell */;
 };
 
 #endif // SUMCELL_H
