@@ -43,9 +43,9 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
 
   AFontSize GetScaledTextSize() const;
-  
+
   void SetStyle(TextStyle style) override;
-  
+
   //! Set the text contained in this cell
   void SetValue(const wxString &text) override;
 
@@ -55,6 +55,7 @@ public:
   const wxFont &GetFont(AFontSize fontsize) const {
     return m_configuration->GetStyle(GetTextStyle())->GetFont(fontsize);
   }
+  //cppcheck-suppress functionConst
   void SetFont(wxDC *dc, AFontSize fontsize);
 
   /*! Calling this function signals that the "(" this cell ends in isn't part of the function name
@@ -117,7 +118,7 @@ protected:
     userLabelText,
     numberStart,
     ellipsis,
-    numberEnd    
+    numberEnd
   };
 
   struct SizeEntry {
@@ -147,20 +148,23 @@ protected:
 
 //** Bitfield objects (1 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_TextCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_dontEscapeOpeningParenthesis = false;
       m_promptTooltip = false;
       m_keepPercent_last = m_configuration->CheckKeepPercent();
+      m_greekNamesAsLetter = false;
     }
 
   //! Is an ending "(" of a function name the opening parenthesis of the function?
-  bool m_dontEscapeOpeningParenthesis : 1 /* InitBitFields */;
+  bool m_dontEscapeOpeningParenthesis : 1 /* InitBitFields_TextCell */;
   //! Default to a special tooltip for prompts?
-  bool m_promptTooltip : 1 /* InitBitFields */;
+  bool m_promptTooltip : 1 /* InitBitFields_TextCell */;
   //! The last known value of CheckKeepPercent
   bool m_keepPercent_last : 1;
+  //! The last known value of "display greek names as unicode char"
+  bool m_greekNamesAsLetter : 1;
 
 };
 
