@@ -44,7 +44,7 @@ public:
 private:
 //** Bitfield objects (0 bytes)
 //**
-  static void InitBitFields()
+  static void InitBitFields_VisiblyInvalidCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
