@@ -27,6 +27,7 @@
 
 #include "main.h"
 #include "Dirstructure.h"
+#include "StackToStdErr.h"
 #include "wxMathml.h"
 #include <iostream>
 #include <wx/cmdline.h>
@@ -36,6 +37,7 @@
 #include <wx/image.h>
 #include <wx/intl.h>
 #include <wx/translation.h>
+#include <wx/debugrpt.h>
 #if wxCHECK_VERSION(3, 1, 6)
 #include <wx/uilocale.h>
 #endif
@@ -43,6 +45,7 @@
 #include <wx/tipdlg.h>
 #include <wx/utils.h>
 #include <wx/wx.h>
+#include <vector>
 #ifdef __WXMSW__
 #include <windows.h>
 #endif
@@ -97,56 +100,56 @@ int CommonMain() {
 }
 wxCmdLineParser cmdLineParser;
 static const wxCmdLineEntryDesc cmdLineDesc[] = {
-    {wxCMD_LINE_SWITCH, "v", "version", "Output the version info.",
-     wxCMD_LINE_VAL_NONE, 0},
-    /* Usually wxCMD_LINE_OPTION_HELP is used with the following option, but
-     * that displays a message using its own window and we want the message on
-     * the command line.  If a user enters a command line option, he expects
-     * probably an answer just on the command line... */
-    {wxCMD_LINE_SWITCH, "h", "help", "Show this help message.",
-     wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_OPTION, "o", "open", "Open a file.", wxCMD_LINE_VAL_STRING, 0},
-    {wxCMD_LINE_SWITCH, "e", "eval", "Evaluate the file after opening it.",
-     wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_SWITCH, "", "single_process",
-     "Open all files from within the same process.", wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_SWITCH, "b", "batch",
-     "Run the file and exit afterwards. Halts on questions and stops on "
-     "errors.",
-     wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_SWITCH, "", "logtostderr",
-     "Log all \"debug messages\" sidebar messages to stderr, too.",
-     wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_SWITCH, "", "debug",
-     "Enable costly debug checks.",
-     wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_SWITCH, "", "pipe", "Pipe messages from Maxima to stderr.",
-     wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_SWITCH, "", "exit-on-error",
-     "Close the program on any Maxima error.", wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_OPTION, "f", "ini",
-     "Allows to specify a file to store the configuration in.",
-     wxCMD_LINE_VAL_STRING, 0},
-    {wxCMD_LINE_OPTION, "u", "use-version", "Use Maxima version <str>.",
-     wxCMD_LINE_VAL_STRING, 0},
-    {wxCMD_LINE_OPTION, "l", "lisp",
-     "Use a Maxima compiled with lisp compiler <str>.", wxCMD_LINE_VAL_STRING,
-     0},
-    {wxCMD_LINE_OPTION, "X", "extra-args",
-     "Allows to specify extra Maxima arguments.", wxCMD_LINE_VAL_STRING, 0},
-    {wxCMD_LINE_OPTION, "m", "maxima",
-     "Allows to specify the location of the Maxima binary.",
-     wxCMD_LINE_VAL_STRING, 0},
-    {wxCMD_LINE_SWITCH, "", "enableipc",
-     "Lets Maxima control wxMaxima via interprocess communications. Use this "
-     "option with care.",
-     wxCMD_LINE_VAL_NONE, 0},
-    {wxCMD_LINE_OPTION, "", "wxmathml-lisp",
-     "Location of wxMathML.lisp (if not the built-in should be used, mainly for developers).",
-     wxCMD_LINE_VAL_STRING, 0},
-    {wxCMD_LINE_PARAM, NULL, NULL, "input file", wxCMD_LINE_VAL_STRING,
-     wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_PARAM_MULTIPLE},
-     wxCMD_LINE_DESC_END};
+  {wxCMD_LINE_SWITCH, "v", "version", "Output the version info.",
+   wxCMD_LINE_VAL_NONE, 0},
+  /* Usually wxCMD_LINE_OPTION_HELP is used with the following option, but
+   * that displays a message using its own window and we want the message on
+   * the command line.  If a user enters a command line option, he expects
+   * probably an answer just on the command line... */
+  {wxCMD_LINE_SWITCH, "h", "help", "Show this help message.",
+   wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_OPTION, "o", "open", "Open a file.", wxCMD_LINE_VAL_STRING, 0},
+  {wxCMD_LINE_SWITCH, "e", "eval", "Evaluate the file after opening it.",
+   wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_SWITCH, "", "single_process",
+   "Open all files from within the same process.", wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_SWITCH, "b", "batch",
+   "Run the file and exit afterwards. Halts on questions and stops on "
+   "errors.",
+   wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_SWITCH, "", "logtostderr",
+   "Log all \"debug messages\" sidebar messages to stderr, too.",
+   wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_SWITCH, "", "debug",
+   "Enable costly debug checks.",
+   wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_SWITCH, "", "pipe", "Pipe messages from Maxima to stderr.",
+   wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_SWITCH, "", "exit-on-error",
+   "Close the program on any Maxima error.", wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_OPTION, "f", "ini",
+   "Allows to specify a file to store the configuration in.",
+   wxCMD_LINE_VAL_STRING, 0},
+  {wxCMD_LINE_OPTION, "u", "use-version", "Use Maxima version <str>.",
+   wxCMD_LINE_VAL_STRING, 0},
+  {wxCMD_LINE_OPTION, "l", "lisp",
+   "Use a Maxima compiled with lisp compiler <str>.", wxCMD_LINE_VAL_STRING,
+   0},
+  {wxCMD_LINE_OPTION, "X", "extra-args",
+   "Allows to specify extra Maxima arguments.", wxCMD_LINE_VAL_STRING, 0},
+  {wxCMD_LINE_OPTION, "m", "maxima",
+   "Allows to specify the location of the Maxima binary.",
+   wxCMD_LINE_VAL_STRING, 0},
+  {wxCMD_LINE_SWITCH, "", "enableipc",
+   "Lets Maxima control wxMaxima via interprocess communications. Use this "
+   "option with care.",
+   wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_OPTION, "", "wxmathml-lisp",
+   "Location of wxMathML.lisp (if not the built-in should be used, mainly for developers).",
+   wxCMD_LINE_VAL_STRING, 0},
+  {wxCMD_LINE_PARAM, NULL, NULL, "input file", wxCMD_LINE_VAL_STRING,
+   wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_PARAM_MULTIPLE},
+  wxCMD_LINE_DESC_END};
 
 
 #ifndef __WXMSW__
@@ -157,8 +160,8 @@ int main(int argc, char *argv[]) {
   return CommonMain();
 }
 #else
-int WINAPI WinMain(HINSTANCE hI, HINSTANCE hPrevI, LPSTR lpCmdLine,
-                   int nCmdShow) {
+int WINAPI WinMain(_In_ HINSTANCE hI, _In_opt_ HINSTANCE hPrevI, _In_ LPSTR lpCmdLine,
+                   _In_ int nCmdShow) {
   // // Only needed if we don't manage to ship the right manifest
   // #ifdef DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE
   // SetProcessDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE);
@@ -183,7 +186,7 @@ bool MyApp::OnInit() {
   wxLogBuffer noStdErr;
   {
     // If supported: Generate symbolic backtraces on crashes.
-#if wxUSE_ON_FATAL_EXCEPTION
+#if wxUSE_ON_FATAL_EXCEPTION && wxUSE_CRASHREPORT
     wxHandleFatalExceptions(true);
 #endif
     int major;
@@ -205,12 +208,12 @@ bool MyApp::OnInit() {
     wxString configFileOld =
       wxStandardPaths::Get().GetUserConfigDir() + wxS("/") +
       wxStandardPaths::Get().MakeConfigFileName(
-						wxString(wxS("wxMaxima")), wxStandardPaths::ConfigFileConv_Dot);
+                                                wxString(wxS("wxMaxima")), wxStandardPaths::ConfigFileConv_Dot);
     wxStandardPaths::Get().SetFileLayout(wxStandardPaths::FileLayout_XDG);
     wxString configFileXDG =
       wxStandardPaths::Get().GetUserConfigDir() + wxS("/") +
       wxStandardPaths::Get().MakeConfigFileName(
-						wxString(wxS("wxMaxima")), wxStandardPaths::ConfigFileConv_Ext);
+                                                wxString(wxS("wxMaxima")), wxStandardPaths::ConfigFileConv_Ext);
 
     if (!wxFileExists(configFileXDG)) {
       wxFileName xdgDir(configFileXDG);
@@ -227,9 +230,9 @@ bool MyApp::OnInit() {
     {
       long lng = wxLocale::GetSystemLanguage();
       wxConfig(wxS("wxMaxima"), wxEmptyString, m_configFileName)
-	.Read(wxS("language"), &lng);
+        .Read(wxS("language"), &lng);
       if (lng == wxLANGUAGE_UNKNOWN)
-	lng = wxLANGUAGE_DEFAULT;
+        lng = wxLANGUAGE_DEFAULT;
       lang = static_cast<wxLanguage>(lng);
     }
 
@@ -254,7 +257,7 @@ bool MyApp::OnInit() {
 
     wxFileTranslationsLoader::AddCatalogLookupPathPrefix(m_dirstruct.LocaleDir());
     wxFileTranslationsLoader::AddCatalogLookupPathPrefix(m_dirstruct.LocaleDir() +
-							 wxS("/wxwin"));
+                                                         wxS("/wxwin"));
     wxFileTranslationsLoader::AddCatalogLookupPathPrefix(wxS("/usr/share/locale"));
     wxFileTranslationsLoader::AddCatalogLookupPathPrefix(wxS("/usr/local/share/locale"));
 
@@ -282,9 +285,10 @@ bool MyApp::OnInit() {
     /* wxWidgets introduced version suffixes to gettext catalogs, see:
      * https://github.com/wxWidgets/wxWidgets/commit/ded4da5 */
     /* so try to load a catalog with this suffix */
+    // cppcheck-suppress unknownMacro
     wxTranslations::Get()->AddCatalog("wxstd-"
-				      wxSTRINGIZE(wxMAJOR_VERSION) "."
-				      wxSTRINGIZE(wxMINOR_VERSION));
+                                      wxSTRINGIZE(wxMAJOR_VERSION) "."
+                                      wxSTRINGIZE(wxMINOR_VERSION));
     wxTranslations::Get()->AddCatalog(wxS("wxstd"));
   }
 
@@ -314,8 +318,8 @@ bool MyApp::OnInit() {
     configFile.MakeAbsolute();
     Configuration::m_configfileLocation_override = configFile.GetFullPath();
     wxConfig::Set(
-		  new wxFileConfig(wxS("wxMaxima"), wxEmptyString,
-				   Configuration::m_configfileLocation_override));
+                  new wxFileConfig(wxS("wxMaxima"), wxEmptyString,
+                                   Configuration::m_configfileLocation_override));
   } else
     wxConfig::Set(new wxConfig(wxS("wxMaxima")));
 
@@ -368,7 +372,7 @@ bool MyApp::OnInit() {
     wxString dir = wxPathOnly(wxStandardPaths::Get().GetExecutablePath());
     if (dir != wxEmptyString)
       wxSetWorkingDirectory(
-			    wxPathOnly(wxStandardPaths::Get().GetExecutablePath()));
+                            wxPathOnly(wxStandardPaths::Get().GetExecutablePath()));
   }
 #if wxCHECK_VERSION(3, 1, 1)
   wxString fontPrefix = m_dirstruct.FontDir() + wxS("/");
@@ -462,7 +466,7 @@ int MyApp::OnRun() {
 
 void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
                       bool exitAfterEval, unsigned char *wxmData,
-                      size_t wxmLen) {
+                      std::size_t wxmLen) {
   int numberOfWindows = wxMaximaFrame::m_topLevelWindows.size();
 
   wxString title = _("wxMaxima");
@@ -472,12 +476,11 @@ void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
   if (numberOfWindows > 1)
     title = wxString::Format(_("wxMaxima %d"), numberOfWindows);
 
-  wxMaxima *frame = new wxMaxima(NULL, -1, title, file);
+  wxString initialContents;
   if (wxmData) {
     // Unzip the .wxm file
     wxMemoryInputStream istream(wxmData, wxmLen);
     wxTextInputStream textIn(istream, "\t", wxConvAuto(wxFONTENCODING_UTF8));
-    wxString initialContents;
     wxString line;
     wxString block;
     while (!istream.Eof()) {
@@ -490,14 +493,12 @@ void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
         block += line + "\n";
     }
     initialContents += _(block);
-    frame->SetWXMdata(initialContents);
   }
+  wxMaxima *frame = new wxMaxima(NULL, -1, title, file, initialContents);
 
   frame->EvalOnStartup(evalOnStartup);
   wxMaximaFrame::m_topLevelWindows.push_back(frame);
   frame->ExitAfterEval(exitAfterEval);
-
-  SetTopWindow(frame);
   frame->Show(true);
   frame->ShowTip(false);
 }
@@ -506,12 +507,12 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
   if(ev.GetId() == EventIDs::menu_help_numberformats)
     {
       NewWindow(wxEmptyString, false, false, NUMBERFORMATS_WXM,
-		NUMBERFORMATS_WXM_SIZE);
+                NUMBERFORMATS_WXM_SIZE);
     }
   else if(ev.GetId() == EventIDs::menu_help_3d)
     {
       NewWindow(wxEmptyString, false, false, DISPLAYING3DCURVES_WXM,
-		DISPLAYING3DCURVES_WXM_SIZE);
+                DISPLAYING3DCURVES_WXM_SIZE);
     }
   else if(ev.GetId() == EventIDs::menu_help_varnames) {
     NewWindow(wxEmptyString, false, false, VARIABLENAMES_WXM,
@@ -532,7 +533,7 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
   else if(ev.GetId() == EventIDs::menu_help_diffequations) {
     NewWindow(wxEmptyString, false, false, DIFFEQUATIONS_WXM,
               DIFFEQUATIONS_WXM_SIZE);
-    }
+  }
   else if(ev.GetId() == EventIDs::menu_help_tolerances) {
     NewWindow(wxEmptyString, false, false, TOLERANCECALCULATIONS_WXM,
               TOLERANCECALCULATIONS_WXM_SIZE);
@@ -548,13 +549,13 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
     wxConfig::Get()->Read(wxS("lastPath"), &lastPath);
     wxString file =
       wxFileSelector(_("Open"), wxEmptyString, wxEmptyString, wxEmptyString,
-		     _("All openable types (*.wxm, *.wxmx, *.mac, *.out, "
-		       "*.xml)|*.wxm;*.wxmx;*.mac;*.out;*.xml|"
-		       "wxMaxima document (*.wxm, *.wxmx)|*.wxm;*.wxmx|"
-		       "Maxima session (*.mac)|*.mac|"
-		       "Xmaxima session (*.out)|*.out|"
-		       "xml from broken .wxmx (*.xml)|*.xml"),
-		     wxFD_OPEN);
+                     _("All openable types (*.wxm, *.wxmx, *.mac, *.out, "
+                       "*.xml)|*.wxm;*.wxmx;*.mac;*.out;*.xml|"
+                       "wxMaxima document (*.wxm, *.wxmx)|*.wxm;*.wxmx|"
+                       "Maxima session (*.mac)|*.mac|"
+                       "Xmaxima session (*.out)|*.out|"
+                       "xml from broken .wxmx (*.xml)|*.xml"),
+                     wxFD_OPEN);
     if (!file.empty()) {
       // On the mac the "File/New" menu item by default opens a new window
       // instead of reusing the old one.
@@ -562,46 +563,46 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
     }
   }
   else if(ev.GetId() == wxID_NEW) {
-      // Mac computers insist that all instances of a new application need to
-      // share the same process. On all other OSes we create a separate process
-      // for each window: This way if one instance of wxMaxima crashes all the
-      // other instances are still alive.
+    // Mac computers insist that all instances of a new application need to
+    // share the same process. On all other OSes we create a separate process
+    // for each window: This way if one instance of wxMaxima crashes all the
+    // other instances are still alive.
     if (m_allWindowsInOneProcess)
       NewWindow();
     else {
       // Compile a list of arguments we want to pass to the new process
       std::vector<wxString> args;
       if (Configuration::m_configfileLocation_override != wxEmptyString)
-	{
-	  args.push_back("-f");
-	  args.push_back(Configuration::m_configfileLocation_override);
-	}
+        {
+          args.push_back("-f");
+          args.push_back(Configuration::m_configfileLocation_override);
+        }
       if (wxMaxima::Get_Maxima_Commandline_Filename() != wxEmptyString)
-	{
-	  args.push_back("-m");
-	  args.push_back(wxMaxima::Get_Maxima_Commandline_Filename());
-	}
+        {
+          args.push_back("-m");
+          args.push_back(wxMaxima::Get_Maxima_Commandline_Filename());
+        }
       if (ErrorRedirector::LoggingToStdErr())
-	  args.push_back("--logtostderr");
+        args.push_back("--logtostderr");
       if (Configuration::GetDebugmode())
-	  args.push_back("--debug");
+        args.push_back("--debug");
       if (wxMaxima::GetPipeToStdout())
-	  args.push_back("--pipe");
+        args.push_back("--pipe");
       if (wxMaxima::GetExitOnError())
-	  args.push_back("--exit-on-error");
+        args.push_back("--exit-on-error");
       if (wxMaxima::GetEnableIPC())
-	  args.push_back("--enableipc");
+        args.push_back("--enableipc");
       if (!wxMaxima::ExtraMaximaArgs().IsEmpty())
-	{
-	  args.push_back("-u");
-	  args.push_back(wxMaxima::ExtraMaximaArgs());
-	}
+        {
+          args.push_back("-u");
+          args.push_back(wxMaxima::ExtraMaximaArgs());
+        }
 
       // wxExecute wants the arguments as C strings, not as wxStrings =>
       // generate those C strings
       std::vector<wxCharBuffer> args_c_strings;
       for(const auto &i : args)
-	args_c_strings.push_back(wxCharBuffer(i.mb_str()));
+        args_c_strings.push_back(wxCharBuffer(i.mb_str()));
 
       // Additionally wxExecute expects these C strings in a C array.
       // Let's generate an unique pointer to that one so C++ automatically destroys it
@@ -610,13 +611,13 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
       wxCharBuffer executableName(wxStandardPaths::Get().GetExecutablePath().mb_str());
       args_array.get()[0] = executableName.data();;
       args_array.get()[args.size() + 1] = NULL;
-      for(size_t i = 0; i< args.size(); i++)
-	args_array.get()[i + 1] = args_c_strings[i].data();
+      for(std::size_t i = 0; i< args.size(); i++)
+        args_array.get()[i + 1] = args_c_strings[i].data();
       wxExecute(args_array.get());
 
       wxString command;
-      for(size_t i = 0; i< args.size() + 1; i++)
-	command += wxString::FromUTF8(args_array.get()[i]) + "\n";
+      for(std::size_t i = 0; i< args.size() + 1; i++)
+        command += wxString::FromUTF8(args_array.get()[i]) + "\n";
       command.Trim();
       wxLogMessage(_("Starting a new wxMaxima process as: %s"), command.mb_str());
     }
@@ -637,7 +638,8 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
       wxCloseEvent *event = new wxCloseEvent(wxEVT_CLOSE_WINDOW);
       event->SetCanVeto(true);
       event->SetLoggingOff(false);
-      win->GetEventHandler()->QueueEvent(event);
+      if(win)
+        win->GetEventHandler()->QueueEvent(event);
     }
     if (wxMaximaFrame::m_topLevelWindows.empty())
       wxExit();
@@ -651,3 +653,92 @@ void MyApp::MacNewFile() {
 }
 
 void MyApp::MacOpenFile(const wxString &file) { NewWindow(file); }
+
+#if wxUSE_ON_FATAL_EXCEPTION && wxUSE_CRASHREPORT
+void MyApp::OnFatalException()
+{
+    GenerateDebugReport(wxDebugReport::Context_Exception);
+}
+
+// Adapted from wxWidget's report sample
+void MyApp::GenerateDebugReport(wxDebugReport::Context ctx)
+{
+  if(ErrorRedirector::LoggingToStdErr())
+    {
+      StackToStdErr stackWalker;
+      stackWalker.Walk(0);
+      return;
+    }
+  else
+    {
+      wxDebugReportCompress *report = new wxDebugReportCompress;
+
+      // add all standard files: currently this means just a minidump and an
+      // XML file with system info and stack trace
+      report->AddAll(ctx);
+
+      // you can also call report->AddFile(...) with your own log files, files
+      // created using wxRegKey::Export() and so on, here we just add a test
+      // file containing the date of the crash
+      wxFileName fn(report->GetDirectory(), "timestamp.my");
+      wxFFile file(fn.GetFullPath(), "w");
+      if ( file.IsOpened() )
+        {
+          wxDateTime dt = wxDateTime::Now();
+          file.Write(dt.FormatISODate() + ' ' + dt.FormatISOTime());
+          file.Close();
+        }
+
+      // No translation after a crash, as the internationalization stuff might have been
+      // broken by the crash.
+      report->AddText("README.txt",
+                      "On crashes, if the compiler has provided enough information\n"
+                      "and wxWidgets knows how to interpret it we might get a stack\n"
+                      "backtrace, that contains the exact line of program code the\n"
+                      "crash happened in, what parameters the function that crashed\n"
+                      "was called with and, if that does still not explain the crash\n"
+                      "how we ended up in that situation.\n"
+                      "With all that information fixing a crash usually only takes\n"
+                      "minutes. The rest of the crash report\n"
+                      "might be there, if needed, but usually doesn't help too much.\n\n"
+                      "be aware, though, that the stack backtrace contains the\n"
+                      "parameters of the chain of function calls that ended up in\n"
+                      "a crash, and therefore in rare cases might contain personal\n"
+                      "information.",
+                      "What is this report all about?");
+      report->AddFile(fn.GetFullName(), "timestamp of this report");
+
+      // can also add an existing file directly, it will be copied
+      // automatically
+#ifdef __WXMSW__
+      wxString windir;
+      if ( !wxGetEnv("WINDIR", &windir) )
+        windir = "C:\\Windows";
+      fn.AssignDir(windir);
+      fn.AppendDir("system32");
+      fn.AppendDir("drivers");
+      fn.AppendDir("etc");
+#else // !__WXMSW__
+      fn.AssignDir("/etc");
+#endif // __WXMSW__/!__WXMSW__
+      fn.SetFullName("hosts");
+
+      if ( fn.FileExists() )
+        report->AddFile(fn.GetFullPath(), "Local hosts file");
+
+      // calling Show() is not mandatory, but is more polite
+      if ( wxDebugReportPreviewStd().Show(*report) )
+        {
+          if ( report->Process() )
+            {
+              wxLogMessage("Report generated in \"%s\".",
+                           report->GetCompressedFileName());
+              report->Reset();
+            }
+        }
+      //else: user cancelled the report
+
+      delete report;
+    }
+}
+#endif
