@@ -47,6 +47,7 @@
 #include <wx/sckstrm.h>
 #include <wx/buffer.h>
 #include <wx/power.h>
+#include <wx/debugrpt.h>
 #include <memory>
 #ifdef __WXMSW__
 #include <windows.h>
@@ -84,6 +85,7 @@ class wxMaxima : public wxMaximaFrame
 public:
   wxMaxima(wxWindow *parent, int id, const wxString title,
            const wxString &filename = wxEmptyString,
+           const wxString initialWorksheetContents = wxEmptyString,
            const wxPoint pos = wxDefaultPosition, const wxSize size = wxDefaultSize);
 
   virtual ~wxMaxima();
@@ -100,7 +102,7 @@ public:
   /*! Allow maxima to click buttons in wxMaxima
 
     Disabled by default for security reasons
-   */
+  */
   static void EnableIPC(){ MaximaIPC::EnableIPC(); }
   //! Do we allow maxima to click buttons in wxMaxima?
   static bool GetEnableIPC(){ return MaximaIPC::GetEnableIPC(); }
@@ -131,8 +133,6 @@ public:
   wxTimer m_maximaStdoutPollTimer;
 
   void ShowTip(bool force);
-
-  void SetWXMdata(const wxString &data){m_initialWorkSheetContents = data;}
   //! Do we want to evaluate the document on startup?
   void EvalOnStartup(bool eval)
     {
@@ -165,7 +165,7 @@ public:
 
   //! Load an image from a file into the worksheet.
   void LoadImage(wxString file)
-    { m_worksheet->OpenHCaret(file, GC_TYPE_IMAGE); }
+    { GetWorksheet()->OpenHCaret(file, GC_TYPE_IMAGE); }
 
   //! Query the value of a new maxima variable
   bool QueryVariableValue();
@@ -199,13 +199,11 @@ private:
   bool m_discardAllData = false;
   wxString m_maximaAuthString;
   MaximaIPC m_ipc{this};
-  //! wxm data the worksheet is populated from
-  wxString m_initialWorkSheetContents;
   static bool m_pipeToStderr;
   static bool m_exitOnError;
   static wxString m_extraMaximaArgs;
   //! The variable names to query for the variables pane and for internal reasons
-  wxArrayString m_varNamesToQuery;
+  std::vector<wxString> m_varNamesToQuery;
 
   bool m_isLogTarget;
   //! Is true if opening the file from the command line failed before updating the statusbar.
@@ -232,9 +230,9 @@ private:
   //! Searches for maxima's output prompts
 //  static wxRegEx m_outputPromptRegEx;
   //! The number of output cells the current command has produced so far.
-  int m_outputCellsFromCurrentCommand;
+  long m_outputCellsFromCurrentCommand;
   //! The maximum number of lines per command we will display
-  int m_maxOutputCellsPerCommand;
+  long m_maxOutputCellsPerCommand;
   /*! Double the number of consecutive unsuccessful attempts to connect to the maxima server
 
     Each prompt is deemed as but one hint for a working maxima while each crash counts twice
@@ -255,7 +253,7 @@ private:
 
     If text doesn't contain any error this function returns wxEmptyString
   */
-  wxString GetUnmatchedParenthesisState(wxString text, int &index);
+  wxString GetUnmatchedParenthesisState(wxString text, std::size_t &index);
   //! The buffer all text from maxima is stored in before converting it to a wxString.
   wxMemoryBuffer m_uncompletedChars;
 
@@ -520,7 +518,7 @@ protected:
   bool ParseNextChunkFromMaxima(wxString &data);
 
   //! Find the end of a tag in wxMaxima's output.
-  int FindTagEnd(const wxString &data, const wxString &tag);
+  long FindTagEnd(const wxString &data, const wxString &tag);
 
   /*! Reads text that isn't enclosed between xml tags.
 
@@ -689,11 +687,11 @@ protected:
 
   /*! Tries or offers to save the document
 
-      If auto-save is on the document is automatically saved.
+    If auto-save is on the document is automatically saved.
 
-      \return
-      * wxID_NO: No saving is necessary, currently
-  */
+    \return
+    * wxID_NO: No saving is necessary, currently
+    */
   int SaveDocumentP();
 
   //! Set the current working directory file I/O from maxima is relative to.
@@ -808,7 +806,6 @@ protected:
     If we didn't we respan an unexpectedly-closing maxima.
   */
   bool m_closing;
-  wxString m_openFile;
   //! The directory with maxima's temp files
   wxString m_maximaTempDir;
   wxString m_maximaHtmlDir;
@@ -820,7 +817,7 @@ protected:
   //! Maxima's idea about gnuplot's location
   wxString m_gnuplotcommand;
   //! The Char the current command starts at in the current WorkingGroup
-  int m_commandIndex;
+  std::size_t m_commandIndex;
   FindReplacePane::FindReplaceData m_findData;
   static wxRegEx m_funRegEx;
   static wxRegEx m_varRegEx;
@@ -884,6 +881,54 @@ private:
 
 #if wxUSE_DRAG_AND_DROP
 
+// cppcheck-suppress noConstructor
+class MyApp : public wxApp
+{
+public:
+  virtual bool OnInit();
+  virtual int OnRun();
+  virtual int OnExit();
+#if wxUSE_ON_FATAL_EXCEPTION && wxUSE_CRASHREPORT
+  void	OnFatalException () override;
+#endif
+  /*! Create a new window
+
+    The mac platform insists in making all windows of an application
+    share the same process. On the other platforms we create a separate
+    process for every wxMaxima session instead which means that each
+    process uses the NewWindow() function only once.
+
+    \param file The file name
+    \param evalOnStartup Do we want to execute the file automatically, but halt on error?
+    \param exitAfterEval Do we want to close the window after the file has been evaluated?
+    \param wxmData A .wxm file containing the initial worksheet contents
+    \param wxmLen  The length of wxmData
+  */
+  static void NewWindow(const wxString &file = {}, bool evalOnStartup = false, bool exitAfterEval = false, unsigned char *wxmData = NULL, std::size_t wxmLen = 0);
+
+  void OnFileMenu(wxCommandEvent &ev);
+
+  virtual void MacNewFile();
+  void BecomeLogTarget();
+
+  virtual void MacOpenFile(const wxString &file);
+
+private:
+#if wxUSE_ON_FATAL_EXCEPTION && wxUSE_CRASHREPORT
+  void GenerateDebugReport(wxDebugReport::Context ctx);
+#endif
+  std::unique_ptr<wxLocale> m_locale;
+  std::unique_ptr<wxTranslations> m_translations;
+  //! The name of the config file. Empty = Use the default one.
+  wxString m_configFileName;
+  Dirstructure m_dirstruct;
+#if defined __WXOSX__
+  bool m_allWindowsInOneProcess = true;
+#else
+  bool m_allWindowsInOneProcess = false;
+#endif
+};
+
 class MyDropTarget : public wxFileDropTarget
 {
 public:
