@@ -21,7 +21,7 @@
 //
 //  SPDX-License-Identifier: GPL-2.0+
 
-/*!\file 
+/*!\file
   This file declares the class wxMaximaFrame
 
   wxMaximaFrame draws everything which can be seen
@@ -98,9 +98,9 @@ public:
   bool IsPaneDisplayed(int id);
 
   /*! Show or hide a sidebar
-    
+
     \param id The type of the sidebar to show/hide
-    \param show 
+    \param show
     - true: show the sidebar
     - false: hide it
   */
@@ -116,7 +116,7 @@ public:
    */
   void EvaluationQueueLength(int length, int numberOfCommands = -1);
 
-  /*! Set the status according to if maxima is calculating 
+  /*! Set the status according to if maxima is calculating
 
     \param status
     - true:  Maxima is calculating
@@ -151,7 +151,7 @@ public:
 protected:
   Configuration m_configuration;
   //! How many bytes did maxima send us until now?
-  long m_bytesFromMaxima;
+  long m_bytesFromMaxima = 0;
   //! The process id of maxima. Is determined by ReadFirstPrompt.
   long m_pid;
   //! The last name GetTempAutosavefileName() has returned.
@@ -198,7 +198,7 @@ protected:
   wxMenu *m_Simplify_Complex_Sub;
   //! The calculus menu
   wxMenu *m_CalculusMenu;
-  
+
   //! The plot menu
   wxMenu *m_PlotMenu;
   //! The list menu
@@ -210,14 +210,14 @@ protected:
   //! Remove an eventual temporary autosave file.
   void RemoveTempAutosavefile();
   //! Re-read the configuration.
-  void ReReadConfig();  
+  void ReReadConfig();
   //! Read the configuration from the OS's configuration storage.
-  void ReadConfig();  
+  void ReadConfig();
   //! Remember a temporary autosave file name.
   void RegisterAutoSaveFile();
   /*! An instant single-window mode
-   
-    A last resort if https://trac.wxwidgets.org/ticket/18815 hinders one from 
+
+    A last resort if https://trac.wxwidgets.org/ticket/18815 hinders one from
     re-docking windows.
   */
   void DockAllSidebars(wxCommandEvent &ev);
@@ -235,6 +235,8 @@ public:
 
   //! Get the list of human-readable sidebarnames and IDs
   const std::unordered_map<int, wxString>  &GetSidebarNames() const {return m_sidebarNames;}
+protected:
+  Worksheet *GetWorksheet() const {return m_worksheet;}
 private:
   //! The names our dockable sidebars are identified with in the config
   std::unordered_map<int, wxString> m_sidebarNames;
@@ -242,13 +244,13 @@ private:
   std::unordered_map<int, wxString> m_sidebarCaption;
   //! How many bytes did maxima send us when we updated the statusbar?
   long m_bytesFromMaxima_last;
-  wxTimer m_bytesReadDisplayTimer; 
+  wxTimer m_bytesReadDisplayTimer;
   //! True=We are currently saving.
   bool m_StatusSaving;
 
   void SetupToolBar();
 
-/*! 
+/*!
   Create the menus.
 */
   void SetupMenu();
@@ -258,14 +260,14 @@ private:
   wxWindow *CreateMathPane();
 
   wxWindow *CreateFormatPane();
-  
+
   //! The class for the sidebar with the draw commands
   class DrawPane: public wxScrolled<wxPanel>
   {
   public:
     explicit DrawPane(wxWindow *parent, int id = wxID_ANY);
     /*! Tell the sidebar if we currently are inside a 2D or a 3D plot command
-        
+
       \param dimensions
       - 0 = We aren't inside a plot
       - 2 = We are inside a 2D plot
@@ -298,7 +300,7 @@ public:
 protected:
   ScrollingGenWizPanel *m_wizard = NULL;
   //! Are we inside a 2d or 3d draw command?
-  long m_drawDimensions_last;
+  long m_drawDimensions_last = -1;
   //! Do we have new text to output in the Status Bar?
   bool m_newStatusText;
   //! The text for the Right half of the Status Bar
@@ -368,16 +370,19 @@ protected:
   bool ToolbarIsShown();
   //! The manager for dynamic screen layouts
   wxAuiManager m_manager;
+private:
+  //! The worksheet itself
+protected:
+  //! The worksheet
+  Worksheet * const m_worksheet = NULL;
+  //! The history pane
+  History * const m_history;
   //! A XmlInspector-like xml monitor
   XmlInspector *m_xmlInspector;
   //! true=force an update of the status bar at the next call of StatusMaximaBusy()
   bool m_forceStatusbarUpdate;
   //! The panel the log and debug messages will appear on
   LogPane *m_logPane;
-  //! The worksheet itself
-  Worksheet *m_worksheet;
-  //! The history pane
-  History *m_history;
   RecentDocuments m_recentDocuments;
   RecentDocuments m_recentPackages;
   wxMenu *m_recentDocumentsMenu;
